@@ -1,10 +1,9 @@
 /*
-(c) 2014 Glen Joseph Fernandes
-<glenjofe -at- gmail.com>
+Copyright 2014 Glen Joseph Fernandes
+(glenjofe@gmail.com)
 
-Distributed under the Boost Software
-License, Version 1.0.
-http://boost.org/LICENSE_1_0.txt
+Distributed under the Boost Software License, Version 1.0.
+(http://www.boost.org/LICENSE_1_0.txt)
 */
 #ifndef BOOST_ALIGN_ALIGNED_ALLOCATOR_FORWARD_HPP
 #define BOOST_ALIGN_ALIGNED_ALLOCATOR_FORWARD_HPP
@@ -17,7 +16,7 @@ namespace alignment {
 template<class T, std::size_t Alignment = 1>
 class aligned_allocator;
 
-} /* .alignment */
-} /* .boost */
+} /* alignment */
+} /* boost */
 
 #endif
