@@ -2,7 +2,7 @@
 // ssl/detail/write_op.hpp
 // ~~~~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2017 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2023 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -17,10 +17,8 @@
 
 #include <boost/asio/detail/config.hpp>
 
-#if !defined(BOOST_ASIO_ENABLE_OLD_SSL)
-# include <boost/asio/detail/buffer_sequence_adapter.hpp>
-# include <boost/asio/ssl/detail/engine.hpp>
-#endif // !defined(BOOST_ASIO_ENABLE_OLD_SSL)
+#include <boost/asio/detail/buffer_sequence_adapter.hpp>
+#include <boost/asio/ssl/detail/engine.hpp>
 
 #include <boost/asio/detail/push_options.hpp>
 
@@ -29,12 +27,15 @@ namespace asio {
 namespace ssl {
 namespace detail {
 
-#if !defined(BOOST_ASIO_ENABLE_OLD_SSL)
-
 template <typename ConstBufferSequence>
 class write_op
 {
 public:
+  static constexpr const char* tracking_name()
+  {
+    return "ssl::stream<>::async_write_some";
+  }
+
   write_op(const ConstBufferSequence& buffers)
     : buffers_(buffers)
   {
@@ -44,9 +45,13 @@ public:
       boost::system::error_code& ec,
       std::size_t& bytes_transferred) const
   {
+    unsigned char storage[
+      boost::asio::detail::buffer_sequence_adapter<boost::asio::const_buffer,
+        ConstBufferSequence>::linearisation_storage_size];
+
     boost::asio::const_buffer buffer =
       boost::asio::detail::buffer_sequence_adapter<boost::asio::const_buffer,
-        ConstBufferSequence>::first(buffers_);
+        ConstBufferSequence>::linearise(buffers_, boost::asio::buffer(storage));
 
     return eng.write(buffer, ec, bytes_transferred);
   }
@@ -56,15 +61,13 @@ public:
       const boost::system::error_code& ec,
       const std::size_t& bytes_transferred) const
   {
-    handler(ec, bytes_transferred);
+    static_cast<Handler&&>(handler)(ec, bytes_transferred);
   }
 
 private:
   ConstBufferSequence buffers_;
 };
 
-#endif // !defined(BOOST_ASIO_ENABLE_OLD_SSL)
-
 } // namespace detail
 } // namespace ssl
 } // namespace asio
