@@ -1,7 +1,9 @@
 // Boost.Geometry (aka GGL, Generic Geometry Library)
 
-// Copyright (c) 2014-2017, Oracle and/or its affiliates.
+// Copyright (c) 2017-2023 Adam Wulkiewicz, Lodz, Poland.
 
+// Copyright (c) 2014-2023, Oracle and/or its affiliates.
+// Contributed and/or modified by Vissarion Fysikopoulos, on behalf of Oracle
 // Contributed and/or modified by Menelaos Karavelas, on behalf of Oracle
 // Contributed and/or modified by Adam Wulkiewicz, on behalf of Oracle
 
@@ -23,7 +25,8 @@
 #include <vector>
 
 #include <boost/core/ignore_unused.hpp>
-#include <boost/range.hpp>
+#include <boost/range/begin.hpp>
+#include <boost/range/end.hpp>
 
 #include <boost/geometry/core/assert.hpp>
 #include <boost/geometry/core/exterior_ring.hpp>
@@ -31,8 +34,9 @@
 #include <boost/geometry/core/ring_type.hpp>
 #include <boost/geometry/core/tags.hpp>
 
-#include <boost/geometry/util/condition.hpp>
+#include <boost/geometry/util/constexpr.hpp>
 #include <boost/geometry/util/range.hpp>
+#include <boost/geometry/util/sequence.hpp>
 
 #include <boost/geometry/geometries/box.hpp>
 
@@ -43,9 +47,9 @@
 #include <boost/geometry/algorithms/expand.hpp>
 #include <boost/geometry/algorithms/num_interior_rings.hpp>
 #include <boost/geometry/algorithms/validity_failure_type.hpp>
+#include <boost/geometry/algorithms/detail/point_on_border.hpp>
 #include <boost/geometry/algorithms/within.hpp>
 
-#include <boost/geometry/algorithms/detail/check_iterator_range.hpp>
 #include <boost/geometry/algorithms/detail/partition.hpp>
 
 #include <boost/geometry/algorithms/detail/is_valid/complement_graph.hpp>
@@ -60,6 +64,12 @@
 #include <boost/geometry/algorithms/dispatch/is_valid.hpp>
 
 
+// TEMP
+#include <boost/geometry/strategies/envelope/cartesian.hpp>
+#include <boost/geometry/strategies/envelope/geographic.hpp>
+#include <boost/geometry/strategies/envelope/spherical.hpp>
+
+
 namespace boost { namespace geometry
 {
 
@@ -73,20 +83,19 @@ template <typename Polygon, bool CheckRingValidityOnly = false>
 class is_valid_polygon
 {
 protected:
-    typedef debug_validity_phase<Polygon> debug_phase;
 
     template <typename VisitPolicy, typename Strategy>
-    struct per_ring
+    struct is_invalid_ring
     {
-        per_ring(VisitPolicy& policy, Strategy const& strategy)
+        is_invalid_ring(VisitPolicy& policy, Strategy const& strategy)
             : m_policy(policy)
             , m_strategy(strategy)
         {}
 
         template <typename Ring>
-        inline bool apply(Ring const& ring) const
+        inline bool operator()(Ring const& ring) const
         {
-            return detail::is_valid::is_valid_ring
+            return ! detail::is_valid::is_valid_ring
                 <
                     Ring, false, true
                 >::apply(ring, m_policy, m_strategy);
@@ -101,14 +110,9 @@ protected:
                                          VisitPolicy& visitor,
                                          Strategy const& strategy)
     {
-        return
-            detail::check_iterator_range
-                <
-                    per_ring<VisitPolicy, Strategy>,
-                    true // allow for empty interior ring range
-                >::apply(boost::begin(interior_rings),
-                         boost::end(interior_rings),
-                         per_ring<VisitPolicy, Strategy>(visitor, strategy));
+        return std::none_of(boost::begin(interior_rings),
+                            boost::end(interior_rings),
+                            is_invalid_ring<VisitPolicy, Strategy>(visitor, strategy));
     }
 
     struct has_valid_rings
@@ -118,6 +122,7 @@ protected:
                                  VisitPolicy& visitor,
                                  Strategy const& strategy)
         {
+            typedef debug_validity_phase<Polygon> debug_phase;
             typedef typename ring_type<Polygon>::type ring_type;
 
             // check validity of exterior ring
@@ -142,43 +147,104 @@ protected:
     };
 
 
+    // Iterator value_type is a Ring or Polygon
+    template <typename Iterator, typename Box>
+    struct partition_item
+    {
+        explicit partition_item(Iterator it)
+            : m_it(it)
+            , m_is_initialized(false)
+        {}
+
+        Iterator get() const
+        {
+            return m_it;
+        }
+
+        template <typename EnvelopeStrategy>
+        Box const& get_envelope(EnvelopeStrategy const& strategy) const
+        {
+            if (! m_is_initialized)
+            {
+                m_box = geometry::return_envelope<Box>(*m_it, strategy);
+                m_is_initialized = true;
+            }
+            return m_box;
+        }
+
+    private:
+        Iterator m_it;
+        mutable Box m_box;
+        mutable bool m_is_initialized;
+    };
+
     // structs for partition -- start
+    template <typename Strategy>
     struct expand_box
     {
+        explicit expand_box(Strategy const& strategy)
+            : m_strategy(strategy)
+        {}
+
         template <typename Box, typename Iterator>
-        static inline void apply(Box& total, Iterator const& it)
+        inline void apply(Box& total, partition_item<Iterator, Box> const& item) const
         {
-            geometry::expand(total, geometry::return_envelope<Box>(*it));
+            geometry::expand(total,
+                             item.get_envelope(m_strategy),
+                             m_strategy);
         }
 
+        Strategy const& m_strategy;
     };
 
+    template <typename Strategy>
     struct overlaps_box
     {
+        explicit overlaps_box(Strategy const& strategy)
+            : m_strategy(strategy)
+        {}
+
         template <typename Box, typename Iterator>
-        static inline bool apply(Box const& box, Iterator const& it)
+        inline bool apply(Box const& box, partition_item<Iterator, Box> const& item) const
         {
-            return ! geometry::disjoint(*it, box);
+            return ! geometry::disjoint(item.get_envelope(m_strategy),
+                                        box,
+                                        m_strategy);
         }
+
+        Strategy const& m_strategy;
     };
 
 
+    template <typename Strategy>
     struct item_visitor_type
     {
         bool items_overlap;
+        Strategy const& m_strategy;
 
-        item_visitor_type() : items_overlap(false) {}
+        explicit item_visitor_type(Strategy const& strategy)
+            : items_overlap(false)
+            , m_strategy(strategy)
+        {}
 
-        template <typename Item1, typename Item2>
-        inline void apply(Item1 const& item1, Item2 const& item2)
+        template <typename Iterator, typename Box>
+        inline bool apply(partition_item<Iterator, Box> const& item1,
+                          partition_item<Iterator, Box> const& item2)
         {
-            if (! items_overlap
-                && (geometry::within(*points_begin(*item1), *item2)
-                    || geometry::within(*points_begin(*item2), *item1))
-                )
+            typedef util::type_sequence
+                <
+                    geometry::de9im::static_mask<'T'>,
+                    geometry::de9im::static_mask<'*', 'T'>,
+                    geometry::de9im::static_mask<'*', '*', '*', 'T'>
+                > relate_mask_t;
+
+            if ( ! items_overlap
+              && geometry::relate(*item1.get(), *item2.get(), relate_mask_t(), m_strategy) )
             {
                 items_overlap = true;
+                return false; // interrupt
             }
+            return true;
         }
     };
     // structs for partition -- end
@@ -189,14 +255,16 @@ protected:
         typename RingIterator,
         typename ExteriorRing,
         typename TurnIterator,
-        typename VisitPolicy
+        typename VisitPolicy,
+        typename Strategy
     >
     static inline bool are_holes_inside(RingIterator rings_first,
                                         RingIterator rings_beyond,
                                         ExteriorRing const& exterior_ring,
                                         TurnIterator turns_first,
                                         TurnIterator turns_beyond,
-                                        VisitPolicy& visitor)
+                                        VisitPolicy& visitor,
+                                        Strategy const& strategy)
     {
         boost::ignore_unused(visitor);
 
@@ -224,7 +292,7 @@ protected:
             // do not examine interior rings that have turns with the
             // exterior ring
             if (ring_indices.find(ring_index) == ring_indices.end()
-                && ! geometry::covered_by(range::front(*it), exterior_ring))
+                && ! geometry::covered_by(range::front(*it), exterior_ring, strategy))
             {
                 return visitor.template apply<failure_interior_rings_outside>();
             }
@@ -237,26 +305,31 @@ protected:
             ring_indices.insert(tit->operations[1].seg_id.ring_index);
         }
 
+        typedef geometry::model::box<typename point_type<Polygon>::type> box_type;
+        typedef partition_item<RingIterator, box_type> item_type;
+
         // put iterators for interior rings without turns in a vector
-        std::vector<RingIterator> ring_iterators;
+        std::vector<item_type> ring_iterators;
         ring_index = 0;
         for (RingIterator it = rings_first; it != rings_beyond;
              ++it, ++ring_index)
         {
             if (ring_indices.find(ring_index) == ring_indices.end())
             {
-                ring_iterators.push_back(it);
+                ring_iterators.push_back(item_type(it));
             }
         }
 
-        // call partition to check is interior rings are disjoint from
+        // call partition to check if interior rings are disjoint from
         // each other
-        item_visitor_type item_visitor;
+        item_visitor_type<Strategy> item_visitor(strategy);
 
         geometry::partition
             <
-                geometry::model::box<typename point_type<Polygon>::type>
-            >::apply(ring_iterators, item_visitor, expand_box(), overlaps_box());
+                box_type
+            >::apply(ring_iterators, item_visitor,
+                     expand_box<Strategy>(strategy),
+                     overlaps_box<Strategy>(strategy));
 
         if (item_visitor.items_overlap)
         {
@@ -273,35 +346,40 @@ protected:
         typename InteriorRings,
         typename ExteriorRing,
         typename TurnIterator,
-        typename VisitPolicy
+        typename VisitPolicy,
+        typename Strategy
     >
     static inline bool are_holes_inside(InteriorRings const& interior_rings,
                                         ExteriorRing const& exterior_ring,
                                         TurnIterator first,
                                         TurnIterator beyond,
-                                        VisitPolicy& visitor)
+                                        VisitPolicy& visitor,
+                                        Strategy const& strategy)
     {
         return are_holes_inside(boost::begin(interior_rings),
                                 boost::end(interior_rings),
                                 exterior_ring,
                                 first,
                                 beyond,
-                                visitor);
+                                visitor,
+                                strategy);
     }
 
     struct has_holes_inside
-    {    
-        template <typename TurnIterator, typename VisitPolicy>
+    {
+        template <typename TurnIterator, typename VisitPolicy, typename Strategy>
         static inline bool apply(Polygon const& polygon,
                                  TurnIterator first,
                                  TurnIterator beyond,
-                                 VisitPolicy& visitor)
+                                 VisitPolicy& visitor,
+                                 Strategy const& strategy)
         {
             return are_holes_inside(geometry::interior_rings(polygon),
                                     geometry::exterior_ring(polygon),
                                     first,
                                     beyond,
-                                    visitor);
+                                    visitor,
+                                    strategy);
         }
     };
 
@@ -310,11 +388,12 @@ protected:
 
     struct has_connected_interior
     {
-        template <typename TurnIterator, typename VisitPolicy>
+        template <typename TurnIterator, typename VisitPolicy, typename Strategy>
         static inline bool apply(Polygon const& polygon,
                                  TurnIterator first,
                                  TurnIterator beyond,
-                                 VisitPolicy& visitor)
+                                 VisitPolicy& visitor,
+                                 Strategy const& )
         {
             boost::ignore_unused(visitor);
 
@@ -322,7 +401,11 @@ protected:
                 <
                     TurnIterator
                 >::value_type turn_type;
-            typedef complement_graph<typename turn_type::point_type> graph;
+            typedef complement_graph
+                <
+                    typename turn_type::point_type,
+                    Strategy
+                > graph;
 
             graph g(geometry::num_interior_rings(polygon) + 1);
             for (TurnIterator tit = first; tit != beyond; ++tit)
@@ -363,15 +446,16 @@ public:
             return false;
         }
 
-        if (BOOST_GEOMETRY_CONDITION(CheckRingValidityOnly))
+        if BOOST_GEOMETRY_CONSTEXPR (CheckRingValidityOnly)
         {
             return true;
         }
 
         // compute turns and check if all are acceptable
+        typedef debug_validity_phase<Polygon> debug_phase;
         debug_phase::apply(3);
 
-        typedef has_valid_self_turns<Polygon> has_valid_turns;
+        typedef has_valid_self_turns<Polygon, typename Strategy::cs_tag> has_valid_turns;
 
         std::deque<typename has_valid_turns::turn_type> turns;
         bool has_invalid_turns
@@ -388,7 +472,8 @@ public:
 
         if (! has_holes_inside::apply(polygon,
                                       turns.begin(), turns.end(),
-                                      visitor))
+                                      visitor,
+                                      strategy))
         {
             return false;
         }
@@ -399,7 +484,8 @@ public:
         return has_connected_interior::apply(polygon,
                                              turns.begin(),
                                              turns.end(),
-                                             visitor);
+                                             visitor,
+                                             strategy);
     }
 };
 
