@@ -2,8 +2,8 @@
 
 // Copyright (c) 2007-2012 Barend Gehrels, Amsterdam, the Netherlands.
 
-// This file was modified by Oracle on 2017, 2018.
-// Modifications copyright (c) 2017-2018 Oracle and/or its affiliates.
+// This file was modified by Oracle on 2017-2020.
+// Modifications copyright (c) 2017-2020 Oracle and/or its affiliates.
 
 // Contributed and/or modified by Adam Wulkiewicz, on behalf of Oracle
 
@@ -17,13 +17,15 @@
 #include <cstddef>
 #include <set>
 
-#include <boost/range.hpp>
+#include <boost/range/begin.hpp>
+#include <boost/range/end.hpp>
+#include <boost/range/value_type.hpp>
 
 #include <boost/geometry/algorithms/detail/overlay/cluster_info.hpp>
+#include <boost/geometry/algorithms/detail/overlay/cluster_exits.hpp>
 #include <boost/geometry/algorithms/detail/overlay/is_self_turn.hpp>
 #include <boost/geometry/algorithms/detail/overlay/sort_by_side.hpp>
 #include <boost/geometry/algorithms/detail/overlay/turn_info.hpp>
-#include <boost/geometry/core/access.hpp>
 #include <boost/geometry/core/assert.hpp>
 #include <boost/geometry/util/condition.hpp>
 
@@ -72,24 +74,6 @@ inline void debug_traverse(Turn const& , Operation, const char*, bool = true)
 }
 #endif
 
-
-//! Metafunction to define side_order (clockwise, ccw) by operation_type
-template <operation_type OpType>
-struct side_compare {};
-
-template <>
-struct side_compare<operation_union>
-{
-    typedef std::greater<int> type;
-};
-
-template <>
-struct side_compare<operation_intersection>
-{
-    typedef std::less<int> type;
-};
-
-
 template
 <
     bool Reverse1,
@@ -106,25 +90,10 @@ template
 struct traversal
 {
 private :
-    struct linked_turn_op_info
-    {
-        explicit linked_turn_op_info(signed_size_type ti = -1, int oi = -1,
-                    signed_size_type nti = -1)
-            : turn_index(ti)
-            , op_index(oi)
-            , next_turn_index(nti)
-            , rank_index(-1)
-        {}
-
-        signed_size_type turn_index;
-        int op_index;
-        signed_size_type next_turn_index;
-        signed_size_type rank_index;
-    };
 
     static const operation_type target_operation = operation_from_overlay<OverlayType>::value;
 
-    typedef typename side_compare<target_operation>::type side_compare_type;
+    typedef typename sort_by_side::side_compare<target_operation>::type side_compare_type;
     typedef typename boost::range_value<Turns>::type turn_type;
     typedef typename turn_type::turn_operation_type turn_operation_type;
 
@@ -153,12 +122,8 @@ public :
     template <typename TurnInfoMap>
     inline void finalize_visit_info(TurnInfoMap& turn_info_map)
     {
-        for (typename boost::range_iterator<Turns>::type
-            it = boost::begin(m_turns);
-            it != boost::end(m_turns);
-            ++it)
+        for (auto& turn : m_turns)
         {
-            turn_type& turn = *it;
             for (int i = 0; i < 2; i++)
             {
                 turn_operation_type& op = turn.operations[i];
@@ -166,12 +131,7 @@ public :
                     || op.visited.started()
                     || op.visited.finished() )
                 {
-                   ring_identifier const ring_id
-                        (
-                            op.seg_id.source_index,
-                            op.seg_id.multi_index,
-                            op.seg_id.ring_index
-                        );
+                   ring_identifier const ring_id = ring_id_by_seg_id(op.seg_id);
                    turn_info_map[ring_id].has_traversed_turn = true;
 
                    if (op.operation == operation_continue)
@@ -180,11 +140,7 @@ public :
                        // as traversed too
                        turn_operation_type& other_op = turn.operations[1 - i];
                        ring_identifier const other_ring_id
-                            (
-                                other_op.seg_id.source_index,
-                                other_op.seg_id.multi_index,
-                                other_op.seg_id.ring_index
-                            );
+                               = ring_id_by_seg_id(other_op.seg_id);
                        turn_info_map[other_ring_id].has_traversed_turn = true;
                    }
                 }
@@ -197,23 +153,18 @@ public :
     inline void set_visited_in_cluster(signed_size_type cluster_id,
                                        signed_size_type rank)
     {
-        typename Clusters::const_iterator mit = m_clusters.find(cluster_id);
+        auto mit = m_clusters.find(cluster_id);
         BOOST_ASSERT(mit != m_clusters.end());
 
         cluster_info const& cinfo = mit->second;
-        std::set<signed_size_type> const& ids = cinfo.turn_indices;
 
-        for (typename std::set<signed_size_type>::const_iterator it = ids.begin();
-             it != ids.end(); ++it)
+        for (auto turn_index : cinfo.turn_indices)
         {
-            signed_size_type const turn_index = *it;
             turn_type& turn = m_turns[turn_index];
 
-            for (int i = 0; i < 2; i++)
+            for (auto& op : turn.operations)
             {
-                turn_operation_type& op = turn.operations[i];
-                if (op.visited.none()
-                    && op.enriched.rank == rank)
+                if (op.visited.none() && op.enriched.rank == rank)
                 {
                     op.visited.set_visited();
                 }
@@ -553,7 +504,7 @@ public :
     }
 
     inline
-    bool select_operation(const turn_type& turn,
+    bool select_operation(turn_type const& turn,
                 signed_size_type turn_index,
                 signed_size_type start_turn_index,
                 segment_identifier const& previous_seg_id,
@@ -584,7 +535,7 @@ public :
         return result;
     }
 
-    inline int starting_operation_index(const turn_type& turn) const
+    inline int starting_operation_index(turn_type const& turn) const
     {
         for (int i = 0; i < 2; i++)
         {
@@ -596,7 +547,7 @@ public :
         return -1;
     }
 
-    inline bool both_finished(const turn_type& turn) const
+    inline bool both_finished(turn_type const& turn) const
     {
         for (int i = 0; i < 2; i++)
         {
@@ -608,28 +559,24 @@ public :
         return true;
     }
 
-
-    template <typename RankedPoint>
-    inline turn_operation_type const& operation_from_rank(RankedPoint const& rp) const
-    {
-        return m_turns[rp.turn_index].operations[rp.operation_index];
-    }
-
-    inline int select_turn_in_cluster_union(sort_by_side::rank_type selected_rank,
+    inline int priority_of_turn_in_cluster_union(sort_by_side::rank_type selected_rank,
             typename sbs_type::rp const& ranked_point,
+            std::set<signed_size_type> const& cluster_indices,
             signed_size_type start_turn_index, int start_op_index) const
     {
-        // Returns 0 if it not OK
-        // Returns 1 if it OK
-        // Returns 2 if it OK and start turn matches
-        // Returns 3 if it OK and start turn and start op both match
+        // Returns 0: not OK
+        // Returns 1: OK but next turn is in same cluster
+        // Returns 2: OK
+        // Returns 3: OK and start turn matches
+        // Returns 4: OK and start turn and start op both match
         if (ranked_point.rank != selected_rank
             || ranked_point.direction != sort_by_side::dir_to)
         {
             return 0;
         }
 
-        turn_operation_type const& op = operation_from_rank(ranked_point);
+        auto const& turn = m_turns[ranked_point.turn_index];
+        auto const& op = turn.operations[ranked_point.operation_index];
 
         // Check finalized: TODO: this should be finetuned, it is not necessary
         if (op.visited.finalized())
@@ -645,38 +592,51 @@ public :
             return 0;
         }
 
-        return ranked_point.turn_index == start_turn_index
-                && ranked_point.operation_index == start_op_index ? 3
-            : ranked_point.turn_index == start_turn_index ? 2
-            : 1
+        bool const to_start = ranked_point.turn_index == start_turn_index;
+        bool const to_start_index = ranked_point.operation_index == start_op_index;
+
+        bool const next_in_same_cluster
+                = cluster_indices.count(op.enriched.get_next_turn_index()) > 0;
+
+        return to_start && to_start_index ? 4
+            : to_start ? 3
+            : next_in_same_cluster ? 1
+            : 2
             ;
     }
 
-    inline sort_by_side::rank_type select_rank(sbs_type const& sbs,
-                                        bool skip_isolated) const
+    template <typename RankedPoint>
+    inline turn_operation_type const& operation_from_rank(RankedPoint const& rp) const
     {
+        return m_turns[rp.turn_index].operations[rp.operation_index];
+    }
+
+    inline sort_by_side::rank_type select_rank(sbs_type const& sbs) const
+    {
+        static bool const is_intersection
+                = target_operation == operation_intersection;
+
         // Take the first outgoing rank corresponding to incoming region,
         // or take another region if it is not isolated
-        turn_operation_type const& incoming_op
-                = operation_from_rank(sbs.m_ranked_points.front());
+        auto const& in_op = operation_from_rank(sbs.m_ranked_points.front());
 
         for (std::size_t i = 0; i < sbs.m_ranked_points.size(); i++)
         {
-            typename sbs_type::rp const& rp = sbs.m_ranked_points[i];
+            auto const& rp = sbs.m_ranked_points[i];
             if (rp.rank == 0 || rp.direction == sort_by_side::dir_from)
             {
                 continue;
             }
-            turn_operation_type const& op = operation_from_rank(rp);
+            auto const& out_op = operation_from_rank(rp);
 
-            if (op.operation != target_operation
-                && op.operation != operation_continue)
+            if (out_op.operation != target_operation
+                && out_op.operation != operation_continue)
             {
                 continue;
             }
 
-            if (op.enriched.region_id == incoming_op.enriched.region_id
-                || (skip_isolated && ! op.enriched.isolated))
+            if (in_op.enriched.region_id == out_op.enriched.region_id
+                || (is_intersection && ! out_op.enriched.isolated))
             {
                 // Region corresponds to incoming region, or (for intersection)
                 // there is a non-isolated other region which should be taken
@@ -687,250 +647,102 @@ public :
     }
 
     inline bool select_from_cluster_union(signed_size_type& turn_index,
+        std::set<signed_size_type> const& cluster_indices,
         int& op_index, sbs_type const& sbs,
         signed_size_type start_turn_index, int start_op_index) const
     {
-        sort_by_side::rank_type const selected_rank = select_rank(sbs, false);
+        sort_by_side::rank_type const selected_rank = select_rank(sbs);
 
-        int best_code = 0;
-        bool result = false;
+        int current_priority = 0;
         for (std::size_t i = 1; i < sbs.m_ranked_points.size(); i++)
         {
             typename sbs_type::rp const& ranked_point = sbs.m_ranked_points[i];
 
             if (ranked_point.rank > selected_rank)
             {
-                // Sorted on rank, so it makes no sense to continue
                 break;
             }
 
-            int const code
-                = select_turn_in_cluster_union(selected_rank, ranked_point,
-                    start_turn_index, start_op_index);
+            int const priority = priority_of_turn_in_cluster_union(selected_rank,
+                ranked_point, cluster_indices, start_turn_index, start_op_index);
 
-            if (code > best_code)
+            if (priority > current_priority)
             {
-                // It is 1 or higher and matching better than previous
-                best_code = code;
+                current_priority = priority;
                 turn_index = ranked_point.turn_index;
                 op_index = ranked_point.operation_index;
-                result = true;
             }
         }
-        return result;
+        return current_priority > 0;
     }
 
     inline bool analyze_cluster_intersection(signed_size_type& turn_index,
                 int& op_index, sbs_type const& sbs) const
     {
-        sort_by_side::rank_type const selected_rank = select_rank(sbs, true);
+        // Select the rank based on regions and isolation
+        sort_by_side::rank_type const selected_rank = select_rank(sbs);
 
-        if (selected_rank > 0)
-        {
-            typename turn_operation_type::comparable_distance_type
-                    min_remaining_distance = 0;
-
-            std::size_t selected_index = sbs.m_ranked_points.size();
-            for (std::size_t i = 0; i < sbs.m_ranked_points.size(); i++)
-            {
-                typename sbs_type::rp const& ranked_point = sbs.m_ranked_points[i];
-
-                if (ranked_point.rank == selected_rank)
-                {
-                    turn_operation_type const& op = operation_from_rank(ranked_point);
-
-                    if (op.visited.finalized())
-                    {
-                        // This direction is already traveled before, the same
-                        // cannot be traveled again
-                        continue;
-                    }
-
-                    // Take turn with the smallest remaining distance
-                    if (selected_index == sbs.m_ranked_points.size()
-                            || op.remaining_distance < min_remaining_distance)
-                    {
-                        selected_index = i;
-                        min_remaining_distance = op.remaining_distance;
-                    }
-                }
-            }
-
-            if (selected_index < sbs.m_ranked_points.size())
-            {
-                typename sbs_type::rp const& ranked_point = sbs.m_ranked_points[selected_index];
-                turn_index = ranked_point.turn_index;
-                op_index = ranked_point.operation_index;
-                return true;
-            }
-        }
-
-        return false;
-    }
-
-    inline signed_size_type get_rank(sbs_type const& sbs,
-            linked_turn_op_info const& info) const
-    {
-        for (std::size_t i = 0; i < sbs.m_ranked_points.size(); i++)
-        {
-            typename sbs_type::rp const& rp = sbs.m_ranked_points[i];
-            if (rp.turn_index == info.turn_index
-                    && rp.operation_index == info.op_index
-                    && rp.direction == sort_by_side::dir_to)
-            {
-                return rp.rank;
-            }
-        }
-        return -1;
-    }
-
-    // Function checks simple cases, such as a cluster with two turns,
-    // arriving at the first turn, first turn points to second turn,
-    // second turn points further.
-    inline bool select_turn_from_cluster_linked(signed_size_type& turn_index,
-            int& op_index,
-            std::set<signed_size_type> const& ids,
-            segment_identifier const& previous_seg_id) const
-    {
-        typedef typename std::set<signed_size_type>::const_iterator sit_type;
-
-        std::vector<linked_turn_op_info> possibilities;
-        std::vector<linked_turn_op_info> blocked;
-        for (sit_type it = ids.begin(); it != ids.end(); ++it)
-        {
-            signed_size_type cluster_turn_index = *it;
-            turn_type const& cluster_turn = m_turns[cluster_turn_index];
-            if (cluster_turn.discarded)
-            {
-                continue;
-            }
-            if (cluster_turn.both(target_operation))
-            {
-                // Not (yet) supported, can be cluster of u/u turns
-                return false;
-            }
-            for (int i = 0; i < 2; i++)
-            {
-                turn_operation_type const& op = cluster_turn.operations[i];
-                turn_operation_type const& other_op = cluster_turn.operations[1 - i];
-                signed_size_type const ni = op.enriched.get_next_turn_index();
-                if (op.operation == target_operation
-                    || op.operation == operation_continue)
-                {
-                    if (ni == cluster_turn_index)
-                    {
-                        // Not (yet) supported, traveling to itself, can be
-                        // hole
-                        return false;
-                    }
-                    possibilities.push_back(
-                        linked_turn_op_info(cluster_turn_index, i, ni));
-                }
-                else if (op.operation == operation_blocked
-                         && ! (ni == other_op.enriched.get_next_turn_index())
-                         && ids.count(ni) == 0)
-                {
-                    // Points to turn, not part of this cluster,
-                    // and that way is blocked. But if the other operation
-                    // points at the same turn, it is still fine.
-                    blocked.push_back(
-                        linked_turn_op_info(cluster_turn_index, i, ni));
-                }
-            }
-        }
-
-        typedef typename std::vector<linked_turn_op_info>::const_iterator const_it_type;
-
-        if (! blocked.empty())
-        {
-            sbs_type sbs(m_strategy);
-
-            if (! fill_sbs(sbs, turn_index, ids, previous_seg_id))
-            {
-                return false;
-            }
-
-            for (typename std::vector<linked_turn_op_info>::iterator it = possibilities.begin();
-                 it != possibilities.end(); ++it)
-            {
-                linked_turn_op_info& info = *it;
-                info.rank_index = get_rank(sbs, info);
-            }
-            for (typename std::vector<linked_turn_op_info>::iterator it = blocked.begin();
-                 it != blocked.end(); ++it)
-            {
-                linked_turn_op_info& info = *it;
-                info.rank_index = get_rank(sbs, info);
-            }
-
-
-            for (const_it_type it = possibilities.begin();
-                 it != possibilities.end(); ++it)
-            {
-                linked_turn_op_info const& lti = *it;
-                for (const_it_type bit = blocked.begin();
-                     bit != blocked.end(); ++bit)
-                {
-                    linked_turn_op_info const& blti = *bit;
-                    if (blti.next_turn_index == lti.next_turn_index
-                            && blti.rank_index == lti.rank_index)
-                    {
-                        return false;
-                    }
-                }
-            }
-        }
-
-        // Traversal can either enter the cluster in the first turn,
-        // or it can start halfway.
-        // If there is one (and only one) possibility pointing outside
-        // the cluster, take that one.
-        linked_turn_op_info target;
-        for (const_it_type it = possibilities.begin();
-             it != possibilities.end(); ++it)
-        {
-            linked_turn_op_info const& lti = *it;
-            if (ids.count(lti.next_turn_index) == 0)
-            {
-                if (target.turn_index >= 0
-                    && target.next_turn_index != lti.next_turn_index)
-                {
-                    // Points to different target
-                    return false;
-                }
-                if (BOOST_GEOMETRY_CONDITION(OverlayType == overlay_buffer)
-                    && target.turn_index > 0)
-                {
-                    // Target already assigned, so there are more targets
-                    // or more ways to the same target
-                    return false;
-                }
-
-                target = lti;
-            }
-        }
-        if (target.turn_index < 0)
+        if (selected_rank <= 0)
         {
             return false;
         }
 
-        turn_index = target.turn_index;
-        op_index = target.op_index;
+        // From these ranks, select the index: the first, or the one with
+        // the smallest remaining distance
+        typename turn_operation_type::comparable_distance_type
+                min_remaining_distance = 0;
 
+        std::size_t selected_index = sbs.m_ranked_points.size();
+        for (std::size_t i = 0; i < sbs.m_ranked_points.size(); i++)
+        {
+            auto const& ranked_point = sbs.m_ranked_points[i];
+
+            if (ranked_point.rank > selected_rank)
+            {
+                break;
+            }
+            else if (ranked_point.rank == selected_rank)
+            {
+                auto const& op = operation_from_rank(ranked_point);
+
+                if (op.visited.finalized())
+                {
+                    // This direction is already traveled,
+                    // it cannot be traveled again
+                    continue;
+                }
+
+                if (selected_index == sbs.m_ranked_points.size()
+                        || op.remaining_distance < min_remaining_distance)
+                {
+                    // It was unassigned or it is better
+                    selected_index = i;
+                    min_remaining_distance = op.remaining_distance;
+                }
+            }
+        }
+
+        if (selected_index == sbs.m_ranked_points.size())
+        {
+            // Should not happen, there must be points with the selected rank
+            return false;
+        }
+
+        auto const& ranked_point = sbs.m_ranked_points[selected_index];
+        turn_index = ranked_point.turn_index;
+        op_index = ranked_point.operation_index;
         return true;
     }
 
     inline bool fill_sbs(sbs_type& sbs,
                          signed_size_type turn_index,
-                         std::set<signed_size_type> const& ids,
+                         std::set<signed_size_type> const& cluster_indices,
                          segment_identifier const& previous_seg_id) const
     {
-        for (typename std::set<signed_size_type>::const_iterator sit = ids.begin();
-             sit != ids.end(); ++sit)
+
+        for (auto cluster_turn_index : cluster_indices)
         {
-            signed_size_type cluster_turn_index = *sit;
             turn_type const& cluster_turn = m_turns[cluster_turn_index];
-            bool const departure_turn = cluster_turn_index == turn_index;
             if (cluster_turn.discarded)
             {
                 // Defensive check, discarded turns should not be in cluster
@@ -939,10 +751,11 @@ public :
 
             for (int i = 0; i < 2; i++)
             {
-                sbs.add(cluster_turn.operations[i],
+                sbs.add(cluster_turn,
+                        cluster_turn.operations[i],
                         cluster_turn_index, i, previous_seg_id,
                         m_geometry1, m_geometry2,
-                        departure_turn);
+                        cluster_turn_index == turn_index);
             }
         }
 
@@ -966,30 +779,37 @@ public :
         turn_type const& turn = m_turns[turn_index];
         BOOST_ASSERT(turn.is_clustered());
 
-        typename Clusters::const_iterator mit = m_clusters.find(turn.cluster_id);
+        auto mit = m_clusters.find(turn.cluster_id);
         BOOST_ASSERT(mit != m_clusters.end());
 
         cluster_info const& cinfo = mit->second;
-        std::set<signed_size_type> const& ids = cinfo.turn_indices;
-
-        if (select_turn_from_cluster_linked(turn_index, op_index, ids, previous_seg_id))
-        {
-            return true;
-        }
 
         sbs_type sbs(m_strategy);
 
-        if (! fill_sbs(sbs, turn_index, ids, previous_seg_id))
+        if (! fill_sbs(sbs, turn_index, cinfo.turn_indices, previous_seg_id))
         {
             return false;
         }
 
+        cluster_exits<OverlayType, Turns, sbs_type> exits(m_turns, cinfo.turn_indices, sbs);
+
+        if (exits.apply(turn_index, op_index))
+        {
+            return true;
+        }
+
         bool result = false;
 
         if (is_union)
         {
-            result = select_from_cluster_union(turn_index, op_index, sbs,
-                start_turn_index, start_op_index);
+            result = select_from_cluster_union(turn_index, cinfo.turn_indices,
+                                               op_index, sbs,
+                                               start_turn_index, start_op_index);
+            if (! result)
+            {
+               // There no way out found, try second pass in collected cluster exits
+               result = exits.apply(turn_index, op_index, false);
+            }
         }
         else
         {
@@ -998,6 +818,7 @@ public :
         return result;
     }
 
+    // Analyzes a non-clustered "ii" intersection, as if it is clustered.
     inline bool analyze_ii_intersection(signed_size_type& turn_index, int& op_index,
                     turn_type const& current_turn,
                     segment_identifier const& previous_seg_id)
@@ -1007,7 +828,8 @@ public :
         // Add this turn to the sort-by-side sorter
         for (int i = 0; i < 2; i++)
         {
-            sbs.add(current_turn.operations[i],
+            sbs.add(current_turn,
+                    current_turn.operations[i],
                     turn_index, i, previous_seg_id,
                     m_geometry1, m_geometry2,
                     true);
@@ -1134,31 +956,43 @@ public :
     {
         turn_type const& current_turn = m_turns[turn_index];
 
+        bool const back_at_start_cluster
+                = has_points
+                && current_turn.is_clustered()
+                && m_turns[start_turn_index].cluster_id == current_turn.cluster_id;
         if (BOOST_GEOMETRY_CONDITION(target_operation == operation_intersection))
         {
-            if (has_points)
-            {
-                bool const back_at_start_cluster
-                        = current_turn.is_clustered()
-                        && m_turns[start_turn_index].cluster_id == current_turn.cluster_id;
+            // Intersection or difference
 
-                if (turn_index == start_turn_index || back_at_start_cluster)
-                {
-                    // Intersection can always be finished if returning
-                    turn_index = start_turn_index;
-                    op_index = start_op_index;
-                    return true;
-                }
+            if (has_points && (turn_index == start_turn_index || back_at_start_cluster))
+            {
+                // Intersection can always be finished if returning
+                turn_index = start_turn_index;
+                op_index = start_op_index;
+                return true;
             }
 
             if (! current_turn.is_clustered()
-                && current_turn.both(operation_intersection))
-            {
-                if (analyze_ii_intersection(turn_index, op_index,
+                && current_turn.both(operation_intersection)
+                && analyze_ii_intersection(turn_index, op_index,
                             current_turn, previous_seg_id))
-                {
-                    return true;
-                }
+            {
+                return true;
+            }
+        }
+        else if (turn_index == start_turn_index || back_at_start_cluster)
+        {
+            // Union or buffer: cannot return immediately to starting turn, because it then
+            // might miss a formed multi polygon with a touching point.
+            auto const& current_op = current_turn.operations[op_index];
+            signed_size_type const next_turn_index = current_op.enriched.get_next_turn_index();
+            bool const to_other_turn = next_turn_index >= 0 && m_turns[next_turn_index].cluster_id != current_turn.cluster_id;
+            if (! to_other_turn)
+            {
+                // Return to starting point
+                turn_index = start_turn_index;
+                op_index = start_op_index;
+                return true;
             }
         }
 
