@@ -11,7 +11,11 @@
 #ifndef BOOST_INTERPROCESS_DETAIL_WINAPI_SEMAPHORE_WRAPPER_HPP
 #define BOOST_INTERPROCESS_DETAIL_WINAPI_SEMAPHORE_WRAPPER_HPP
 
-#if (defined _MSC_VER) && (_MSC_VER >= 1200)
+#ifndef BOOST_CONFIG_HPP
+#  include <boost/config.hpp>
+#endif
+#
+#if defined(BOOST_HAS_PRAGMA_ONCE)
 #  pragma once
 #endif
 
@@ -20,7 +24,7 @@
 #include <boost/interprocess/creation_tags.hpp>
 #include <boost/interprocess/permissions.hpp>
 #include <boost/interprocess/detail/win32_api.hpp>
-#include <boost/interprocess/detail/posix_time_types_wrk.hpp>
+#include <boost/interprocess/sync/windows/winapi_wrapper_common.hpp>
 #include <boost/interprocess/errors.hpp>
 #include <boost/interprocess/exceptions.hpp>
 #include <limits>
@@ -31,12 +35,12 @@ namespace ipcdetail {
 
 class winapi_semaphore_functions
 {
-   /// @cond
+   #if !defined(BOOST_INTERPROCESS_DOXYGEN_INVOKED)
 
    //Non-copyable
    winapi_semaphore_functions(const winapi_semaphore_functions &);
    winapi_semaphore_functions &operator=(const winapi_semaphore_functions &);
-   /// @endcond
+   #endif   //#ifndef BOOST_INTERPROCESS_DOXYGEN_INVOKED
 
    public:
    winapi_semaphore_functions(void *hnd)
@@ -50,48 +54,14 @@ class winapi_semaphore_functions
    }
 
    void wait()
-   {
-      if(winapi::wait_for_single_object(m_sem_hnd, winapi::infinite_time) != winapi::wait_object_0){
-         error_info err = system_error_code();
-         throw interprocess_exception(err);
-      }
-   }
+   {  return winapi_wrapper_wait_for_single_object(m_sem_hnd);  }
 
    bool try_wait()
-   {
-      unsigned long ret = winapi::wait_for_single_object(m_sem_hnd, 0);
-      if(ret == winapi::wait_object_0){
-         return true;
-      }
-      else if(ret == winapi::wait_timeout){
-         return false;
-      }
-      else{
-         error_info err = system_error_code();
-         throw interprocess_exception(err);
-      }
-   }
+   {  return winapi_wrapper_try_wait_for_single_object(m_sem_hnd);  }
 
-   bool timed_wait(const boost::posix_time::ptime &abs_time)
-   {
-      if(abs_time == boost::posix_time::pos_infin){
-         this->wait();
-         return true;
-      }
-
-      unsigned long ret = winapi::wait_for_single_object
-         (m_sem_hnd, (abs_time - microsec_clock::universal_time()).total_milliseconds());
-      if(ret == winapi::wait_object_0){
-         return true;
-      }
-      else if(ret == winapi::wait_timeout){
-         return false;
-      }
-      else{
-         error_info err = system_error_code();
-         throw interprocess_exception(err);
-      }
-   }
+   template<class TimePoint>
+   bool timed_wait(const TimePoint &abs_time)
+   {  return winapi_wrapper_timed_wait_for_single_object(m_sem_hnd, abs_time);  }
 
    long value() const
    {
@@ -109,10 +79,10 @@ class winapi_semaphore_functions
       return l_limit;
    }
 
-   /// @cond
+   #if !defined(BOOST_INTERPROCESS_DOXYGEN_INVOKED)
    protected:
    void *m_sem_hnd;
-   /// @endcond
+   #endif   //#ifndef BOOST_INTERPROCESS_DOXYGEN_INVOKED
 };
 
 
@@ -145,7 +115,8 @@ class winapi_semaphore_wrapper
    void *handle() const
    {  return m_sem_hnd; }
 
-   bool open_or_create( const char *name
+   template <class CharT>
+   bool open_or_create( const CharT *name
                       , long sem_count
                       , long max_count
                       , const permissions &perm
