@@ -2,7 +2,7 @@
 //
 //  See http://www.boost.org for most recent version, including documentation.
 //
-//  Copyright Antony Polukhin, 2013-2021.
+//  Copyright Antony Polukhin, 2013-2023.
 //
 //  Distributed under the Boost
 //  Software License, Version 1.0. (See accompanying file
@@ -14,18 +14,6 @@
 
 #include <boost/any.hpp>
 #include "test.hpp"
-#include <boost/move/move.hpp>
-
-#ifdef BOOST_NO_CXX11_RVALUE_REFERENCES
-
-int main() 
-{
-    BOOST_STATIC_ASSERT(false);
-    return EXIT_SUCCESS;
-}
-
-#else 
-
 
 int main()
 {
@@ -35,5 +23,3 @@ int main()
     return EXIT_SUCCESS;
 }
 
-#endif
-
