@@ -2,7 +2,7 @@
 //
 //  See http://www.boost.org for most recent version, including documentation.
 //
-//  Copyright Antony Polukhin, 2013-2021.
+//  Copyright Antony Polukhin, 2013-2023.
 //
 //  Distributed under the Boost
 //  Software License, Version 1.0. (See accompanying file
@@ -12,18 +12,6 @@
 
 #include "move_test.hpp"
 
-#ifdef BOOST_NO_CXX11_RVALUE_REFERENCES
-
-int main()
-{
-    return EXIT_SUCCESS;
-}
-
-#else
-
 int main() {
     return any_tests::move_tests<boost::any>::run_tests();
 }
-
-#endif
-
