@@ -2,7 +2,7 @@
 // daytime_client.cpp
 // ~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2019 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2023 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -58,7 +58,7 @@ void get_daytime(boost::asio::io_context& io_context, const char* hostname)
         recv_buf.data(),
         recv_length.get()); // Blocks until receive is complete.
   }
-  catch (std::system_error& e)
+  catch (boost::system::system_error& e)
   {
     std::cerr << e.what() << std::endl;
   }
