@@ -2,7 +2,7 @@
 // generic/stream_protocol.cpp
 // ~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2021 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2023 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -20,6 +20,7 @@
 #include <boost/asio/io_context.hpp>
 #include <boost/asio/ip/tcp.hpp>
 #include "../unit_test.hpp"
+#include "../archetypes/async_result.hpp"
 
 #if defined(__cplusplus_cli) || defined(__cplusplus_winrt)
 # define generic cpp_generic
@@ -73,6 +74,7 @@ void test()
     socket_base::message_flags in_flags = 0;
     socket_base::keep_alive socket_option;
     socket_base::bytes_readable io_control_command;
+    archetypes::immediate_handler immediate;
     boost::system::error_code ec;
 
     // basic_stream_socket constructors.
@@ -88,19 +90,15 @@ void test()
 #endif // defined(BOOST_ASIO_WINDOWS_RUNTIME)
     sp::socket socket4(ioc, sp(af_inet, ipproto_tcp), native_socket1);
 
-#if defined(BOOST_ASIO_HAS_MOVE)
     sp::socket socket5(std::move(socket4));
     boost::asio::ip::tcp::socket tcp_socket(ioc);
     sp::socket socket6(std::move(tcp_socket));
-#endif // defined(BOOST_ASIO_HAS_MOVE)
 
     // basic_stream_socket operators.
 
-#if defined(BOOST_ASIO_HAS_MOVE)
     socket1 = sp::socket(ioc);
     socket1 = std::move(socket2);
     socket1 = boost::asio::ip::tcp::socket(ioc);
-#endif // defined(BOOST_ASIO_HAS_MOVE)
 
     // basic_io_object functions.
 
@@ -159,6 +157,7 @@ void test()
     socket1.connect(sp::endpoint(), ec);
 
     socket1.async_connect(sp::endpoint(), connect_handler);
+    socket1.async_connect(sp::endpoint(), immediate);
 
     socket1.set_option(socket_option);
     socket1.set_option(socket_option, ec);
@@ -200,6 +199,12 @@ void test()
     socket1.async_send(buffer(mutable_char_buffer), in_flags, send_handler);
     socket1.async_send(buffer(const_char_buffer), in_flags, send_handler);
     socket1.async_send(null_buffers(), in_flags, send_handler);
+    socket1.async_send(buffer(mutable_char_buffer), immediate);
+    socket1.async_send(buffer(const_char_buffer), immediate);
+    socket1.async_send(null_buffers(), immediate);
+    socket1.async_send(buffer(mutable_char_buffer), in_flags, immediate);
+    socket1.async_send(buffer(const_char_buffer), in_flags, immediate);
+    socket1.async_send(null_buffers(), in_flags, immediate);
 
     socket1.receive(buffer(mutable_char_buffer));
     socket1.receive(null_buffers());
@@ -213,6 +218,11 @@ void test()
     socket1.async_receive(buffer(mutable_char_buffer), in_flags,
         receive_handler);
     socket1.async_receive(null_buffers(), in_flags, receive_handler);
+    socket1.async_receive(buffer(mutable_char_buffer), immediate);
+    socket1.async_receive(null_buffers(), immediate);
+    socket1.async_receive(buffer(mutable_char_buffer), in_flags,
+        immediate);
+    socket1.async_receive(null_buffers(), in_flags, immediate);
 
     socket1.write_some(buffer(mutable_char_buffer));
     socket1.write_some(buffer(const_char_buffer));
@@ -224,6 +234,9 @@ void test()
     socket1.async_write_some(buffer(mutable_char_buffer), write_some_handler);
     socket1.async_write_some(buffer(const_char_buffer), write_some_handler);
     socket1.async_write_some(null_buffers(), write_some_handler);
+    socket1.async_write_some(buffer(mutable_char_buffer), immediate);
+    socket1.async_write_some(buffer(const_char_buffer), immediate);
+    socket1.async_write_some(null_buffers(), immediate);
 
     socket1.read_some(buffer(mutable_char_buffer));
     socket1.read_some(buffer(mutable_char_buffer), ec);
@@ -231,6 +244,8 @@ void test()
 
     socket1.async_read_some(buffer(mutable_char_buffer), read_some_handler);
     socket1.async_read_some(null_buffers(), read_some_handler);
+    socket1.async_read_some(buffer(mutable_char_buffer), immediate);
+    socket1.async_read_some(null_buffers(), immediate);
   }
   catch (std::exception&)
   {
@@ -244,5 +259,5 @@ void test()
 BOOST_ASIO_TEST_SUITE
 (
   "generic/stream_protocol",
-  BOOST_ASIO_TEST_CASE(generic_stream_protocol_socket_compile::test)
+  BOOST_ASIO_COMPILE_TEST_CASE(generic_stream_protocol_socket_compile::test)
 )
