@@ -2,7 +2,7 @@
 // address.cpp
 // ~~~~~~~~~~~
 //
-// Copyright (c) 2003-2021 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2023 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -128,10 +128,8 @@ void test()
     wos << addr1;
 #endif // !defined(BOOST_NO_STD_WSTREAMBUF)
 
-#if defined(BOOST_ASIO_HAS_STD_HASH)
     std::size_t hash1 = std::hash<ip::address>()(addr1);
     (void)hash1;
-#endif // defined(BOOST_ASIO_HAS_STD_HASH)
   }
   catch (std::exception&)
   {
@@ -145,5 +143,5 @@ void test()
 BOOST_ASIO_TEST_SUITE
 (
   "ip/address",
-  BOOST_ASIO_TEST_CASE(ip_address_compile::test)
+  BOOST_ASIO_COMPILE_TEST_CASE(ip_address_compile::test)
 )
