@@ -2,7 +2,7 @@
 // read_until.cpp
 // ~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2021 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2023 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -17,18 +17,13 @@
 #include <boost/asio/read_until.hpp>
 
 #include <cstring>
+#include <functional>
 #include "archetypes/async_result.hpp"
 #include <boost/asio/io_context.hpp>
 #include <boost/asio/post.hpp>
 #include <boost/asio/streambuf.hpp>
 #include "unit_test.hpp"
 
-#if defined(BOOST_ASIO_HAS_BOOST_BIND)
-# include <boost/bind/bind.hpp>
-#else // defined(BOOST_ASIO_HAS_BOOST_BIND)
-# include <functional>
-#endif // defined(BOOST_ASIO_HAS_BOOST_BIND)
-
 class test_stream
 {
 public:
@@ -42,7 +37,7 @@ public:
   {
   }
 
-  executor_type get_executor() BOOST_ASIO_NOEXCEPT
+  executor_type get_executor() noexcept
   {
     return io_context_.get_executor();
   }
@@ -88,7 +83,7 @@ public:
     size_t bytes_transferred = read_some(buffers);
     boost::asio::post(get_executor(),
         boost::asio::detail::bind_handler(
-          BOOST_ASIO_MOVE_CAST(Handler)(handler),
+          static_cast<Handler&&>(handler),
           boost::system::error_code(), bytes_transferred));
   }
 
@@ -675,11 +670,7 @@ void async_read_handler(
 
 void test_dynamic_string_async_read_until_char()
 {
-#if defined(BOOST_ASIO_HAS_BOOST_BIND)
-  namespace bindns = boost;
-#else // defined(BOOST_ASIO_HAS_BOOST_BIND)
   namespace bindns = std;
-#endif // defined(BOOST_ASIO_HAS_BOOST_BIND)
   using bindns::placeholders::_1;
   using bindns::placeholders::_2;
 
@@ -838,11 +829,7 @@ void test_dynamic_string_async_read_until_char()
 void test_streambuf_async_read_until_char()
 {
 #if !defined(BOOST_ASIO_NO_DYNAMIC_BUFFER_V1)
-#if defined(BOOST_ASIO_HAS_BOOST_BIND)
-  namespace bindns = boost;
-#else // defined(BOOST_ASIO_HAS_BOOST_BIND)
   namespace bindns = std;
-#endif // defined(BOOST_ASIO_HAS_BOOST_BIND)
   using bindns::placeholders::_1;
   using bindns::placeholders::_2;
 
@@ -998,11 +985,7 @@ void test_streambuf_async_read_until_char()
 
 void test_dynamic_string_async_read_until_string()
 {
-#if defined(BOOST_ASIO_HAS_BOOST_BIND)
-  namespace bindns = boost;
-#else // defined(BOOST_ASIO_HAS_BOOST_BIND)
   namespace bindns = std;
-#endif // defined(BOOST_ASIO_HAS_BOOST_BIND)
   using bindns::placeholders::_1;
   using bindns::placeholders::_2;
 
@@ -1161,11 +1144,7 @@ void test_dynamic_string_async_read_until_string()
 void test_streambuf_async_read_until_string()
 {
 #if !defined(BOOST_ASIO_NO_DYNAMIC_BUFFER_V1)
-#if defined(BOOST_ASIO_HAS_BOOST_BIND)
-  namespace bindns = boost;
-#else // defined(BOOST_ASIO_HAS_BOOST_BIND)
   namespace bindns = std;
-#endif // defined(BOOST_ASIO_HAS_BOOST_BIND)
   using bindns::placeholders::_1;
   using bindns::placeholders::_2;
 
@@ -1321,11 +1300,7 @@ void test_streambuf_async_read_until_string()
 
 void test_dynamic_string_async_read_until_match_condition()
 {
-#if defined(BOOST_ASIO_HAS_BOOST_BIND)
-  namespace bindns = boost;
-#else // defined(BOOST_ASIO_HAS_BOOST_BIND)
   namespace bindns = std;
-#endif // defined(BOOST_ASIO_HAS_BOOST_BIND)
   using bindns::placeholders::_1;
   using bindns::placeholders::_2;
 
@@ -1484,11 +1459,7 @@ void test_dynamic_string_async_read_until_match_condition()
 void test_streambuf_async_read_until_match_condition()
 {
 #if !defined(BOOST_ASIO_NO_DYNAMIC_BUFFER_V1)
-#if defined(BOOST_ASIO_HAS_BOOST_BIND)
-  namespace bindns = boost;
-#else // defined(BOOST_ASIO_HAS_BOOST_BIND)
   namespace bindns = std;
-#endif // defined(BOOST_ASIO_HAS_BOOST_BIND)
   using bindns::placeholders::_1;
   using bindns::placeholders::_2;
 
