@@ -2,7 +2,7 @@
 // stream_file.cpp
 // ~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2022 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2023 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -31,22 +31,18 @@ struct write_some_handler
 {
   write_some_handler() {}
   void operator()(const boost::system::error_code&, std::size_t) {}
-#if defined(BOOST_ASIO_HAS_MOVE)
   write_some_handler(write_some_handler&&) {}
 private:
   write_some_handler(const write_some_handler&);
-#endif // defined(BOOST_ASIO_HAS_MOVE)
 };
 
 struct read_some_handler
 {
   read_some_handler() {}
   void operator()(const boost::system::error_code&, std::size_t) {}
-#if defined(BOOST_ASIO_HAS_MOVE)
   read_some_handler(read_some_handler&&) {}
 private:
   read_some_handler(const read_some_handler&);
-#endif // defined(BOOST_ASIO_HAS_MOVE)
 };
 
 void test()
@@ -78,16 +74,16 @@ void test()
     stream_file::native_handle_type native_file2 = file1.native_handle();
     stream_file file8(ioc_ex, native_file2);
 
-#if defined(BOOST_ASIO_HAS_MOVE)
     stream_file file9(std::move(file8));
-#endif // defined(BOOST_ASIO_HAS_MOVE)
+
+    basic_stream_file<io_context::executor_type> file10(ioc);
+    stream_file file11(std::move(file10));
 
     // basic_stream_file operators.
 
-#if defined(BOOST_ASIO_HAS_MOVE)
     file1 = stream_file(ioc);
     file1 = std::move(file2);
-#endif // defined(BOOST_ASIO_HAS_MOVE)
+    file1 = std::move(file10);
 
     // basic_io_object functions.
 
