@@ -4,7 +4,7 @@
  * Boost Software License, Version 1.0. (See accompanying
  * file LICENSE_1_0.txt or http://www.boost.org/LICENSE_1_0.txt)
  * Author: Jeff Garland, Bart Garst
- * $Date: 2012-07-27 11:15:55 -0700 (Fri, 27 Jul 2012) $
+ * $Date$
  */
 
 #include "boost/date_time/posix_time/posix_time.hpp"
@@ -220,8 +220,8 @@ int main() {
     // not dereference end() iterator for the format string in do_put_tm.
     {
       boost::gregorian::date date(2009, 1, 1);
-      boost::posix_time::time_duration td(0, 0, 0, 0);
-      boost::posix_time::ptime boost_time(date, td);
+      boost::posix_time::time_duration tdx(0, 0, 0, 0);
+      boost::posix_time::ptime boost_time(date, tdx);
       std::stringstream sstr;
     
       boost::posix_time::time_facet* pFacet = new boost::posix_time::time_facet("");
