@@ -67,8 +67,9 @@ void test_all()
         1, 5, 8.0);
 
     {
+        // Sym difference works, but expectations are different for rescaling
         ut_settings settings;
-        settings.validity_false_negative_sym = true;
+        settings.sym_difference = false;
         test_one<polygon, polygon, polygon>("star_comb_15",
             star_comb_15[0], star_comb_15[1],
             30, -1, 227.658275102812,
@@ -92,7 +93,6 @@ void test_all()
         1, 5, 1.0,
         1, 5, 1.0);
 
-#if defined(BOOST_GEOMETRY_USE_RESCALING) || defined(BOOST_GEOMETRY_TEST_FAILURES)
     // Two outputs, but the small one might be discarded
     // (depending on point-type / compiler)
     test_one<polygon, polygon, polygon>("distance_zero",
@@ -100,7 +100,6 @@ void test_all()
         count_set(1, 2), -1, 8.7048386,
         count_set(1, 2), -1, 0.0098387,
         tolerance(0.001));
-#endif
 
     test_one<polygon, polygon, polygon>("equal_holes_disjoint",
         equal_holes_disjoint[0], equal_holes_disjoint[1],
@@ -584,6 +583,8 @@ void test_all()
 #endif
     TEST_DIFFERENCE(issue_876b, 1, 6114.18234, 1, 4754.29449, count_set(1, 2));
 
+    TEST_DIFFERENCE(issue_1138, 1, 203161.751, 2, 1237551.0171, 1);
+
     TEST_DIFFERENCE(mysql_21977775, 2, 160.856568913, 2, 92.3565689126, 4);
     TEST_DIFFERENCE(mysql_21965285, 1, 92.0, 1, 14.0, 1);
     TEST_DIFFERENCE(mysql_23023665_1, 1, 92.0, 1, 142.5, 2);
@@ -599,7 +600,7 @@ void test_all()
     {
         ut_settings settings;
         settings.validity_false_negative_sym = true;
-        TEST_DIFFERENCE_WITH(mysql_23023665_13, 3, 99.74526, 3, 37.74526, 6, settings);
+        TEST_DIFFERENCE_WITH(mysql_23023665_13, 3, 99.74526, 3, 37.74526, count_set(5, 6), settings);
     }
 }
 
@@ -612,9 +613,9 @@ void test_specific()
 
     test_one<polygon, polygon, polygon>("ggl_list_20120717_volker",
         ggl_list_20120717_volker[0], ggl_list_20120717_volker[1],
-        1, 11, 3371540,
-        1, 4, 385,
-        1, 16, 3371540 + 385);
+        1, 11, 3370444,
+        1, 4, 383,
+        2, 16, 3370444 + 383);
 
     test_one<polygon, polygon, polygon>("ticket_10658",
         ticket_10658[0], ticket_10658[1],
@@ -623,11 +624,12 @@ void test_specific()
 
     test_one<polygon, polygon, polygon>("ticket_11121",
         ticket_11121[0], ticket_11121[1],
-        2, 8, 489763.5,
-        1, 4, 6731652.0);
+        2, 8, 489904.5,
+        1, 4, 6755355,
+        1);
 
     // Generates spikes, both a-b and b-a
-    TEST_DIFFERENCE(ticket_11676, 2, 2537992.5, 2, 294963.5, 3);
+    TEST_DIFFERENCE(ticket_11676, 2, 2537404.5, 2, 295353, 3);
 }
 
 int test_main(int, char* [])
