@@ -2,7 +2,7 @@
 // Unit Test
 
 // Copyright (c) 2007-2015 Barend Gehrels, Amsterdam, the Netherlands.
-// Copyright (c) 2017 Adam Wulkiewicz, Lodz, Poland.
+// Copyright (c) 2017-2023 Adam Wulkiewicz, Lodz, Poland.
 
 // This file was modified by Oracle on 2016-2020.
 // Modifications copyright (c) 2016-2020, Oracle and/or its affiliates.
@@ -25,7 +25,6 @@
 #include "../setop_output_type.hpp"
 
 #include <boost/core/ignore_unused.hpp>
-#include <boost/foreach.hpp>
 
 #include <boost/range/algorithm/copy.hpp>
 #include <boost/range/size.hpp>
@@ -60,20 +59,45 @@
 #  include <boost/geometry/algorithms/detail/overlay/debug_turn_info.hpp>
 #endif
 
+enum difference_type
+{
+    difference_a, difference_b, difference_sym
+};
 
 struct ut_settings : ut_base_settings
 {
     double percentage;
     bool sym_difference;
-    bool remove_spikes;
+    bool validity_of_sym = true;
+    bool remove_spikes = false;
 
-    explicit ut_settings(double p = 0.0001, bool tv = true, bool sd = true)
-        : ut_base_settings(tv)
+    // The validity check gives sometimes false negatives.
+    // boost::geometry::is_valid can return FALSE while it is valid.
+    // (especially at touch in combination with a u/u turn)
+    // For now, the cases where this is the case are skipped for validity check.
+    bool validity_false_negative_a = false;
+    bool validity_false_negative_b = false;
+    bool validity_false_negative_sym = false;
+
+    explicit ut_settings(double p = 0.0001, bool validity = true, bool sd = true)
+        : ut_base_settings(validity)
         , percentage(p)
         , sym_difference(sd)
-        , remove_spikes(false)
     {}
 
+    bool test_validity_of_diff(difference_type dtype) const
+    {
+        bool const sym = dtype == difference_sym;
+        bool const a = dtype == difference_a;
+        bool const b = dtype == difference_b;
+
+        return sym && validity_false_negative_sym ? false
+            : a && validity_false_negative_a ? false
+            : b && validity_false_negative_b ? false
+            : sym ? (validity_of_sym || BG_IF_TEST_FAILURES)
+            : test_validity();
+    }
+
 };
 
 inline ut_settings tolerance(double percentage)
@@ -123,9 +147,9 @@ void difference_output(std::string const& caseid, G1 const& g1, G2 const& g2, Ou
         mapper.map(g2, "fill-opacity:0.5;fill:rgb(153,204,0);stroke:rgb(153,204,0);stroke-width:3");
 
 
-        for (typename Output::const_iterator it = output.begin(); it != output.end(); ++it)
+        for (auto const& item : output)
         {
-            mapper.map(*it,
+            mapper.map(item,
                 //sym ? "fill-opacity:0.2;stroke-opacity:0.4;fill:rgb(255,255,0);stroke:rgb(255,0,255);stroke-width:8" :
                 "fill-opacity:0.2;stroke-opacity:0.4;fill:rgb(255,0,0);stroke:rgb(255,0,255);stroke-width:8");
         }
@@ -135,19 +159,19 @@ void difference_output(std::string const& caseid, G1 const& g1, G2 const& g2, Ou
 
 template <typename OutputType, typename G1, typename G2>
 std::string test_difference(std::string const& caseid, G1 const& g1, G2 const& g2,
-        const count_set& expected_count,
+        count_set const& expected_count,
         int expected_rings_count, int expected_point_count,
         expectation_limits const& expected_area,
-        bool sym,
+        difference_type dtype,
         ut_settings const& settings)
 {
     typedef typename bg::coordinate_type<G1>::type coordinate_type;
     boost::ignore_unused<coordinate_type>();
+    boost::ignore_unused(expected_point_count);
 
     bg::model::multi_polygon<OutputType> result;
 
-
-    if (sym)
+    if (dtype == difference_sym)
     {
         bg::sym_difference(g1, g2, result);
     }
@@ -168,7 +192,7 @@ std::string test_difference(std::string const& caseid, G1 const& g1, G2 const& g
             <
                 G1, G2
             >::type strategy_type;
-        if (sym)
+        if (dtype == difference_sym)
         {
             bg::sym_difference(g1, g2, result_s, strategy_type());
         }
@@ -192,7 +216,7 @@ std::string test_difference(std::string const& caseid, G1 const& g1, G2 const& g
     typename bg::default_area_result<G1>::type const area = bg::area(result);
 
 #if ! defined(BOOST_GEOMETRY_NO_BOOST_TEST)
-    if (settings.test_validity())
+    if (settings.test_validity_of_diff(dtype))
     {
         // std::cout << bg::dsv(result) << std::endl;
         typedef bg::model::multi_polygon<OutputType> result_type;
@@ -214,7 +238,7 @@ std::string test_difference(std::string const& caseid, G1 const& g1, G2 const& g
         typename setop_output_type<OutputType>::type
             inserted, array_with_one_empty_geometry;
         array_with_one_empty_geometry.push_back(OutputType());
-        if (sym)
+        if (dtype == difference_sym)
         {
             boost::copy(array_with_one_empty_geometry,
                 bg::detail::sym_difference::sym_difference_insert<OutputType>
@@ -281,14 +305,14 @@ std::string test_difference(std::string const& caseid, G1 const& g1, G2 const& g
 
 template <typename OutputType, typename G1, typename G2>
 std::string test_difference(std::string const& caseid, G1 const& g1, G2 const& g2,
-        const count_set&  expected_count, int expected_point_count,
+        count_set const&  expected_count, int expected_point_count,
         expectation_limits const& expected_area,
-        bool sym,
+        difference_type dtype,
         ut_settings const& settings)
 {
     return test_difference<OutputType>(caseid, g1, g2,
         expected_count, -1, expected_point_count, expected_area,
-        sym, settings);
+        dtype, settings);
 }
 
 #ifdef BOOST_GEOMETRY_CHECK_WITH_POSTGIS
@@ -299,15 +323,15 @@ static int counter = 0;
 template <typename OutputType, typename G1, typename G2>
 std::string test_one(std::string const& caseid,
         std::string const& wkt1, std::string const& wkt2,
-        const count_set& expected_count1,
+        count_set const& expected_count1,
         int expected_rings_count1,
         int expected_point_count1,
         expectation_limits const& expected_area1,
-        const count_set& expected_count2,
+        count_set const& expected_count2,
         int expected_rings_count2,
         int expected_point_count2,
         expectation_limits const& expected_area2,
-        const count_set&  expected_count_s,
+        count_set const&  expected_count_s,
         int expected_rings_count_s,
         int expected_point_count_s,
         expectation_limits const& expected_area_s,
@@ -322,17 +346,24 @@ std::string test_one(std::string const& caseid,
     bg::correct(g1);
     bg::correct(g2);
 
-    std::string result = test_difference<OutputType>(caseid + "_a", g1, g2,
-        expected_count1, expected_rings_count1, expected_point_count1,
-        expected_area1, false, settings);
+    std::string result;
 
-#ifdef BOOST_GEOMETRY_DEBUG_ASSEMBLE
+#if ! defined(BOOST_GEOMETRY_TEST_DIFFERENCE_ONLY_B)
+    result = test_difference<OutputType>(caseid + "_a", g1, g2,
+        expected_count1, expected_rings_count1, expected_point_count1,
+        expected_area1, difference_a, settings);
+#endif
+#if defined(BOOST_GEOMETRY_TEST_DIFFERENCE_ONLY_A)
     return result;
 #endif
 
     test_difference<OutputType>(caseid + "_b", g2, g1,
         expected_count2, expected_rings_count2, expected_point_count2,
-        expected_area2, false, settings);
+        expected_area2, difference_b, settings);
+
+#if defined(BOOST_GEOMETRY_TEST_DIFFERENCE_ONLY_B)
+    return result;
+#endif
 
 #if ! defined(BOOST_GEOMETRY_TEST_ALWAYS_CHECK_SYMDIFFERENCE)
     if (settings.sym_difference)
@@ -343,7 +374,7 @@ std::string test_one(std::string const& caseid,
             expected_rings_count_s,
             expected_point_count_s,
             expected_area_s,
-            true, settings);
+            difference_sym, settings);
     }
     return result;
 }
@@ -351,11 +382,11 @@ std::string test_one(std::string const& caseid,
 template <typename OutputType, typename G1, typename G2>
 std::string test_one(std::string const& caseid,
         std::string const& wkt1, std::string const& wkt2,
-        const count_set&  expected_count1,
+        count_set const&  expected_count1,
         int expected_rings_count1,
         int expected_point_count1,
         expectation_limits const& expected_area1,
-        const count_set&  expected_count2,
+        count_set const&  expected_count2,
         int expected_rings_count2,
         int expected_point_count2,
         expectation_limits const& expected_area2,
@@ -372,16 +403,17 @@ std::string test_one(std::string const& caseid,
         settings);
 }
 
+// Version with expectations of symmetric: all specified
 template <typename OutputType, typename G1, typename G2>
 std::string test_one(std::string const& caseid,
         std::string const& wkt1, std::string const& wkt2,
-        const count_set&  expected_count1,
+        count_set const&  expected_count1,
         int expected_point_count1,
         expectation_limits const& expected_area1,
-        const count_set&  expected_count2,
+        count_set const&  expected_count2,
         int expected_point_count2,
         expectation_limits const& expected_area2,
-        const count_set&  expected_count_s,
+        count_set const&  expected_count_s,
         int expected_point_count_s,
         expectation_limits const& expected_area_s,
         ut_settings const& settings = ut_settings())
@@ -393,13 +425,37 @@ std::string test_one(std::string const& caseid,
         settings);
 }
 
+// Version with expectations of symmetric: specify only count
 template <typename OutputType, typename G1, typename G2>
 std::string test_one(std::string const& caseid,
         std::string const& wkt1, std::string const& wkt2,
-        const count_set&  expected_count1,
+        count_set const&  expected_count1,
         int expected_point_count1,
         expectation_limits const& expected_area1,
-        const count_set&  expected_count2,
+        count_set const&  expected_count2,
+        int expected_point_count2,
+        expectation_limits const& expected_area2,
+        count_set const&  expected_count_s,
+        ut_settings const& settings = ut_settings())
+{
+    return test_one<OutputType, G1, G2>(caseid, wkt1, wkt2,
+        expected_count1, -1, expected_point_count1, expected_area1,
+        expected_count2, -1, expected_point_count2, expected_area2,
+        expected_count_s, -1,
+        expected_point_count1 >= 0 && expected_point_count2 >= 0
+            ? (expected_point_count1 + expected_point_count2) : -1,
+        expected_area1 + expected_area2,
+        settings);
+}
+
+// Version with expectations of symmetric: all automatically
+template <typename OutputType, typename G1, typename G2>
+std::string test_one(std::string const& caseid,
+        std::string const& wkt1, std::string const& wkt2,
+        count_set const&  expected_count1,
+        int expected_point_count1,
+        expectation_limits const& expected_area1,
+        count_set const&  expected_count2,
         int expected_point_count2,
         expectation_limits const& expected_area2,
         ut_settings const& settings = ut_settings())
