@@ -5,8 +5,8 @@
 // Copyright (c) 2008-2015 Bruno Lalande, Paris, France.
 // Copyright (c) 2009-2015 Mateusz Loskot, London, UK.
 
-// This file was modified by Oracle on 2015-2021.
-// Modifications copyright (c) 2015-2021, Oracle and/or its affiliates.
+// This file was modified by Oracle on 2015-2022.
+// Modifications copyright (c) 2015-2022, Oracle and/or its affiliates.
 // Contributed and/or modified by Menelaos Karavelas, on behalf of Oracle
 // Contributed and/or modified by Adam Wulkiewicz, on behalf of Oracle
 
@@ -472,25 +472,6 @@ void test_areal_clip()
 }
 
 
-template <typename Box>
-void test_boxes(std::string const& wkt1, std::string const& wkt2, double expected_area, bool expected_result)
-{
-    Box box1, box2;
-    bg::read_wkt(wkt1, box1);
-    bg::read_wkt(wkt2, box2);
-
-    Box box_out;
-    bg::assign_zero(box_out);
-    bool detected = bg::intersection(box1, box2, box_out);
-    typename bg::default_area_result<Box>::type area = bg::area(box_out);
-
-    BOOST_CHECK_EQUAL(detected, expected_result);
-    if (detected && expected_result)
-    {
-        BOOST_CHECK_CLOSE(area, expected_area, 0.01);
-    }
-}
-
 template <typename P>
 void test_point_output()
 {
@@ -739,7 +720,7 @@ void test_all()
         1, 7, 5.47363293);
 #endif
 
-       // Basic check: box/linestring, is clipping OK? should compile in any order
+    // Basic check: box/linestring, is clipping OK? should compile in any order
     test_one<linestring, linestring, box>("llb", "LINESTRING(0 0,10 10)", clip, 1, 2, sqrt(2.0 * 6.0 * 6.0));
     test_one<linestring, box, linestring>("lbl", clip, "LINESTRING(0 0,10 10)", 1, 2, sqrt(2.0 * 6.0 * 6.0));
 
@@ -771,21 +752,14 @@ void test_all()
 
     // polygons outputing points
     //test_one<P, polygon, polygon>("ppp1", simplex_normal[0], simplex_normal[1], 1, 7, 5.47363293);
-
-    test_boxes<box>("box(2 2,8 8)", "box(4 4,10 10)", 16, true);
-    test_boxes<box>("box(2 2,8 7)", "box(4 4,10 10)", 12, true);
-    test_boxes<box>("box(2 2,8 7)", "box(14 4,20 10)", 0, false);
-    test_boxes<box>("box(2 2,4 4)", "box(4 4,8 8)", 0, true);
-
+    
     test_point_output<P>();
 
-
     /*
     test_one<polygon, box, polygon>(99, "box(115041.10 471900.10, 118334.60 474523.40)",
             "POLYGON ((115483.40 474533.40, 116549.40 474059.20, 117199.90 473762.50, 117204.90 473659.50, 118339.40 472796.90, 118334.50 472757.90, 118315.10 472604.00, 118344.60 472520.90, 118277.90 472419.10, 118071.40 472536.80, 118071.40 472536.80, 117943.10 472287.70, 117744.90 472248.40, 117708.00 472034.50, 117481.90 472056.90, 117481.90 472056.90, 117272.30 471890.10, 117077.90 472161.20, 116146.60 473054.50, 115031.10 473603.30, 115483.40 474533.40))",
                 1, 26, 3727690.74);
     */
-
 }
 
 void test_pointer_version()
@@ -852,62 +826,6 @@ void test_rational()
         1, 7, 5.47363293);
 }
 
-
-template <typename P>
-void test_boxes_per_d(P const& min1, P const& max1, P const& min2, P const& max2, bool expected_result)
-{
-    typedef bg::model::box<P> box;
-    
-    box box_out;
-    bool detected = bg::intersection(box(min1, max1), box(min2, max2), box_out);
-
-    BOOST_CHECK_EQUAL(detected, expected_result);
-    if ( detected && expected_result )
-    {
-        BOOST_CHECK( bg::equals(box_out, box(min2,max1)) );
-    }
-}
-
-template <typename CoordinateType>
-void test_boxes_nd()
-{
-    typedef bg::model::point<CoordinateType, 1, bg::cs::cartesian> p1;
-    typedef bg::model::point<CoordinateType, 2, bg::cs::cartesian> p2;
-    typedef bg::model::point<CoordinateType, 3, bg::cs::cartesian> p3;
-
-    test_boxes_per_d(p1(0), p1(5), p1(3), p1(6), true);
-    test_boxes_per_d(p2(0,0), p2(5,5), p2(3,3), p2(6,6), true);
-    test_boxes_per_d(p3(0,0,0), p3(5,5,5), p3(3,3,3), p3(6,6,6), true);
-}
-
-
-template <typename CoordinateType>
-void test_ticket_10868(std::string const& wkt_out)
-{
-    typedef bg::model::point<CoordinateType, 2, bg::cs::cartesian> point_type;
-    typedef bg::model::polygon
-        <
-            point_type, /*ClockWise*/false, /*Closed*/false
-        > polygon_type;
-    typedef bg::model::multi_polygon<polygon_type> multipolygon_type;
-
-    polygon_type polygon1;
-    bg::read_wkt(ticket_10868[0], polygon1);
-    polygon_type polygon2;
-    bg::read_wkt(ticket_10868[1], polygon2);
-
-    multipolygon_type multipolygon_out;
-    bg::intersection(polygon1, polygon2, multipolygon_out);
-    std::stringstream stream;
-    stream << bg::wkt(multipolygon_out);
-
-    BOOST_CHECK_EQUAL(stream.str(), wkt_out);
-
-    test_one<polygon_type, polygon_type, polygon_type>("ticket_10868",
-        ticket_10868[0], ticket_10868[1],
-        1, 7, 20266195244586.0);
-}
-
 int test_main(int, char* [])
 {
     BoostGeometryWriteTestConfiguration();
@@ -924,23 +842,6 @@ int test_main(int, char* [])
     test_rational<bg::model::d2::point_xy<boost::rational<int> > >();
 #endif
 
-    test_boxes_nd<double>();
-
-#if defined(BOOST_GEOMETRY_TEST_FAILURES)
-    // ticket #10868 still fails for 32-bit integers
-    test_ticket_10868<int32_t>("MULTIPOLYGON(((33520458 6878575,33480192 14931538,31446819 18947953,30772384 19615678,30101303 19612322,30114725 16928001,33520458 6878575)))");
-
-#if !defined(BOOST_NO_INT64_T) || defined(BOOST_HAS_MS_INT64)
-    test_ticket_10868<int64_t>("MULTIPOLYGON(((33520458 6878575,33480192 14931538,31446819 18947953,30772384 19615678,30101303 19612322,30114725 16928001,33520458 6878575)))");
-#endif
-
-    if (BOOST_GEOMETRY_CONDITION(sizeof(long) * CHAR_BIT >= 64))
-    {
-        test_ticket_10868<long>("MULTIPOLYGON(((33520458 6878575,33480192 14931538,31446819 18947953,30772384 19615678,30101303 19612322,30114725 16928001,33520458 6878575)))");
-    }
-
-    test_ticket_10868<long long>("MULTIPOLYGON(((33520458 6878575,33480192 14931538,31446819 18947953,30772384 19615678,30101303 19612322,30114725 16928001,33520458 6878575)))");
-#endif
 #endif
 
 #if defined(BOOST_GEOMETRY_TEST_FAILURES)
