@@ -6,7 +6,9 @@
 
 //[code_bron_kerbosch_clique_number
 #include <iostream>
-
+#ifdef _MSC_VER
+#define _CRT_SECURE_NO_WARNINGS
+#endif
 #include <boost/graph/undirected_graph.hpp>
 #include <boost/graph/bron_kerbosch_all_cliques.hpp>
 
@@ -17,11 +19,10 @@ using namespace boost;
 
 // Declare the graph type and its vertex and edge types.
 typedef undirected_graph<> Graph;
-typedef graph_traits<Graph>::vertex_descriptor Vertex;
-typedef graph_traits<Graph>::edge_descriptor Edge;
+typedef graph_traits< Graph >::vertex_descriptor Vertex;
+typedef graph_traits< Graph >::edge_descriptor Edge;
 
-int
-main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
     // Create the graph and read it from standard input.
     Graph g;
