@@ -1,48 +1,22 @@
 var group__group_datatypes =
 [
     [ "integral_constant", "structboost_1_1hana_1_1integral__constant.html", [
-      [ "bool_", "structboost_1_1hana_1_1integral__constant.html#adeaf00ee03ae0daf97d60d5258bd3703", null ],
-      [ "true_", "structboost_1_1hana_1_1integral__constant.html#ae0cf9368270efc7fdd2aeec497644892", null ],
-      [ "false_", "structboost_1_1hana_1_1integral__constant.html#a84a8b7c3f824b4f0421d6a834601a0c4", null ],
-      [ "char_", "structboost_1_1hana_1_1integral__constant.html#a08598ceb1797047d8938049b0cad6ccc", null ],
-      [ "short_", "structboost_1_1hana_1_1integral__constant.html#a217459eb4ffdd9580b5d8e1bf36d7ac4", null ],
-      [ "ushort_", "structboost_1_1hana_1_1integral__constant.html#a69a1bcadc259af364eb87d634c76c12e", null ],
-      [ "int_", "structboost_1_1hana_1_1integral__constant.html#ab4891bf3aec7c15fa2d91c8fbacf4563", null ],
-      [ "uint", "structboost_1_1hana_1_1integral__constant.html#a5071dd223185718f85da1db48fb95d80", null ],
-      [ "long_", "structboost_1_1hana_1_1integral__constant.html#a41f541c4b34b1972d0e84bf10f7908e1", null ],
-      [ "ulong", "structboost_1_1hana_1_1integral__constant.html#aedb2b03831973b4b54c5d0abce1af63c", null ],
-      [ "llong", "structboost_1_1hana_1_1integral__constant.html#aa7bf152c582934a70baa1d6c2bc758ba", null ],
-      [ "ullong", "structboost_1_1hana_1_1integral__constant.html#a112e62e2d698846ca9e3940eb15333d3", null ],
-      [ "size_t", "structboost_1_1hana_1_1integral__constant.html#a022e29dcd19f546f3ac35254f11e56de", null ],
       [ "integral_c", "structboost_1_1hana_1_1integral__constant.html#a8e52c0f4a65a852dc88f97259a05ff17", null ],
-      [ "bool_c", "structboost_1_1hana_1_1integral__constant.html#aa301b96de91d665fdc846bde4659b0d3", null ],
-      [ "true_c", "structboost_1_1hana_1_1integral__constant.html#a96c109b048f822be0ca7578c93694405", null ],
-      [ "false_c", "structboost_1_1hana_1_1integral__constant.html#aec1a5deaa7bcdf7c07c2da4af8959454", null ],
-      [ "char_c", "structboost_1_1hana_1_1integral__constant.html#aca22320011be96155645b79fe53dd8c2", null ],
-      [ "short_c", "structboost_1_1hana_1_1integral__constant.html#aaf48189e927611ea460974ba01beb2c7", null ],
-      [ "ushort_c", "structboost_1_1hana_1_1integral__constant.html#ace7c983d1ffed3a1ff10b5287d2c6ddd", null ],
-      [ "int_c", "structboost_1_1hana_1_1integral__constant.html#a8669179fa3d068951014b3be07a7d673", null ],
-      [ "uint_c", "structboost_1_1hana_1_1integral__constant.html#a79f45e3c2411db1d36127c1341673ffb", null ],
-      [ "long_c", "structboost_1_1hana_1_1integral__constant.html#ab7e3b17ac89121823916ebd7c6f96235", null ],
-      [ "ulong_c", "structboost_1_1hana_1_1integral__constant.html#a65df6bbd2d90432bdcdc709cdbca9921", null ],
-      [ "llong_c", "structboost_1_1hana_1_1integral__constant.html#a81c86537a0d36b8788cba2188314febc", null ],
-      [ "ullong_c", "structboost_1_1hana_1_1integral__constant.html#a186b6fdf81c9be08f42576cafd63b38d", null ],
-      [ "size_c", "structboost_1_1hana_1_1integral__constant.html#ac49b8fd71a0ef9229511bd7d6cc0f150", null ],
-      [ "operator+", "structboost_1_1hana_1_1integral__constant.html#a077af435df78fdb178f98b109c8c4297", null ],
-      [ "operator-", "structboost_1_1hana_1_1integral__constant.html#a51facf9760bb93d63efdca06dcf859ad", null ],
-      [ "operator-", "structboost_1_1hana_1_1integral__constant.html#a6be175332d55b7bfcf1afc33856d9b7d", null ],
-      [ "operator *", "structboost_1_1hana_1_1integral__constant.html#a5f4b91589df01b625ffb92499ab27876", null ],
-      [ "operator/", "structboost_1_1hana_1_1integral__constant.html#ab8b66ff58605e53149aad7eca0922ad7", null ],
-      [ "operator%", "structboost_1_1hana_1_1integral__constant.html#ad2fabb33632e115e96d0b7474670e6a1", null ],
-      [ "operator==", "structboost_1_1hana_1_1integral__constant.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1integral__constant.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
-      [ "operator||", "structboost_1_1hana_1_1integral__constant.html#a883a869b5e96e32744ebf75d63c763ae", null ],
-      [ "operator &&", "structboost_1_1hana_1_1integral__constant.html#a6eb151945e888d45427d4195a549a57c", null ],
-      [ "operator!", "structboost_1_1hana_1_1integral__constant.html#a7d9f9e5adeb222e676ee02d6f28198ee", null ],
-      [ "operator<", "structboost_1_1hana_1_1integral__constant.html#ada078dcf9e68b8e9a82b33c75dde8457", null ],
-      [ "operator>", "structboost_1_1hana_1_1integral__constant.html#aedd11fddefddbbbb87d3b24c7117528f", null ],
-      [ "operator<=", "structboost_1_1hana_1_1integral__constant.html#a53817979990da799e659b2576799a79a", null ],
-      [ "operator>=", "structboost_1_1hana_1_1integral__constant.html#aa3f0436b623de5208767751e1e9f7e59", null ],
+      [ "operator+", "structboost_1_1hana_1_1integral__constant.html#a897cb2a15eeef6924a2b2fda36eac874", null ],
+      [ "operator-", "structboost_1_1hana_1_1integral__constant.html#a7217b8e64dd43d969faca2c727db08b3", null ],
+      [ "operator-", "structboost_1_1hana_1_1integral__constant.html#a8a38703ec26537f474a9f0a5953ac582", null ],
+      [ "operator*", "structboost_1_1hana_1_1integral__constant.html#a1495dcab0ecb2627ce1e834afe98f8d6", null ],
+      [ "operator/", "structboost_1_1hana_1_1integral__constant.html#a7191ce0909ad60058d4fbf8f1d3ef235", null ],
+      [ "operator%", "structboost_1_1hana_1_1integral__constant.html#abae3f5f4393987734db5b7a638735918", null ],
+      [ "operator==", "structboost_1_1hana_1_1integral__constant.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1integral__constant.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
+      [ "operator||", "structboost_1_1hana_1_1integral__constant.html#acac20f8a52750bae122668729ec4df36", null ],
+      [ "operator&&", "structboost_1_1hana_1_1integral__constant.html#a69ba502677100036ab9e7101e91ca28f", null ],
+      [ "operator!", "structboost_1_1hana_1_1integral__constant.html#a8edb19203d27b84512479602eeeb8fe3", null ],
+      [ "operator<", "structboost_1_1hana_1_1integral__constant.html#aca31ad50b2d35d48aac88aa762530c75", null ],
+      [ "operator>", "structboost_1_1hana_1_1integral__constant.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
+      [ "operator<=", "structboost_1_1hana_1_1integral__constant.html#a971bac762b767fe0ec222adb367c9aeb", null ],
+      [ "operator>=", "structboost_1_1hana_1_1integral__constant.html#adec95a8109b858673412671ba341611b", null ],
       [ "operator\"\"_c", "structboost_1_1hana_1_1integral__constant.html#a1c078fd00db48686ca9e0aa17f47344e", null ]
     ] ],
     [ "basic_tuple", "structboost_1_1hana_1_1basic__tuple.html", [
@@ -53,7 +27,7 @@ var group__group_datatypes =
       [ "eval", "structboost_1_1hana_1_1lazy.html#aae2998c08f1f80ed52a6acf57c4eec6c", null ],
       [ "make< lazy_tag >", "structboost_1_1hana_1_1lazy.html#aa968ecf473c93821f1726fd9692e97f3", null ],
       [ "make_lazy", "structboost_1_1hana_1_1lazy.html#a7dc86ca61b84fc42aabb525787ae61b4", null ],
-      [ "operator|", "structboost_1_1hana_1_1lazy.html#a97b267b09ee075f1c531b849969e75e6", null ]
+      [ "operator|", "structboost_1_1hana_1_1lazy.html#a0527aedd89d16220a6b70404d4b1a322", null ]
     ] ],
     [ "map", "structboost_1_1hana_1_1map.html", [
       [ "make< map_tag >", "structboost_1_1hana_1_1map.html#a409d52de54cc7e55eca1a7b5dda4ce30", null ],
@@ -67,11 +41,11 @@ var group__group_datatypes =
       [ "intersection", "structboost_1_1hana_1_1map.html#a3b3430482d4e88052e621f63a234f3eb", null ],
       [ "difference", "structboost_1_1hana_1_1map.html#a718ddfe86437adbbca1e1a5db651d139", null ],
       [ "symmetric_difference", "structboost_1_1hana_1_1map.html#a8bcb2455eb9f7074185d8fb61a99801e", null ],
-      [ "operator==", "structboost_1_1hana_1_1map.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1map.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
+      [ "operator==", "structboost_1_1hana_1_1map.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1map.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
       [ "operator=", "structboost_1_1hana_1_1map.html#ae18123925b628b5cfcb1adaef5c83ac7", null ],
       [ "operator=", "structboost_1_1hana_1_1map.html#a9a6635ea36edc582518d278238defa0d", null ],
-      [ "operator[]", "structboost_1_1hana_1_1map.html#a4881a1810986e678959af8ccb58f5666", null ],
+      [ "operator[]", "structboost_1_1hana_1_1map.html#a1532587d8da252c580d24c5f4ab66cca", null ],
       [ "map", "structboost_1_1hana_1_1map.html#a1ee432be0bd10f08a637a437e311e4e2", null ],
       [ "map", "structboost_1_1hana_1_1map.html#a943219d1c9692938167639d8ad2525b8", null ],
       [ "map", "structboost_1_1hana_1_1map.html#a675bb30af155b40f72cbe8607eefbe4e", null ],
@@ -86,19 +60,19 @@ var group__group_datatypes =
       [ "sfinae", "structboost_1_1hana_1_1optional.html#aa4c8c0b1ef3d8206974734b93646c9fd", null ],
       [ "is_just", "structboost_1_1hana_1_1optional.html#a1047a69893a62cd36eb0d2934f85e0e7", null ],
       [ "is_nothing", "structboost_1_1hana_1_1optional.html#a4eb266d123883c23853f7731a6c5953f", null ],
-      [ "operator|", "structboost_1_1hana_1_1optional.html#a833b9d5d44bb431621af9129994b9bbc", null ],
-      [ "operator==", "structboost_1_1hana_1_1optional.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1optional.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
-      [ "operator<", "structboost_1_1hana_1_1optional.html#ada078dcf9e68b8e9a82b33c75dde8457", null ],
-      [ "operator>", "structboost_1_1hana_1_1optional.html#aedd11fddefddbbbb87d3b24c7117528f", null ],
-      [ "operator<=", "structboost_1_1hana_1_1optional.html#a53817979990da799e659b2576799a79a", null ],
-      [ "operator>=", "structboost_1_1hana_1_1optional.html#aa3f0436b623de5208767751e1e9f7e59", null ],
+      [ "operator|", "structboost_1_1hana_1_1optional.html#af19873df9190014c0dd09781c210becc", null ],
+      [ "operator==", "structboost_1_1hana_1_1optional.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1optional.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
+      [ "operator<", "structboost_1_1hana_1_1optional.html#aca31ad50b2d35d48aac88aa762530c75", null ],
+      [ "operator>", "structboost_1_1hana_1_1optional.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
+      [ "operator<=", "structboost_1_1hana_1_1optional.html#a971bac762b767fe0ec222adb367c9aeb", null ],
+      [ "operator>=", "structboost_1_1hana_1_1optional.html#adec95a8109b858673412671ba341611b", null ],
       [ "operator=", "structboost_1_1hana_1_1optional.html#abefc885243f38c66c52fdada3588f951", null ],
       [ "operator=", "structboost_1_1hana_1_1optional.html#a52057c5da4b9aee49ee15a167459fc9a", null ],
       [ "operator->", "structboost_1_1hana_1_1optional.html#a6eeef1512294d408857805eb3a790230", null ],
       [ "value", "structboost_1_1hana_1_1optional.html#acdcf71b43d4e27d5efbf0ad875d0be58", null ],
-      [ "operator *", "structboost_1_1hana_1_1optional.html#a237b2147dd9b72bb2dfa4a268056e4c2", null ],
-      [ "value_or", "structboost_1_1hana_1_1optional.html#a1f511267d94c178e4ef955da60f0888d", null ],
+      [ "operator*", "structboost_1_1hana_1_1optional.html#a3132b919ab7710d79155674272961d4b", null ],
+      [ "value_or", "structboost_1_1hana_1_1optional.html#ab65fe691bafd979111b52f97ec258e48", null ],
       [ "optional", "structboost_1_1hana_1_1optional.html#aefbd278cf7bb9e921707d6d827014bcb", null ],
       [ "optional", "structboost_1_1hana_1_1optional.html#a9074406adb54a6a848ba482895c51d1f", null ],
       [ "optional", "structboost_1_1hana_1_1optional.html#ac46a23f0ada20175c4c9a58af3d15753", null ],
@@ -108,12 +82,12 @@ var group__group_datatypes =
     [ "pair", "structboost_1_1hana_1_1pair.html", [
       [ "make< pair_tag >", "structboost_1_1hana_1_1pair.html#aab78903e9982284e82744dec570afa8d", null ],
       [ "make_pair", "structboost_1_1hana_1_1pair.html#a1bc322b45af2148a413ba45ee8097045", null ],
-      [ "operator==", "structboost_1_1hana_1_1pair.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1pair.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
-      [ "operator<", "structboost_1_1hana_1_1pair.html#ada078dcf9e68b8e9a82b33c75dde8457", null ],
-      [ "operator>", "structboost_1_1hana_1_1pair.html#aedd11fddefddbbbb87d3b24c7117528f", null ],
-      [ "operator<=", "structboost_1_1hana_1_1pair.html#a53817979990da799e659b2576799a79a", null ],
-      [ "operator>=", "structboost_1_1hana_1_1pair.html#aa3f0436b623de5208767751e1e9f7e59", null ],
+      [ "operator==", "structboost_1_1hana_1_1pair.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1pair.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
+      [ "operator<", "structboost_1_1hana_1_1pair.html#aca31ad50b2d35d48aac88aa762530c75", null ],
+      [ "operator>", "structboost_1_1hana_1_1pair.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
+      [ "operator<=", "structboost_1_1hana_1_1pair.html#a971bac762b767fe0ec222adb367c9aeb", null ],
+      [ "operator>=", "structboost_1_1hana_1_1pair.html#adec95a8109b858673412671ba341611b", null ],
       [ "operator=", "structboost_1_1hana_1_1pair.html#a96ada4b84949f1653de497410af50013", null ],
       [ "operator=", "structboost_1_1hana_1_1pair.html#a3f1a25445fa5380a78bdf524b764e1c7", null ],
       [ "pair", "structboost_1_1hana_1_1pair.html#acb8494edc410c10d824e942341f30719", null ],
@@ -126,9 +100,9 @@ var group__group_datatypes =
       [ "make< range_tag >", "structboost_1_1hana_1_1range.html#ad5ad9a1f847daa24ef62f5d81b8eef8e", null ],
       [ "make_range", "structboost_1_1hana_1_1range.html#aba8dd69deb1d810ef65ec289127bf0ab", null ],
       [ "range_c", "structboost_1_1hana_1_1range.html#a899b7a0c065ff64cd747fe1671753d3f", null ],
-      [ "operator==", "structboost_1_1hana_1_1range.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1range.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
-      [ "operator[]", "structboost_1_1hana_1_1range.html#a5df034200fc77683173f7cecf99f491e", null ]
+      [ "operator==", "structboost_1_1hana_1_1range.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1range.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
+      [ "operator[]", "structboost_1_1hana_1_1range.html#a766563b786c316320d175590fe3ad7af", null ]
     ] ],
     [ "set", "structboost_1_1hana_1_1set.html", [
       [ "make< set_tag >", "structboost_1_1hana_1_1set.html#aa337857e80b8a8c91880b0184aaf7534", null ],
@@ -140,9 +114,9 @@ var group__group_datatypes =
       [ "to_set", "structboost_1_1hana_1_1set.html#accbea694d32b341e860dac724c0c6933", null ],
       [ "difference", "structboost_1_1hana_1_1set.html#a718ddfe86437adbbca1e1a5db651d139", null ],
       [ "symmetric_difference", "structboost_1_1hana_1_1set.html#a8bcb2455eb9f7074185d8fb61a99801e", null ],
-      [ "operator==", "structboost_1_1hana_1_1set.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1set.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
-      [ "operator[]", "structboost_1_1hana_1_1set.html#a00f6165e7a2db4218c67d80929c457d2", null ],
+      [ "operator==", "structboost_1_1hana_1_1set.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1set.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
+      [ "operator[]", "structboost_1_1hana_1_1set.html#a426850019348f48aef6765c57061c631", null ],
       [ "set", "structboost_1_1hana_1_1set.html#a51bdb213a03abc126668c4c3b14fc50b", null ],
       [ "set", "structboost_1_1hana_1_1set.html#a937a7d47238690b571e7dd524278f6d5", null ],
       [ "set", "structboost_1_1hana_1_1set.html#ac5b7025edfb0c6c28f31d84598e130f0", null ]
@@ -152,16 +126,16 @@ var group__group_datatypes =
       [ "make_string", "structboost_1_1hana_1_1string.html#acd99ab02697909eba5eb76caf1ca7a8b", null ],
       [ "to_string", "structboost_1_1hana_1_1string.html#aa3fb479070239c86673c624a21a845b6", null ],
       [ "string_c", "structboost_1_1hana_1_1string.html#a810915f5e494decfe47b047a3500c577", null ],
-      [ "operator==", "structboost_1_1hana_1_1string.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1string.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
-      [ "operator<", "structboost_1_1hana_1_1string.html#ada078dcf9e68b8e9a82b33c75dde8457", null ],
-      [ "operator>", "structboost_1_1hana_1_1string.html#aedd11fddefddbbbb87d3b24c7117528f", null ],
-      [ "operator<=", "structboost_1_1hana_1_1string.html#a53817979990da799e659b2576799a79a", null ],
-      [ "operator>=", "structboost_1_1hana_1_1string.html#aa3f0436b623de5208767751e1e9f7e59", null ],
-      [ "operator+", "structboost_1_1hana_1_1string.html#a077af435df78fdb178f98b109c8c4297", null ],
+      [ "operator==", "structboost_1_1hana_1_1string.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1string.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
+      [ "operator<", "structboost_1_1hana_1_1string.html#aca31ad50b2d35d48aac88aa762530c75", null ],
+      [ "operator>", "structboost_1_1hana_1_1string.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
+      [ "operator<=", "structboost_1_1hana_1_1string.html#a971bac762b767fe0ec222adb367c9aeb", null ],
+      [ "operator>=", "structboost_1_1hana_1_1string.html#adec95a8109b858673412671ba341611b", null ],
+      [ "operator+", "structboost_1_1hana_1_1string.html#a897cb2a15eeef6924a2b2fda36eac874", null ],
       [ "BOOST_HANA_STRING", "structboost_1_1hana_1_1string.html#a7f15faa77e126e1c2b08a2224ceefb84", null ],
       [ "operator\"\"_s", "structboost_1_1hana_1_1string.html#ad77f7afff008c2ce15739ad16a8bf0a8", null ],
-      [ "operator[]", "structboost_1_1hana_1_1string.html#a02f56704524481cf919907caf271d2a1", null ]
+      [ "operator[]", "structboost_1_1hana_1_1string.html#a186fd5a7d40373d568a0c3d4517da929", null ]
     ] ],
     [ "tuple", "structboost_1_1hana_1_1tuple.html", [
       [ "make< tuple_tag >", "structboost_1_1hana_1_1tuple.html#ad9d8c7efa77e573eba2dfc48b3343e66", null ],
@@ -169,16 +143,16 @@ var group__group_datatypes =
       [ "to_tuple", "structboost_1_1hana_1_1tuple.html#a749b564c8f115957837761d75191beac", null ],
       [ "tuple_t", "structboost_1_1hana_1_1tuple.html#a1997546daf58a48cc15498d338a03da3", null ],
       [ "tuple_c", "structboost_1_1hana_1_1tuple.html#a85c2f16caa2a1e12eefd1b3f69fa658e", null ],
-      [ "operator|", "structboost_1_1hana_1_1tuple.html#a59b4d21f17e2caed8c31d8389d0f0878", null ],
-      [ "operator==", "structboost_1_1hana_1_1tuple.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1tuple.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
-      [ "operator<", "structboost_1_1hana_1_1tuple.html#ada078dcf9e68b8e9a82b33c75dde8457", null ],
-      [ "operator>", "structboost_1_1hana_1_1tuple.html#aedd11fddefddbbbb87d3b24c7117528f", null ],
-      [ "operator<=", "structboost_1_1hana_1_1tuple.html#a53817979990da799e659b2576799a79a", null ],
-      [ "operator>=", "structboost_1_1hana_1_1tuple.html#aa3f0436b623de5208767751e1e9f7e59", null ],
+      [ "operator|", "structboost_1_1hana_1_1tuple.html#a9f7ef8b098a26c3168e1dbd4dd54ff7b", null ],
+      [ "operator==", "structboost_1_1hana_1_1tuple.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1tuple.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
+      [ "operator<", "structboost_1_1hana_1_1tuple.html#aca31ad50b2d35d48aac88aa762530c75", null ],
+      [ "operator>", "structboost_1_1hana_1_1tuple.html#a65b9400772e651101ae83d7f9f7ba84d", null ],
+      [ "operator<=", "structboost_1_1hana_1_1tuple.html#a971bac762b767fe0ec222adb367c9aeb", null ],
+      [ "operator>=", "structboost_1_1hana_1_1tuple.html#adec95a8109b858673412671ba341611b", null ],
       [ "operator=", "structboost_1_1hana_1_1tuple.html#acddfa6d631c249ae667d52dd63c0aeaf", null ],
       [ "operator=", "structboost_1_1hana_1_1tuple.html#ad3f0fe520974a22cc12a978f4b061caa", null ],
-      [ "operator[]", "structboost_1_1hana_1_1tuple.html#acef38216a6c6da0296a5f7b5241e951b", null ],
+      [ "operator[]", "structboost_1_1hana_1_1tuple.html#a8a7edb152340d0eabf67a62f9e25c99f", null ],
       [ "tuple", "structboost_1_1hana_1_1tuple.html#a8e10223983bfb3873c285be85f7ab273", null ],
       [ "tuple", "structboost_1_1hana_1_1tuple.html#a4e4e6193df38146b1eab93bcf963fc81", null ],
       [ "tuple", "structboost_1_1hana_1_1tuple.html#a9a5dd3930d94a900190de98247e0c415", null ],
@@ -194,8 +168,8 @@ var group__group_datatypes =
       [ "sizeof_", "structboost_1_1hana_1_1type.html#a26b702b280ca02f118affaaca9112a8c", null ],
       [ "alignof_", "structboost_1_1hana_1_1type.html#a6fd9ac456f4b5574dcb16384dbb85736", null ],
       [ "is_valid", "structboost_1_1hana_1_1type.html#a2d2e7e08e284f7e0bd1bd9c3ad0e0a2b", null ],
-      [ "operator==", "structboost_1_1hana_1_1type.html#a27607958295e6da8a0ba602a2db468f1", null ],
-      [ "operator!=", "structboost_1_1hana_1_1type.html#a0cae3af55edb3eb05bfa184bda633f7d", null ],
+      [ "operator==", "structboost_1_1hana_1_1type.html#a22bef1b2c14cf393a3a9cb1924d8c8ff", null ],
+      [ "operator!=", "structboost_1_1hana_1_1type.html#a4ecea0deb4c00ae2eb0b0713ee0645e9", null ],
       [ "operator+", "structboost_1_1hana_1_1type.html#a228c1b24d16b2c765c816f816a09337c", null ]
     ] ]
 ];
\ No newline at end of file
