@@ -1,8 +1,9 @@
-// Copyright Louis Dionne 2013-2017
+// Copyright Louis Dionne 2013-2022
 // Distributed under the Boost Software License, Version 1.0.
 // (See accompanying file LICENSE.md or copy at http://boost.org/LICENSE_1_0.txt)
 
 #include <boost/hana/at.hpp>
+#include <boost/hana/bool.hpp>
 #include <boost/hana/first.hpp>
 #include <boost/hana/integral_constant.hpp>
 #include <boost/hana/pair.hpp>
@@ -10,6 +11,7 @@
 #include <boost/hana/tuple.hpp>
 
 #include <type_traits>
+#include <utility>
 namespace hana = boost::hana;
 
 
@@ -42,4 +44,14 @@ int main() {
         auto b = hana::at_c<1>(tuple);
         static_assert(std::is_same<decltype(b), Nested>{}, "");
     }
+
+    // Original test case submitted by Vittorio Romeo
+    {
+        hana::pair<hana::int_<1>, hana::bool_<false>> p{};
+        auto copy = hana::make_pair(hana::int_c<0>, p);
+        auto move = hana::make_pair(hana::int_c<0>, std::move(p));
+
+        copy = move; // copy assign
+        copy = std::move(move); // move assign
+    }
 }
