@@ -7,81 +7,275 @@
 // Official repository: https://github.com/boostorg/json
 //
 
-#include <boost/json.hpp>
-
-#include <algorithm>
-#include <cmath>
-#include <complex>
-#include <iostream>
-#include <map>
-#include <numeric>
-#include <string>
-#include <unordered_map>
-#include <vector>
-
-#include "test_suite.hpp"
-
 #ifdef _MSC_VER
 # pragma warning(push)
 # pragma warning(disable: 4101)
+# pragma warning(disable: 4996)
 #elif defined(__clang__)
 # pragma clang diagnostic push
 # pragma clang diagnostic ignored "-Wunused"
-# pragma clang diagnostic ignored "-Wmismatched-tags"
 #elif defined(__GNUC__)
 # pragma GCC diagnostic push
 # pragma GCC diagnostic ignored "-Wunused"
 #endif
 
-//[snippet_conv_3
+#include <boost/json.hpp>
 
-template< std::size_t N >
-struct static_string { };
+#include <algorithm>
+#include <cmath>
+#include <map>
+#include <numeric>
+#include <string>
+#include <vector>
 
-namespace std
+#include "test_suite.hpp"
+#include "doc_types.hpp"
+
+//[snippet_conv_spec_trait2
+namespace boost
+{
+namespace json
 {
 
-template< std::size_t N >
-class hash< static_string< N > >
+template<>
+struct is_sequence_like< user_ns::ip_address >
+    : std::false_type
+{ };
+
+} // namespace json
+} // namespace boost
+//]
+
+namespace user_ns2 {
+
+class ip_address : public user_ns::ip_address
 {
 public:
-    std::size_t
-    operator()(const static_string< N >& str ) const noexcept
-    {
-        return std::hash< std::string >()( str );
-    }
+    using user_ns::ip_address::ip_address;
 };
 
-} // std
+using namespace boost::json;
 
-//]
-
-BOOST_JSON_NS_BEGIN
-
-//[snippet_conv_4
-
-template< class T >
+//[snippet_tag_invoke_1
 void
-tag_invoke( const value_from_tag&, value& jv, std::complex< T > const& t)
+tag_invoke( const value_from_tag&, value& jv, ip_address const& addr )
 {
-    // Store a complex number as a 2-element array
-    // with the real part followed by the imaginary part
-    jv = { t.real(), t.imag() };
+    // Store the IP address as a 4-element array of octets
+    const unsigned char* b = addr.begin();
+    jv = { b[0], b[1], b[2], b[3] };
 }
 
-template< class T >
-std::complex< T >
-tag_invoke( const value_to_tag< std::complex< T > >&, value const& jv )
+ip_address
+tag_invoke( const value_to_tag< ip_address >&, value const& jv )
 {
-    return std::complex< T >(
-        jv.as_array().at(0).to_number< T >(),
-        jv.as_array().at(1).to_number< T >());
+    array const& arr = jv.as_array();
+    return ip_address(
+        arr.at(0).to_number< unsigned char >(),
+        arr.at(1).to_number< unsigned char >(),
+        arr.at(2).to_number< unsigned char >(),
+        arr.at(3).to_number< unsigned char >() );
 }
-
 //]
 
+//[snippet_nothrow_1
+result_for< ip_address, value >::type
+tag_invoke( const try_value_to_tag< ip_address >&, value const& jv )
+{
+    if( !jv.is_array() )
+        return make_error_code( std::errc::invalid_argument );
+
+    array const& arr = jv.get_array();
+    if( arr.size() != 4 )
+        return make_error_code( std::errc::invalid_argument );
+
+    result< unsigned char > oct1 = try_value_to< unsigned char >( arr[0] );
+    if( !oct1 )
+        return make_error_code( std::errc::invalid_argument );
+
+    result< unsigned char > oct2 = try_value_to< unsigned char >( arr[1] );
+    if( !oct2 )
+        return make_error_code( std::errc::invalid_argument );
+
+    result< unsigned char > oct3 = try_value_to< unsigned char >( arr[2] );
+    if( !oct3 )
+        return make_error_code( std::errc::invalid_argument );
+
+    result< unsigned char > oct4 = try_value_to< unsigned char >( arr[3] );
+    if( !oct4 )
+        return make_error_code( std::errc::invalid_argument );
+
+    return ip_address{ *oct1, *oct2, *oct3, *oct4 };
+}
+//]
+
+} // namespace user_ns
+
+//[doc_context_conversion_1
+namespace user_ns
+{
+
+struct as_string
+{ };
+
+void
+tag_invoke(
+    boost::json::value_from_tag, boost::json::value& jv, const ip_address& addr, const as_string& )
+{
+    boost::json::string& js = jv.emplace_string();
+    js.resize( 4 * 3 + 3 + 1 ); // XXX.XXX.XXX.XXX\0
+    auto it = addr.begin();
+    auto n = std::sprintf(
+        js.data(), "%hhu.%hhu.%hhu.%hhu", it[0], it[1], it[2], it[3] );
+    js.resize(n);
+}
+
+ip_address
+tag_invoke(
+    boost::json::value_to_tag<ip_address>, const boost::json::value& jv, const as_string& )
+{
+    const boost::json::string& js = jv.as_string();
+
+    unsigned char octets[4];
+    int result = std::sscanf(
+        js.data(), "%hhu.%hhu.%hhu.%hhu", octets, octets + 1, octets + 2, octets + 3 );
+    if( result != 4 )
+        throw std::invalid_argument("not an IP address");
+
+    return ip_address( octets[0], octets[1], octets[2], octets[3] );
+}
+
+}
+//]
+
+//[doc_context_conversion_4
+namespace user_ns
+{
+
+struct as_iso_8601
+{ };
+
+void
+tag_invoke(
+    boost::json::value_from_tag, boost::json::value& jv, std::chrono::system_clock::time_point tp, const as_iso_8601& )
+{
+    boost::json::string& js = jv.emplace_string();
+    js.resize( 4 + 2 * 5 + 5 + 1 ); // YYYY-mm-ddTHH:MM:ss\0
+
+    std::time_t t = std::chrono::system_clock::to_time_t( tp );
+    std::tm tm = *std::gmtime( &t );
+    std::size_t n = std::strftime(
+        js.data(), js.size(), "%FT%T", &tm );
+    js.resize(n);
+}
+
+}
+//]
+
+//[doc_context_conversion_6
+namespace user_ns
+{
+
+struct date_format
+{
+    std::string format;
+    std::size_t buffer_size;
+};
+
+void
+tag_invoke(
+    boost::json::value_from_tag, boost::json::value& jv, std::chrono::system_clock::time_point tp, const date_format& ctx )
+{
+    boost::json::string& js = jv.emplace_string();
+    js.resize( ctx.buffer_size );
+
+    std::time_t t = std::chrono::system_clock::to_time_t( tp );
+    std::size_t n = std::strftime(
+        js.data(), js.size(), ctx.format.c_str(), std::gmtime( &t ) );
+    js.resize(n);
+}
+
+}
+//]
+
+//[doc_context_conversion_10
+namespace user_ns
+{
+
+struct maps_as_objects
+{ };
+
+template<
+    class Key,
+    class Value,
+    class Ctx >
+void
+tag_invoke(
+    boost::json::value_from_tag,
+    boost::json::value& jv,
+    const std::map<Key, Value>& m,
+    const maps_as_objects&,
+    const Ctx& ctx )
+{
+    boost::json::object& jo = jv.emplace_object();
+
+    for( const auto& item: m )
+    {
+        auto k = boost::json::value_from( item.first, ctx, jo.storage() );
+        auto v = boost::json::value_from( item.second, ctx, jo.storage() );
+        jo[std::move( k.as_string() )] = std::move( v );
+    }
+}
+
+template<
+    class Key,
+    class Value,
+    class Ctx >
+std::map<Key, Value>
+tag_invoke(
+    boost::json::value_to_tag< std::map<Key, Value> >,
+    boost::json::value const& jv,
+    const maps_as_objects&,
+    const Ctx& ctx )
+{
+    const boost::json::object& jo = jv.as_object();
+    std::map< Key, Value > result;
+    for( auto&& item: jo )
+    {
+        Key k = boost::json::value_to< Key >( item.key(), ctx );
+        Value v = boost::json::value_to< Value >( item.value(), ctx );
+        result.emplace( std::move(k), std::move(v) );
+    }
+    return result;
+}
+
+}
+//]
+
+namespace boost {
+namespace json {
+
 namespace {
 
+//[snippet_strings_5
+string greeting( string_view first_name, string_view last_name )
+{
+    const char hello[] = "Hello, ";
+    const std::size_t sz = first_name.size() + last_name.size() + sizeof(hello) + 1;
+
+    string js;
+    js.reserve(sz);
+
+    char* p = std::copy( hello, hello + sizeof(hello) - 1, js.data() );
+    p = std::copy( first_name.begin(), first_name.end(), p );
+    *p++ = ' ';
+    p = std::copy( last_name.begin(), last_name.end(), p );
+    *p++ = '!';
+
+    js.grow( sz );
+    return js;
+}
+//]
+
 void
 usingStrings()
 {
@@ -144,6 +338,12 @@ usingStrings()
 
         //]
     }
+
+    {
+        auto str = greeting( "John", "Smith" );
+        (void)str;
+        assert( str == "Hello, John Smith!");
+    }
 }
 
 //----------------------------------------------------------
@@ -279,7 +479,7 @@ usingInitLists()
 
         assert( jv.as_array().size() == 4 );
 
-        assert( serialize(jv) == "[true,2,\"hello\",null]" );
+        assert( serialize(jv) == R"([true,2,"hello",null])" );
 
         //]
     }
@@ -293,7 +493,7 @@ usingInitLists()
 
         assert( jv.as_array().back().is_array() );
 
-        assert( serialize(jv) == "[true,2,\"hello\",[\"bye\",null,false]]" );
+        assert( serialize(jv) == R"([true,2,"hello",["bye",null,false]])" );
 
         //]
     }
@@ -356,11 +556,11 @@ usingInitLists()
 
         assert( jv.is_object() );
 
-        assert( serialize(jv) == "{\"mercury\":36,\"venus\":67,\"earth\":93}" );
+        assert( serialize(jv) == R"({"mercury":36,"venus":67,"earth":93})" );
 
         array ja = { { "mercury", 36 }, { "venus", 67 }, { "earth", 93 } };
 
-        assert( serialize(ja) == "[[\"mercury\",36],[\"venus\",67],[\"earth\",93]]" );
+        assert( serialize(ja) == R"([["mercury",36],["venus",67],["earth",93]])" );
 
         //]
 
@@ -435,7 +635,7 @@ usingArrays()
 
         assert( arr[0].as_string() == "Hello" );
 
-        // The following line throws std::out_of_range, since the index is out of range
+        // The following line throws system_error, since the index is out of range
         arr.at( 3 ) = nullptr;
 
         //]
@@ -487,7 +687,7 @@ usingObjects()
         obj["key2"] = 42;
         obj["key3"] = false;
 
-        // The following line throws std::out_of_range, since the key does not exist
+        // The following line throws system_error, since the key does not exist
         obj.at( "key4" );
 
         //]
@@ -508,27 +708,6 @@ usingObjects()
     }
 }
 
-//----------------------------------------------------------
-
-//[snippet_conv_2
-
-template< class T >
-void identity_swap( T& a, T& b )
-{
-    // introduces the declaration of
-    // std::swap into this scope
-    using std::swap;
-    if( &a == &b )
-        return;
-    // the overload set will contain std::swap,
-    // any declarations of swap within the enclosing
-    // namespace, and any declarations of swap within
-    // the namespaces associated with T
-    swap( a, b );
-}
-
-//]
-
 //[snippet_conv_5
 
 template< class T >
@@ -549,19 +728,6 @@ void tag_invoke( const value_from_tag&, value& jv, const vec3<T>& vec )
 
 //]
 
-#ifdef BOOST_JSON_DOCS
-//[snippet_conv_7
-
-template< class T, typename std::enable_if<
-    std::is_floating_point< T >::value>::type* = nullptr >
-void tag_invoke( const value_from_tag&, value& jv, T t )
-{
-    jv = std::llround( t );
-}
-
-//]
-#endif
-
 //[snippet_conv_10
 
 struct customer
@@ -574,8 +740,6 @@ struct customer
 
     customer( std::uint64_t i, const std::string& n, bool l )
         : id( i ), name( n ), late( l ) { }
-
-    explicit customer( value const& );
 };
 
 void tag_invoke( const value_from_tag&, value& jv, customer const& c )
@@ -625,169 +789,96 @@ usingExchange()
 
         // Convert the vector to a JSON array
         value jv = value_from( v1 );
-
-        assert( jv.is_array() );
-
-        array& ja = jv.as_array();
-
-        assert( ja.size() == 4 );
-
-        for ( std::size_t i = 0; i < v1.size(); ++i )
-            assert( v1[i] == ja[i].as_int64() );
+        assert( serialize( jv ) == R"([1,2,3,4])" );
 
         // Convert back to vector< int >
         std::vector< int > v2 = value_to< std::vector< int > >( jv );
-
         assert( v1 == v2 );
 
         //]
 
-        (void)ja;
+        (void)v2;
     }
     {
-        //[snippet_conv_6
+        using namespace user_ns2;
 
-        vec3< int > pos = { 4, 1, 4 };
-
-        value jv = value_from( pos );
-
-        assert( serialize( jv ) == "{\"x\":4,\"y\":1,\"z\":4}" );
-
-        //]
-    }
-    {
-        //[snippet_conv_8
-
-       value jv = value_from( 1.5 ); // error
-
-        //]
-    }
-    {
-        //[snippet_conv_9
-
-        std::map< std::string, vec3< int > > positions = {
-            { "Alex", { 42, -60, 18 } },
-            { "Blake", { 300, -60, -240} },
-            { "Carol", { -60, 30, 30 } }
+        //[snippet_tag_invoke_3
+        std::map< std::string, ip_address > computers = {
+            { "Alex", { 192, 168, 1, 1 } },
+            { "Blake", { 192, 168, 1, 2 } },
+            { "Carol", { 192, 168, 1, 3 } },
         };
 
         // conversions are applied recursively;
         // the key type and value type will be converted
         // using value_from as well
-        value jv = value_from( positions );
-
+        value jv = value_from( computers );
         assert( jv.is_object() );
 
-        object& jo = jv.as_object();
-
-        assert( jo.size() == 3 );
-
-        // The sum of the coordinates is 0
-        assert( std::accumulate( jo.begin(), jo.end(), std::int64_t(0),
-            []( std::int64_t total, const key_value_pair& jp )
+        value serialized = parse(R"(
             {
-                assert ( jp.value().is_object() );
-
-                const object& pos = jp.value().as_object();
-
-                return total + pos.at( "x" ).as_int64() +
-                    pos.at( "y" ).as_int64() +
-                    pos.at( "z" ).as_int64();
-
-            } ) == 0 );
-
+                "Alex":  [ 192, 168, 1, 1 ],
+                "Blake": [ 192, 168, 1, 2 ],
+                "Carol": [ 192, 168, 1, 3 ]
+            }
+            )");
+        assert( jv == serialized );
         //]
 
-        (void)jo;
+        (void)jv;
     }
     {
-        //[snippet_conv_11
+        using namespace user_ns2;
 
-        std::vector< customer > customers = {
-            customer( 0, "Alison", false ),
-            customer( 1, "Bill", false ),
-            customer( 3, "Catherine", true ),
-            customer( 4, "Doug", false )
-         };
-
-        storage_ptr sp = make_shared_resource< monotonic_resource >();
-
-        value jv = value_from( customers, sp );
-
-        assert( jv.storage() == sp );
-
-        assert( jv.is_array() );
+        //[snippet_tag_invoke_2
+        ip_address addr = { 127, 0, 0, 12 };
+        value jv = value_from( addr );
+        assert( serialize( jv ) == R"([127,0,0,12])" );
 
+        // Convert back to IP address
+        ip_address addr2 = value_to< ip_address >( jv );
+        assert(std::equal(
+            addr.begin(), addr.end(), addr2.begin() ));
         //]
+
+        (void)addr2;
     }
-
     {
-        //[snippet_conv_12
+        using namespace user_ns2;
 
-        // Satisfies both FromMapLike and FromContainerLike
-        std::unordered_map< std::string, bool > available_tools = {
-            { "Crowbar", true },
-            { "Hammer", true },
-            { "Drill", true },
-            { "Saw", false },
+        //[snippet_nothrow_2
+        value jv = parse( R"([127,0,0,12])" );
+
+        result< ip_address > addr = try_value_to< ip_address >( jv );
+        assert( addr.has_value() );
+
+        ip_address addr2{ 127, 0, 0, 12 };
+        assert(std::equal(
+            addr->begin(), addr->end(), addr2.begin() ));
+
+        // this fails without exception
+        addr = try_value_to< ip_address >( value() );
+        assert( addr.has_error() );
+        //]
+
+        (void)addr;
+        (void)addr2;
+    }
+    {
+        //[snippet_conv_recursive
+        std::map< std::string, std::pair<int, bool> > m = {
+            {"a", {1, false}},
+            {"b", {4, true}},
+            {"c", {5, false}},
         };
 
-        value jv = value_from( available_tools );
-
-        assert( jv.is_object() );
-
-        //]
-    }
-    {
-        //[snippet_conv_13
-
-        std::complex< double > c1 = { 3.14159, 2.71828 };
-
-        // Convert a complex number to JSON
-        value jv = value_from( c1 );
-
-        assert ( jv.is_array() );
-
-        // Convert back to a complex number
-
-        std::complex< double > c2 = value_to< std::complex< double > >( jv );
-
-        //]
-
-        (void)c2;
-    }
-    {
-        //[snippet_conv_15
-
-        customer c1( 5, "Ed", false );
-
-        // Convert customer to value
-        value jv = value_from( c1 );
-
-        // Convert the result back to customer
-        customer c2 = value_to< customer >( jv );
-
-        // The resulting customer is unchanged
-        assert( c1.name == c2.name );
-
-        //]
-    }
-    {
-        //[snippet_conv_16
-
-        value available_tools = {
-            { "Crowbar", true },
-            { "Hammer", true },
-            { "Drill", true },
-            { "Saw", false }
-        };
-
-        assert( available_tools.is_object() );
-
-        auto as_map = value_to< std::map< std::string, bool > >( available_tools );
-
-        assert( available_tools.as_object().size() == as_map.size() );
+        value jv = value_from( m );
 
+        assert(( jv == object{
+            {"a", array{1, false}},
+            {"b", array{4, true}},
+            {"c", array{5, false}},
+        }));
         //]
     }
 }
@@ -846,18 +937,39 @@ usingPointer()
     assert( elem1 == elem2 );
 }
 
+
+void
+usingSetAtPointer()
+{
+    //[snippet_pointer_4
+    value jv;
+    jv.set_at_pointer("/two/bar/0", 12);
+    assert( jv.is_object() );
+    assert( jv.at_pointer("/two").is_object() );
+    assert( jv.at_pointer("/two/bar").is_array() );
+    assert( jv.at_pointer("/two/bar/0") == 12 );
+    //]
+
+    jv = nullptr;
+    //[snippet_pointer_5
+    set_pointer_options opts;
+    opts.create_arrays = false;
+
+    jv.set_at_pointer("/two/bar/0", 12, opts);
+    assert( jv.is_object() );
+    assert( jv.at_pointer("/two").is_object() );
+    assert( jv.at_pointer("/two/bar").is_object() ); // object, not array
+    assert( jv.at_pointer("/two/bar/0") == 12 );
+    //]
+}
+
 BOOST_STATIC_ASSERT(
     has_value_from<customer>::value);
 
 BOOST_STATIC_ASSERT(
-    has_value_from<std::complex<float>>::value);
+    has_value_from<user_ns2::ip_address>::value);
 BOOST_STATIC_ASSERT(
-    has_value_from<std::complex<double>>::value);
-
-BOOST_STATIC_ASSERT(
-    has_value_to<std::complex<float>>::value);
-BOOST_STATIC_ASSERT(
-    has_value_to<std::complex<double>>::value);
+    has_value_to<user_ns2::ip_address>::value);
 
 } // (anon)
 
@@ -887,10 +999,141 @@ struct is_deallocate_trivial< my_non_deallocating_resource >
 } // boost
 
 //]
-
 namespace boost {
 namespace json {
 
+namespace
+{
+
+void
+usingSpecializedTrait()
+{
+    value jv1{127, 0, 0, 1};
+    auto const addr = value_to< user_ns::ip_address >( jv1 );
+    auto const jv2 = value_from(addr);
+    assert( jv1 == jv2 );
+}
+
+void
+usingContextualConversions()
+{
+    using namespace user_ns;
+    using namespace boost::json;
+    {
+//[doc_context_conversion_2
+        ip_address addr( 192, 168, 10, 11 );
+
+        value jv = value_from( addr, as_string() );
+        assert( jv == parse(R"( "192.168.10.11" )") );
+
+        ip_address addr2 = value_to< ip_address >( jv, as_string() );
+        assert(std::equal(
+            addr.begin(), addr.end(), addr2.begin() ));
+//]
+        (void)addr2;
+    }
+
+    {
+//[doc_context_conversion_3
+        std::map< std::string, ip_address > computers = {
+            { "Alex", { 192, 168, 1, 1 } },
+            { "Blake", { 192, 168, 1, 2 } },
+            { "Carol", { 192, 168, 1, 3 } },
+        };
+        value jv = value_from( computers, as_string() );
+        assert( jv == parse(
+            "{                               "
+            "    \"Alex\" : \"192.168.1.1\", "
+            "    \"Blake\": \"192.168.1.2\", "
+            "    \"Carol\": \"192.168.1.3\"  "
+            "}                               "
+            ) );
+//]
+        (void)jv;
+    }
+
+    {
+//[doc_context_conversion_5
+        std::chrono::system_clock::time_point tp;
+        value jv = value_from( tp, as_iso_8601() );
+        assert( jv == parse(R"( "1970-01-01T00:00:00" )") );
+//]
+        (void)jv;
+    }
+
+    {
+//[doc_context_conversion_7
+        std::chrono::system_clock::time_point tp;
+
+        value jv = value_from( tp, date_format{ "%T %D", 18 } );
+        assert( jv == parse(R"( "00:00:00 01/01/70" )") );
+
+        jv = value_from( tp, as_iso_8601() );
+        assert( jv == parse(R"( "1970-01-01T00:00:00" )") );
+//]
+        (void)jv;
+    }
+
+    {
+//[doc_context_conversion_8
+        using time_point = std::chrono::system_clock::time_point;
+        time_point start;
+        std::vector< std::pair<time_point, ip_address> > log = {
+            { start += std::chrono::seconds(10), {192, 168, 10, 11} },
+            { start += std::chrono::hours(2),    {192, 168, 10, 13} },
+            { start += std::chrono::minutes(14), {192, 168, 10, 10} },
+        };
+        value jv = value_from(
+            log, std::make_tuple( as_string(), as_iso_8601() ) );
+        assert( jv == parse(
+            " [                                                   "
+            "     [ \"1970-01-01T00:00:10\", \"192.168.10.11\" ], "
+            "     [ \"1970-01-01T02:00:10\", \"192.168.10.13\" ], "
+            "     [ \"1970-01-01T02:14:10\", \"192.168.10.10\" ]  "
+            " ]                                                   "
+            ) );
+//]
+        (void)jv;
+    }
+
+    {
+        using time_point = std::chrono::system_clock::time_point;
+        time_point start;
+//[doc_context_conversion_9
+
+        std::map< time_point, ip_address > log = {
+            { start += std::chrono::seconds(10), {192, 168, 10, 11} },
+            { start += std::chrono::hours(2),    {192, 168, 10, 13} },
+            { start += std::chrono::minutes(14), {192, 168, 10, 10} },
+        };
+
+        value jv = value_from(
+            log,
+            std::make_tuple( maps_as_objects(), as_string(), as_iso_8601() ) );
+        assert( jv == parse(
+            " {                                               "
+            "     \"1970-01-01T00:00:10\": \"192.168.10.11\", "
+            "     \"1970-01-01T02:00:10\": \"192.168.10.13\", "
+            "     \"1970-01-01T02:14:10\": \"192.168.10.10\"  "
+            " }                                               "
+            ) );
+//]
+        (void)jv;
+    }
+}
+
+void
+usingParseInto()
+{
+//[doc_parse_into_1
+    std::map< std::string, std::vector<int> > vectors;
+    string_view input = R"( { "even": [2,4,6], "odd": [1,3,5] } )";
+    parse_into(vectors, input);
+//]
+}
+
+} // namespace
+
 class snippets_test
 {
 public:
@@ -904,6 +1147,10 @@ public:
         usingObjects();
         usingStrings();
         usingPointer();
+        usingSpecializedTrait();
+        usingSetAtPointer();
+        usingContextualConversions();
+        usingParseInto();
 
         BOOST_TEST_PASS();
     }
@@ -911,4 +1158,5 @@ public:
 
 TEST_SUITE(snippets_test, "boost.json.snippets");
 
-BOOST_JSON_NS_END
+} // namespace json
+} // namespace boost
