@@ -9,6 +9,7 @@
 
 // Test that header file is self-contained.
 #include <boost/json/value.hpp>
+#include <iostream>
 
 #include <boost/json/monotonic_resource.hpp>
 
@@ -19,7 +20,8 @@
 #include "test.hpp"
 #include "test_suite.hpp"
 
-BOOST_JSON_NS_BEGIN
+namespace boost {
+namespace json {
 
 BOOST_STATIC_ASSERT( std::is_nothrow_destructible<value>::value );
 BOOST_STATIC_ASSERT( std::is_nothrow_move_constructible<value>::value );
@@ -40,6 +42,27 @@ T min_of()
     return (std::numeric_limits<T>::min)();
 }
 
+class throwing_buffer
+    : public std::streambuf
+{
+protected:
+    int_type
+    underflow() override
+    {
+        // make sure we don't throw before the parser had the chance to start
+        if( !gptr()  )
+        {
+            setg(buf_, buf_, buf_ + 1);
+            return *buf_;
+        }
+
+        throw std::invalid_argument("this buffer throws");
+    }
+
+private:
+    char buf_[1] = {'t'};
+};
+
 } // (anon)
 
 class value_test
@@ -844,6 +867,13 @@ public:
                 BOOST_TEST(jv.is_array());
                 BOOST_TEST(*jv.storage() == *sp);
             }
+            {
+                value jv(sp);
+                array const arr;
+                jv = arr;
+                BOOST_TEST(jv.is_array());
+                BOOST_TEST(*jv.storage() == *sp);
+            }
         }
 
         // operator=(object)
@@ -860,6 +890,13 @@ public:
                 BOOST_TEST(jv.is_object());
                 BOOST_TEST(*jv.storage() == *sp);
             }
+            {
+                value jv(sp);
+                object const obj;
+                jv = obj;
+                BOOST_TEST(jv.is_object());
+                BOOST_TEST(*jv.storage() == *sp);
+            }
         }
     }
 
@@ -1400,25 +1437,25 @@ public:
 #define EQAL(T) BOOST_TEST(jv.to_number<T>() == V)
 #define EQUS(T) BOOST_TEST((V >= 0) && jv.to_number<T>() == static_cast<std::uint64_t>(V))
 #define EQUF(T) BOOST_TEST(static_cast<float>(V) == static_cast<float>(jv.to_number<T>()))
-#define THRO(T) BOOST_TEST_THROWS(jv.to_number<T>(), system_error)
+#define THRO(T) BOOST_TEST_THROWS_WITH_LOCATION(jv.to_number<T>());
 
-        BOOST_TEST_THROWS(value(nullptr).to_number<int>(), system_error);
-        BOOST_TEST_THROWS(value(false).to_number<int>(), system_error);
-        BOOST_TEST_THROWS(value(string_kind).to_number<int>(), system_error);
-        BOOST_TEST_THROWS(value(array_kind).to_number<int>(), system_error);
-        BOOST_TEST_THROWS(value(object_kind).to_number<int>(), system_error);
+        BOOST_TEST_THROWS_WITH_LOCATION(value(nullptr).to_number<int>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(false).to_number<int>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(string_kind).to_number<int>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(array_kind).to_number<int>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(object_kind).to_number<int>());
 
-        BOOST_TEST_THROWS(value(nullptr).to_number<unsigned>(), system_error);
-        BOOST_TEST_THROWS(value(false).to_number<unsigned>(), system_error);
-        BOOST_TEST_THROWS(value(string_kind).to_number<unsigned>(), system_error);
-        BOOST_TEST_THROWS(value(array_kind).to_number<unsigned>(), system_error);
-        BOOST_TEST_THROWS(value(object_kind).to_number<unsigned>(), system_error);
+        BOOST_TEST_THROWS_WITH_LOCATION(value(nullptr).to_number<unsigned>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(false).to_number<unsigned>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(string_kind).to_number<unsigned>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(array_kind).to_number<unsigned>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(object_kind).to_number<unsigned>());
 
-        BOOST_TEST_THROWS(value(nullptr).to_number<double>(), system_error);
-        BOOST_TEST_THROWS(value(false).to_number<double>(), system_error);
-        BOOST_TEST_THROWS(value(string_kind).to_number<double>(), system_error);
-        BOOST_TEST_THROWS(value(array_kind).to_number<double>(), system_error);
-        BOOST_TEST_THROWS(value(object_kind).to_number<double>(), system_error);
+        BOOST_TEST_THROWS_WITH_LOCATION(value(nullptr).to_number<double>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(false).to_number<double>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(string_kind).to_number<double>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(array_kind).to_number<double>());
+        BOOST_TEST_THROWS_WITH_LOCATION(value(object_kind).to_number<double>());
 
         {
             unsigned char V = 0;
@@ -1647,6 +1684,19 @@ public:
             EQAL(float);
             EQAL(double);
         }
+
+        {
+            error_code ec;
+            value(nullptr).to_number<double>(ec);
+            BOOST_TEST(ec == error::not_number);
+            BOOST_TEST(ec.has_location());
+        }
+
+        {
+            std::error_code ec;
+            value(nullptr).to_number<double>(ec);
+            BOOST_TEST(error::not_number == ec);
+        }
     }
 
     void
@@ -1670,185 +1720,224 @@ public:
         auto const& cboo(boo);
         auto const& cnul(nul);
 
-        // as_object()
+        // as_object() &
         {
-                  object& x = obj.as_object();
-            BOOST_TEST_THROWS(arr.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(str.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(i64.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(u64.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(dub.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(boo.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(nul.as_object(), std::invalid_argument);
+            object& x = obj.as_object();
+            BOOST_TEST_THROWS_WITH_LOCATION( arr.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( str.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( i64.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( u64.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( dub.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( boo.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( nul.as_object() );
             (void)x;
         }
 
-        // as_object() const
+        // as_object() const&
         {
             object const& x = cobj.as_object();
-            BOOST_TEST_THROWS(carr.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(cstr.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(ci64.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(cu64.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(cdub.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(cboo.as_object(), std::invalid_argument);
-            BOOST_TEST_THROWS(cnul.as_object(), std::invalid_argument);
+            BOOST_TEST_THROWS_WITH_LOCATION( carr.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cstr.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( ci64.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cu64.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cdub.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cboo.as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cnul.as_object() );
             (void)x;
         }
 
-        // as_array()
+        // as_object() &&
         {
-            BOOST_TEST_THROWS(obj.as_array(), std::invalid_argument);
-                   array& x = arr.as_array();
-            BOOST_TEST_THROWS(str.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(i64.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(u64.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(dub.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(boo.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(nul.as_array(), std::invalid_argument);
+            object&& x = std::move(obj).as_object();
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(arr).as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(str).as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(i64).as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(u64).as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(dub).as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(boo).as_object() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(nul).as_object() );
             (void)x;
         }
 
-        // as_array() const
+        // as_array() &
         {
-            BOOST_TEST_THROWS(cobj.as_array(), std::invalid_argument);
-             array const& x = carr.as_array();
-            BOOST_TEST_THROWS(cstr.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(ci64.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(cu64.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(cdub.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(cboo.as_array(), std::invalid_argument);
-            BOOST_TEST_THROWS(cnul.as_array(), std::invalid_argument);
+            array& x = arr.as_array();
+            BOOST_TEST_THROWS_WITH_LOCATION( obj.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( str.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( i64.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( u64.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( dub.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( boo.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( nul.as_array() );
             (void)x;
         }
 
-        // as_string()
+        // as_array() const&
         {
-            BOOST_TEST_THROWS(obj.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(arr.as_string(), std::invalid_argument);
-                  string& x = str.as_string();
-            BOOST_TEST_THROWS(i64.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(u64.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(dub.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(boo.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(nul.as_string(), std::invalid_argument);
+            array const& x = carr.as_array();
+            BOOST_TEST_THROWS_WITH_LOCATION( cobj.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cstr.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( ci64.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cu64.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cdub.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cboo.as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cnul.as_array() );
             (void)x;
         }
 
-        // as_string() const
+        // as_array() &&
+        {
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(obj).as_array() );
+            array&& x = std::move(arr).as_array();
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(str).as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(i64).as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(u64).as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(dub).as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(boo).as_array() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(nul).as_array() );
+            (void)x;
+        }
+
+        // as_string() &
+        {
+            string& x = str.as_string();
+            BOOST_TEST_THROWS_WITH_LOCATION( obj.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( arr.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( i64.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( u64.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( dub.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( boo.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( nul.as_string() );
+            (void)x;
+        }
+
+        // as_string() const&
         {
-            BOOST_TEST_THROWS(cobj.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(carr.as_string(), std::invalid_argument);
             string const& x = cstr.as_string();
-            BOOST_TEST_THROWS(ci64.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(cu64.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(cdub.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(cboo.as_string(), std::invalid_argument);
-            BOOST_TEST_THROWS(cnul.as_string(), std::invalid_argument);
+            BOOST_TEST_THROWS_WITH_LOCATION( cobj.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( carr.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( ci64.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cu64.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cdub.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cboo.as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cnul.as_string() );
+            (void)x;
+        }
+
+        // as_string() const&
+        {
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(obj).as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(arr).as_string() );
+            string&& x = std::move(str).as_string();
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(i64).as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(u64).as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(dub).as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(boo).as_string() );
+            BOOST_TEST_THROWS_WITH_LOCATION( std::move(nul).as_string() );
             (void)x;
         }
 
         // as_int64()
         {
-            BOOST_TEST_THROWS(obj.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(arr.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(str.as_int64(), std::invalid_argument);
             std::int64_t& x = i64.as_int64();
-            BOOST_TEST_THROWS(u64.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(dub.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(boo.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(nul.as_int64(), std::invalid_argument);
+            BOOST_TEST_THROWS_WITH_LOCATION( obj.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( arr.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( str.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( u64.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( dub.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( boo.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( nul.as_int64() );
             (void)x;
         }
 
         // as_int64() const
         {
-            BOOST_TEST_THROWS(cobj.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(carr.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(cstr.as_int64(), std::invalid_argument);
-      std::int64_t const& x = ci64.as_int64();
-            BOOST_TEST_THROWS(cu64.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(cdub.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(cboo.as_int64(), std::invalid_argument);
-            BOOST_TEST_THROWS(cnul.as_int64(), std::invalid_argument);
+            std::int64_t const& x = ci64.as_int64();
+            BOOST_TEST_THROWS_WITH_LOCATION( cobj.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( carr.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cstr.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cu64.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cdub.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cboo.as_int64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cnul.as_int64() );
             (void)x;
         }
 
         // as_uint64()
         {
-            BOOST_TEST_THROWS(obj.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(arr.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(str.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(i64.as_uint64(), std::invalid_argument);
-           std::uint64_t& x = u64.as_uint64();
-            BOOST_TEST_THROWS(dub.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(boo.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(nul.as_uint64(), std::invalid_argument);
+            std::uint64_t& x = u64.as_uint64();
+            BOOST_TEST_THROWS_WITH_LOCATION( obj.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( arr.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( str.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( i64.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( dub.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( boo.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( nul.as_uint64() );
             (void)x;
         }
 
         // as_uint64() const
         {
-            BOOST_TEST_THROWS(cobj.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(carr.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(cstr.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(ci64.as_uint64(), std::invalid_argument);
-     std::uint64_t const& x = cu64.as_uint64();
-            BOOST_TEST_THROWS(cdub.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(cboo.as_uint64(), std::invalid_argument);
-            BOOST_TEST_THROWS(cnul.as_uint64(), std::invalid_argument);
+            std::uint64_t const& x = cu64.as_uint64();
+            BOOST_TEST_THROWS_WITH_LOCATION( cobj.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( carr.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cstr.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( ci64.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cdub.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cboo.as_uint64() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cnul.as_uint64() );
             (void)x;
         }
 
         // as_double()
         {
-            BOOST_TEST_THROWS(obj.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(arr.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(str.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(i64.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(u64.as_double(), std::invalid_argument);
-                  double& x = dub.as_double();
-            BOOST_TEST_THROWS(boo.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(nul.as_double(), std::invalid_argument);
+            double& x = dub.as_double();
+            BOOST_TEST_THROWS_WITH_LOCATION( obj.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( arr.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( str.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( i64.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( u64.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( boo.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( nul.as_double() );
             (void)x;
         }
 
         // as_double() const
         {
-            BOOST_TEST_THROWS(cobj.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(carr.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(cstr.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(ci64.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(cu64.as_double(), std::invalid_argument);
             double const& x = cdub.as_double();
-            BOOST_TEST_THROWS(cboo.as_double(), std::invalid_argument);
-            BOOST_TEST_THROWS(cnul.as_double(), std::invalid_argument);
+            BOOST_TEST_THROWS_WITH_LOCATION( cobj.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( carr.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cstr.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( ci64.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cu64.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cboo.as_double() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cnul.as_double() );
             (void)x;
         }
 
         // as_bool()
         {
-            BOOST_TEST_THROWS(obj.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(arr.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(str.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(i64.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(u64.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(dub.as_bool(), std::invalid_argument);
-                    bool& x = boo.as_bool();
-            BOOST_TEST_THROWS(nul.as_bool(), std::invalid_argument);
+            bool& x = boo.as_bool();
+            BOOST_TEST_THROWS_WITH_LOCATION( obj.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( arr.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( str.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( i64.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( u64.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( dub.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( nul.as_bool() );
             (void)x;
         }
 
         // as_bool() const
         {
-            BOOST_TEST_THROWS(cobj.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(carr.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(cstr.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(ci64.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(cu64.as_bool(), std::invalid_argument);
-            BOOST_TEST_THROWS(cdub.as_bool(), std::invalid_argument);
-               bool const&x = cboo.as_bool();
-            BOOST_TEST_THROWS(cnul.as_bool(), std::invalid_argument);
+            bool const&x = cboo.as_bool();
+            BOOST_TEST_THROWS_WITH_LOCATION( cobj.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( carr.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cstr.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( ci64.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cu64.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cdub.as_bool() );
+            BOOST_TEST_THROWS_WITH_LOCATION( cnul.as_bool() );
             (void)x;
         }
     }
@@ -1872,9 +1961,9 @@ public:
         auto const& cdub(dub);
         auto const& cboo(boo);
 
-        // get_object()
-        // get_array()
-        // get_string()
+        // get_object() &
+        // get_array() &
+        // get_string() &
         // get_int64()
         // get_uint64()
         // get_double()
@@ -1897,9 +1986,9 @@ public:
             (void)(xboo);
         }
 
-        // get_object() const
-        // get_array() const
-        // get_string() const
+        // get_object() const&
+        // get_array() const&
+        // get_string() const&
         // get_int64() const
         // get_uint64() const
         // get_double() const
@@ -1923,31 +2012,55 @@ public:
             (void)(xdub);
             (void)(xboo);
         }
+
+        // get_object() &&
+        // get_array() &&
+        // get_string() &&
+        {
+            object&& xobj = std::move(obj).get_object();
+            array&&  xarr = std::move(arr).get_array();
+            string&& xstr = std::move(str).get_string();
+
+            (void)(xobj);
+            (void)(xarr);
+            (void)(xstr);
+        }
     }
 
     void
     testAt()
     {
         // object
-        BOOST_TEST(value(
-            {{"k1", "value"}, {"k2", nullptr}}
-                ).at("k1").as_string() == "value");
-        BOOST_TEST_THROWS(value(
-            {{"k1", "value"}, {"k2", nullptr}}
-                ).at("null"),
-            std::out_of_range);
+        value jvo{{"k1", "value"}, {"k2", nullptr}};
+        value const& cjvo = jvo;
+        BOOST_TEST( cjvo.at("k1").as_string() == "value" );
+
+        jvo.at("k1") = {1, 2, 3};
+        BOOST_TEST( cjvo.at("k1") == array({1, 2, 3}) );
+
+        auto&& elem1 = std::move(jvo).at("k1");
+        BOOST_TEST( &elem1 == &jvo.at("k1") );
+
+        BOOST_TEST_THROWS_WITH_LOCATION( cjvo.at("null") );
 
         // array
-        BOOST_TEST(
-            value({true,2,"3"}).at(1).as_int64() == 2);
+        value jva{true,2,"3"};
+        value const& cjva = jva;
+        BOOST_TEST( cjva.at(1).as_int64() == 2 );
 
-        BOOST_TEST_THROWS( value({false,2,false}).at(4), std::out_of_range );
-        BOOST_TEST_THROWS( value({false,2,"3"}).at(4), std::out_of_range );
-        BOOST_TEST_THROWS( value({false,false}).at(4), std::out_of_range );
-        BOOST_TEST_THROWS( value({false,2}).at(4), std::out_of_range );
-        BOOST_TEST_THROWS( value({false,2,"3",nullptr}).at(4), std::out_of_range );
-        BOOST_TEST_THROWS( value({2,false,"3"}).at(4), std::out_of_range );
-        BOOST_TEST_THROWS( value({true,2,"3"}).at(4), std::out_of_range );
+        jva.at(1) = "item";
+        BOOST_TEST( cjva.at(1) == "item" );
+
+        auto&& elem2 = std::move(jva).at(1);
+        BOOST_TEST( &elem2 == &jva.at(1) );
+
+        BOOST_TEST_THROWS_WITH_LOCATION( value({false,2,false}).at(4) );
+        BOOST_TEST_THROWS_WITH_LOCATION( value({false,2,"3"}).at(4) );
+        BOOST_TEST_THROWS_WITH_LOCATION( value({false,false}).at(4) );
+        BOOST_TEST_THROWS_WITH_LOCATION( value({false,2}).at(4) );
+        BOOST_TEST_THROWS_WITH_LOCATION( value({false,2,"3",nullptr}).at(4) );
+        BOOST_TEST_THROWS_WITH_LOCATION( value({2,false,"3"}).at(4) );
+        BOOST_TEST_THROWS_WITH_LOCATION( value({true,2,"3"}).at(4) );
     }
 
     //------------------------------------------------------
@@ -2018,6 +2131,57 @@ public:
     void
     testInitList()
     {
+        {
+            value jv1{};
+            BOOST_TEST( jv1.is_null() );
+
+            value jv2 = {};
+            BOOST_TEST( jv2.is_null() );
+
+            value jv3 = value{};
+            BOOST_TEST( jv3.is_null() );
+        }
+        {
+            value jv1{1, 2};
+            BOOST_TEST(( jv1 == array{1,2} ));
+
+            value jv2 = {1, 2};
+            BOOST_TEST(( jv2 == array{1,2} ));
+
+            value jv3 = value{1, 2};
+            BOOST_TEST(( jv3 == array{1,2} ));
+
+            value jv4{{1, 2}};
+            BOOST_TEST(( jv4 == array{1,2} ));
+
+            value jv5 = {{1, 2}};
+            BOOST_TEST(( jv5 == array{1,2} ));
+
+            value jv6 = value{{1, 2}};
+            BOOST_TEST(( jv6 == array{1,2} ));
+        }
+        {
+#ifndef BOOST_JSON_LEGACY_INIT_LIST_BEHAVIOR
+            value jv1{0};
+            BOOST_TEST( jv1 == 0 );
+
+            value jv2 = {0};
+            BOOST_TEST( jv2 == 0 );
+
+            value jv3 = value{0};
+            BOOST_TEST( jv3 == 0 );
+
+#endif
+            value jv4{{0}};
+            BOOST_TEST( jv4 == array{0} );
+
+            value jv5 = {{0}};
+            BOOST_TEST( jv5 == array{0} );
+
+            value jv6 = value{{0}};
+            BOOST_TEST( jv6 == array{0} );
+        }
+
         check_array(value{0,0,0},               0, 0, 0);
         check_array(value{false,false,false},   false, false, false);
         check_array(value{false,2,false},       false, 2, false);
@@ -2026,7 +2190,17 @@ public:
         check_array(value{false,2},             false, 2);
         check_array(value{false,2,"3",nullptr}, false, 2, "3", nullptr);
         check_array(value{2,false,"3"},         2, false, "3");
-        check_array(value{true,2,"3"},          true, 2, "3");    
+        check_array(value{true,2,"3"},          true, 2, "3");
+
+        check_array({0,0,0},               0, 0, 0);
+        check_array({false,false,false},   false, false, false);
+        check_array({false,2,false},       false, 2, false);
+        check_array({false,2,"3"},         false, 2, "3");
+        check_array({false,false},         false, false);
+        check_array({false,2},             false, 2);
+        check_array({false,2,"3",nullptr}, false, 2, "3", nullptr);
+        check_array({2,false,"3"},         2, false, "3");
+        check_array({true,2,"3"},          true, 2, "3");
     }
 
     //------------------------------------------------------
@@ -2087,6 +2261,142 @@ public:
             {"a",1}, {"b",2}, {"c",3} }) != value(nullptr));
     }
 
+    void
+    testHash()
+    {
+        BOOST_TEST(check_hash_equal(value(nullptr), value(nullptr)));
+        BOOST_TEST(check_hash_equal(value(nullptr), value()));
+        BOOST_TEST(check_hash_equal(value(nullptr), value{}));
+        BOOST_TEST(expect_hash_not_equal(value(nullptr), value({})));
+        BOOST_TEST(expect_hash_not_equal(value(nullptr), value({object()})));
+        BOOST_TEST(expect_hash_not_equal(value(nullptr), value(true)));
+        BOOST_TEST(expect_hash_not_equal(value(nullptr), value(false)));
+        BOOST_TEST(expect_hash_not_equal(value(nullptr), value(0)));
+        BOOST_TEST(expect_hash_not_equal(value(nullptr), value(0UL)));
+        BOOST_TEST(expect_hash_not_equal(value(nullptr), value(0.0)));
+        BOOST_TEST(expect_hash_not_equal(value(nullptr), value("")));
+
+        BOOST_TEST(check_hash_equal(value(true), value(true)));
+        BOOST_TEST(check_hash_equal(value(false), value(false)));
+        BOOST_TEST(expect_hash_not_equal(value(false), value(true)));
+        BOOST_TEST(expect_hash_not_equal(value(false), value(0)));
+        BOOST_TEST(expect_hash_not_equal(value(false), value(0UL)));
+        BOOST_TEST(expect_hash_not_equal(value(false), value(0.0)));
+        BOOST_TEST(expect_hash_not_equal(value(true), value(1)));
+        BOOST_TEST(expect_hash_not_equal(value(true), value(1UL)));
+        BOOST_TEST(expect_hash_not_equal(value(true), value(1.0)));
+
+        BOOST_TEST(check_hash_equal(value(2021), value(2021UL)));
+        BOOST_TEST(expect_hash_not_equal(value(2021U), value(-2021)));
+        BOOST_TEST(expect_hash_not_equal(value(2021UL), value(2021.0)));
+
+        BOOST_TEST(expect_hash_not_equal(value({}), value({object()})));
+        BOOST_TEST(expect_hash_not_equal(value({}), value("")));
+        BOOST_TEST(expect_hash_not_equal(value({object()}), value("")));
+
+        BOOST_TEST(check_hash_equal(
+            value({{"a",1}, {"b",2}, {"c",3}}),
+            value({{"b",2}, {"c",3}, {"a",1}})));
+        BOOST_TEST(expect_hash_not_equal(
+            value({{"a",1}, {"b",2}, {"c",3}}),
+            value({{"b",2}, {"c",3}})));
+        BOOST_TEST(check_hash_equal(
+            value({"a", "b", 17}),
+            value({"a", "b", 17U})));
+        BOOST_TEST(expect_hash_not_equal(
+            value({"a", "b", 17}),
+            value({17, "a", "b"})));
+        BOOST_TEST(expect_hash_not_equal(
+            value({"a", "b"}),
+            value({{"a", "b"}})));
+    }
+
+    void
+    testIstream()
+    {
+        std::istringstream ss(
+            R"({ "x": 1
+               , "y": 2
+               , "z": [77, null, true, "qwerty uiop"]
+               }_12)");
+        value jv;
+
+        ss >> jv;
+        BOOST_TEST( !!ss );
+        BOOST_TEST((
+            jv == value{
+                {"x", 1},
+                {"y", 2},
+                {"z", {77, nullptr, true, "qwerty uiop"}}} ));
+
+        // check we didn't consume any extra characters
+        std::string s;
+        std::getline(ss, s);
+        BOOST_TEST( s == "_12" );
+
+        ss.clear();
+        ss.str("23");
+        ss >> jv;
+        BOOST_TEST( jv == 23 );
+
+        ss.clear();
+        ss.str("");
+        ss >> jv;
+        BOOST_TEST( jv == 23 );
+        BOOST_TEST( ss.rdstate() == (std::ios::failbit | std::ios::eofbit) );
+
+        ss.clear();
+        ss.str("nu");
+        ss >> jv;
+        BOOST_TEST( jv == 23 );
+        BOOST_TEST( ss.rdstate() == (std::ios::failbit | std::ios::eofbit) );
+
+        ss.clear();
+        ss.str("[1,2,3,4,]");
+        ss >> jv;
+        BOOST_TEST( jv == 23 );
+        BOOST_TEST( ss.rdstate() == std::ios::failbit );
+
+        {
+            throwing_buffer buf;
+            std::istream is(&buf);
+            is >> jv;
+            BOOST_TEST( jv == 23 );
+            BOOST_TEST( is.rdstate() & std::ios::badbit );
+        }
+        {
+            throwing_buffer buf;
+            std::istream is(&buf);
+            is.exceptions(std::ios::badbit);
+            BOOST_TEST_THROWS( is >> jv, std::invalid_argument );
+            BOOST_TEST( jv == 23 );
+            BOOST_TEST( is.rdstate() & std::ios::badbit );
+        }
+
+        s = "[1,2,3,4, // here goes EOL\n"
+            "  [5,6,7, // and another one\n"
+            "    [8,9]]]";
+
+        parse_options opts;
+        opts.max_depth = 2;
+        opts.allow_comments = true;
+        ss.clear();
+        ss.str(s);
+        ss >> opts >> jv;
+        BOOST_TEST( ss.rdstate() == std::ios::failbit );
+
+        ss.clear();
+        ss.str(s);
+        opts.max_depth = 3;
+        ss >> opts >> jv;
+        BOOST_TEST(( jv == value{1,2,3,4,{5,6,7,{8,9}}} ));
+
+        ss.clear();
+        ss.str( "[1,2,3,4,]" ); // trailing comma should fail
+        ss >> opts >> jv;
+        BOOST_TEST( ss.rdstate() == std::ios::failbit );
+    }
+
     //------------------------------------------------------
 
     void
@@ -2108,9 +2418,12 @@ public:
         testStdConstruction();
         testInitList();
         testEquality();
+        testHash();
+        testIstream();
     }
 };
 
 TEST_SUITE(value_test, "boost.json.value");
 
-BOOST_JSON_NS_END
+} // namespace json
+} // namespace boost
