@@ -12,7 +12,8 @@
 // -----------------------------------------------------------------------
 
 
-#include <boost/test/minimal.hpp>    // see "Header Implementation Option"
+#include <boost/core/lightweight_test.hpp>
+#define BOOST_CHECK BOOST_TEST
 
 
 #include "boost/lambda/lambda.hpp"
@@ -29,7 +30,7 @@ class base {
 public:
   virtual std::string class_name() const { return "const base"; }
   virtual std::string class_name() { return "base"; }
-
+  virtual ~base() {}
 };
 
 class derived : public base {
@@ -100,8 +101,8 @@ void do_test() {
 
 }
 
-int test_main(int, char *[]) {
+int main() {
 
   do_test();
-  return 0;
+  return boost::report_errors();
 }
