@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2021 Emil Dotchevski and Reverge Studios, Inc.
+// Copyright 2018-2023 Emil Dotchevski and Reverge Studios, Inc.
 
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -11,17 +11,27 @@
 #   include <boost/leaf/result.hpp>
 #endif
 
+#if BOOST_LEAF_CFG_STD_STRING
+#   include <sstream>
+#   include <iostream>
+#endif
+
 #include "lightweight_test.hpp"
-#include <sstream>
 
 namespace leaf = boost::leaf;
 
 int main()
 {
     errno = ENOENT;
+#if BOOST_LEAF_CFG_STD_STRING
     std::stringstream ss;
     ss << leaf::e_errno{};
-    BOOST_TEST(ss.str().find(std::strerror(ENOENT)) != std::string::npos);
+    std::string s = ss.str();
+    std::cout << s << std::endl;
+#if BOOST_LEAF_CFG_STD_DIAGNOSTICS
+    BOOST_TEST(s.find(std::strerror(ENOENT)) != std::string::npos);
+#endif
+#endif
 
     int r = leaf::try_handle_all(
         []() -> leaf::result<int>
