@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2021 Emil Dotchevski and Reverge Studios, Inc.
+// Copyright 2018-2023 Emil Dotchevski and Reverge Studios, Inc.
 
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -15,6 +15,12 @@
 
 namespace leaf = boost::leaf;
 
+static_assert(std::is_same<void, leaf::result<void>::value_type>::value, "Bad value_type");
+static_assert(std::is_same<int, leaf::result<int>::value_type>::value, "Bad value_type");
+static_assert(std::is_same<int const, leaf::result<int const>::value_type>::value, "Bad value_type");
+static_assert(std::is_same<int &, leaf::result<int &>::value_type>::value, "Bad value_type");
+static_assert(std::is_same<int const &, leaf::result<int const &>::value_type>::value, "Bad value_type");
+
 struct val
 {
     static int id_count;
@@ -84,17 +90,17 @@ struct err
 int err::count = 0;
 struct e_err { err value; };
 
-bool eq_value( leaf::result<val> & r1, leaf::result<val> & r2 )
+bool eq_value( leaf::result<val> & r, val v )
 {
-    leaf::result<val> const & cr1 = r1;
-    leaf::result<val> const & cr2 = r2;
+    leaf::result<val> const & cr = r;
+    val const & cv = v;
     return
-        r1.value()==r2.value() &&
-        cr1.value()==cr2.value() &&
-        *r1==*r2 &&
-        *cr1==*cr2 &&
-        r1->id==r2->id &&
-        cr1->id==cr2->id;
+        r.value()==v &&
+        cr.value()==cv &&
+        *r.operator->()==v &&
+        *cr.operator->()==cv &&
+        *r==v &&
+        *cr==cv;
 }
 
 int main()
@@ -129,10 +135,12 @@ int main()
         BOOST_TEST(r1);
         BOOST_TEST_EQ(err::count, 0);
         BOOST_TEST_EQ(val::count, 2);
+        BOOST_TEST(eq_value(r1, v));
         leaf::result<val> r2 = std::move(r1);
         BOOST_TEST(r2);
         BOOST_TEST_EQ(err::count, 0);
         BOOST_TEST_EQ(val::count, 3);
+        BOOST_TEST(eq_value(r2, v));
     }
     BOOST_TEST_EQ(err::count, 0);
     BOOST_TEST_EQ(val::count, 0);
@@ -167,16 +175,19 @@ int main()
         BOOST_TEST(r1);
         BOOST_TEST_EQ(err::count, 0);
         BOOST_TEST_EQ(val::count, 2);
+        BOOST_TEST(eq_value(r1, v));
         leaf::result<val> r2; r2=std::move(r1);
         BOOST_TEST(r2);
         BOOST_TEST_EQ(err::count, 0);
         BOOST_TEST_EQ(val::count, 3);
+        BOOST_TEST(eq_value(r2, v));
     }
     BOOST_TEST_EQ(err::count, 0);
     BOOST_TEST_EQ(val::count, 0);
 
     using context_type = leaf::leaf_detail::polymorphic_context_impl<leaf::context<e_err>>;
 
+#if BOOST_LEAF_CFG_CAPTURE
     { // value default -> capture -> move
         leaf::result<val> r1 = leaf::capture( std::make_shared<context_type>(), []{ return leaf::result<val>(); } );
         BOOST_TEST(r1);
@@ -250,6 +261,7 @@ int main()
         }
     BOOST_TEST_EQ(err::count, 0);
     BOOST_TEST_EQ(val::count, 0);
+#endif
 
     // ^^ value ^^
     // vv error vv
@@ -325,6 +337,7 @@ int main()
     BOOST_TEST_EQ(err::count, 0);
     BOOST_TEST_EQ(val::count, 0);
 
+#if BOOST_LEAF_CFG_CAPTURE
     { // error move -> capture -> move
         leaf::result<val> r1 = leaf::capture( std::make_shared<context_type>(), []{ return leaf::result<val>( leaf::new_error( e_err { } ) ); } );
         BOOST_TEST(!r1);
@@ -382,6 +395,7 @@ int main()
     }
     BOOST_TEST_EQ(err::count, 0);
     BOOST_TEST_EQ(val::count, 0);
+#endif
 
     // ^^ result<T> ^^
 
@@ -392,30 +406,55 @@ int main()
     { // void default -> move
         leaf::result<void> r1;
         BOOST_TEST(r1);
+        r1.value();
+        BOOST_TEST(r1.operator->() != 0);
+        *r1;
         leaf::result<void> r2 = std::move(r1);
         BOOST_TEST(r2);
+        r2.value();
+        BOOST_TEST(r2.operator->() != 0);
+        *r2;
     }
 
     { // void default -> assign-move
         leaf::result<void> r1;
         BOOST_TEST(r1);
+        r1.value();
+        BOOST_TEST(r1.operator->() != 0);
+        *r1;
         leaf::result<void> r2; r2=std::move(r1);
         BOOST_TEST(r2);
+        r2.value();
+        BOOST_TEST(r2.operator->() != 0);
+        *r2;
     }
 
+#if BOOST_LEAF_CFG_CAPTURE
     { // void default -> capture -> move
         leaf::result<void> r1 = leaf::capture( std::make_shared<context_type>(), []{ return leaf::result<void>(); } );
         BOOST_TEST(r1);
+        r1.value();
+        BOOST_TEST(r1.operator->() != 0);
+        *r1;
         leaf::result<void> r2 = std::move(r1);
         BOOST_TEST(r2);
+        r2.value();
+        BOOST_TEST(r2.operator->() != 0);
+        *r2;
     }
-
     { // void default -> capture -> assign-move
         leaf::result<void> r1 = leaf::capture( std::make_shared<context_type>(), []{ return leaf::result<void>(); } );
         BOOST_TEST(r1);
+        r1.value();
+        BOOST_TEST(r1.operator->() != 0);
+        *r1;
         leaf::result<void> r2; r2=std::move(r1);
         BOOST_TEST(r2);
+        r2.value();
+        BOOST_TEST(r2.operator->() != 0);
+        *r2;
     }
+#endif
 
     // ^^ void default ^^
     // vv void error vv
@@ -425,12 +464,14 @@ int main()
         auto active_context = activate_context(ctx);
         leaf::result<void> r1 = leaf::new_error( e_err { } );
         BOOST_TEST(!r1);
+        BOOST_TEST(r1.operator->() == 0);
         BOOST_TEST_EQ(err::count, 1);
         leaf::error_id r1e = r1.error();
         leaf::result<void> r2 = std::move(r1);
         leaf::error_id r2e = r2.error();
         BOOST_TEST_EQ(r1e, r2e);
         BOOST_TEST(!r2);
+        BOOST_TEST(r2.operator->() == 0);
     }
     BOOST_TEST_EQ(err::count, 0);
     { // void error copy -> move
@@ -439,12 +480,14 @@ int main()
         leaf::error_id err = leaf::new_error( e_err{ } );
         leaf::result<void> r1 = err;
         BOOST_TEST(!r1);
+        BOOST_TEST(r1.operator->() == 0);
         BOOST_TEST_EQ(err::count, 1);
         leaf::error_id r1e = r1.error();
         leaf::result<void> r2 = std::move(r1);
         leaf::error_id r2e = r2.error();
         BOOST_TEST_EQ(r1e, r2e);
         BOOST_TEST(!r2);
+        BOOST_TEST(r2.operator->() == 0);
     }
     BOOST_TEST_EQ(err::count, 0);
 
@@ -454,12 +497,14 @@ int main()
         leaf::result<void> r1 = leaf::new_error( e_err { } );
         ctx.deactivate();
         BOOST_TEST(!r1);
+        BOOST_TEST(r1.operator->() == 0);
         BOOST_TEST_EQ(err::count, 1);
         leaf::error_id r1e = r1.error();
         leaf::result<void> r2; r2=std::move(r1);
         leaf::error_id r2e = r2.error();
         BOOST_TEST_EQ(r1e, r2e);
         BOOST_TEST(!r2);
+        BOOST_TEST(r2.operator->() == 0);
         ctx.handle_error<void>(r2.error(), []{ });
         BOOST_TEST_EQ(err::count, 1);
     }
@@ -470,60 +515,72 @@ int main()
         leaf::error_id err = leaf::new_error( e_err{ } );
         leaf::result<void> r1 = err;
         BOOST_TEST(!r1);
+        BOOST_TEST(r1.operator->() == 0);
         BOOST_TEST_EQ(err::count, 1);
         leaf::error_id r1e = r1.error();
         leaf::result<void> r2; r2=std::move(r1);
         leaf::error_id r2e = r2.error();
         BOOST_TEST_EQ(r1e, r2e);
         BOOST_TEST(!r2);
+        BOOST_TEST(r2.operator->() == 0);
     }
     BOOST_TEST_EQ(err::count, 0);
 
+#if BOOST_LEAF_CFG_CAPTURE
     { // void error move -> capture -> move
         leaf::result<void> r1 = leaf::capture( std::make_shared<context_type>(), []{ return leaf::result<void>( leaf::new_error( e_err { } ) ); } );
         BOOST_TEST(!r1);
+        BOOST_TEST(r1.operator->() == 0);
         BOOST_TEST_EQ(err::count, 1);
         leaf::error_id r1e = r1.error();
         leaf::result<void> r2 = std::move(r1);
         leaf::error_id r2e = r2.error();
         BOOST_TEST_EQ(r1e, r2e);
         BOOST_TEST(!r2);
+        BOOST_TEST(r2.operator->() == 0);
     }
     BOOST_TEST_EQ(err::count, 0);
     { // void error copy -> capture -> move
         leaf::result<void> r1 = leaf::capture( std::make_shared<context_type>(), []{ leaf::error_id err = leaf::new_error( e_err{ } ); return leaf::result<void>(err); } );
         BOOST_TEST(!r1);
+        BOOST_TEST(r1.operator->() == 0);
         BOOST_TEST_EQ(err::count, 1);
         leaf::error_id r1e = r1.error();
         leaf::result<void> r2 = std::move(r1);
         leaf::error_id r2e = r2.error();
         BOOST_TEST_EQ(r1e, r2e);
         BOOST_TEST(!r2);
+        BOOST_TEST(r2.operator->() == 0);
     }
     BOOST_TEST_EQ(err::count, 0);
 
     { // void error move -> capture -> assign-move
         leaf::result<void> r1 = leaf::capture( std::make_shared<context_type>(), []{ return leaf::result<void>( leaf::new_error( e_err { } ) ); } );
         BOOST_TEST(!r1);
+        BOOST_TEST(r1.operator->() == 0);
         BOOST_TEST_EQ(err::count, 1);
         leaf::error_id r1e = r1.error();
         leaf::result<void> r2; r2=std::move(r1);
         leaf::error_id r2e = r2.error();
         BOOST_TEST_EQ(r1e, r2e);
         BOOST_TEST(!r2);
+        BOOST_TEST(r2.operator->() == 0);
     }
     BOOST_TEST_EQ(err::count, 0);
     { // void error copy -> capture -> assign-move
         leaf::result<void> r1 = leaf::capture( std::make_shared<context_type>(), []{ leaf::error_id err = leaf::new_error( e_err{ } ); return leaf::result<void>(err); } );
         BOOST_TEST(!r1);
+        BOOST_TEST(r1.operator->() == 0);
         BOOST_TEST_EQ(err::count, 1);
         leaf::error_id r1e = r1.error();
         leaf::result<void> r2; r2=std::move(r1);
         leaf::error_id r2e = r2.error();
         BOOST_TEST_EQ(r1e, r2e);
         BOOST_TEST(!r2);
+        BOOST_TEST(r2.operator->() == 0);
     }
     BOOST_TEST_EQ(err::count, 0);
+#endif
 
     {
         leaf::result<int> r = leaf::error_id();
@@ -576,17 +633,21 @@ int main()
     }
     BOOST_TEST_EQ(val::count, 0);
 
+#if BOOST_LEAF_CFG_STD_STRING
     { // Initialization forwarding constructor
         leaf::result<std::string> r = "hello";
         BOOST_TEST(r);
         BOOST_TEST_EQ(r.value(), "hello");
     }
+#endif
 
+#if BOOST_LEAF_CFG_STD_STRING
     { // Initialization forwarding constructor
         leaf::result<std::string> r; r = "hello";
         BOOST_TEST(r);
         BOOST_TEST_EQ(r.value(), "hello");
     }
+#endif
 
     return boost::report_errors();
 }
