@@ -2,22 +2,17 @@
 //
 //  See http://www.boost.org for most recent version, including documentation.
 //
-//  Copyright Antony Polukhin, 2013-2021.
+//  Copyright Antony Polukhin, 2013-2023.
 //
 //  Distributed under the Boost
 //  Software License, Version 1.0. (See accompanying file
 //  LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt).
 
 #include <boost/lexical_cast.hpp>
-#include <boost/type.hpp>
 
-#define BOOST_INCLUDE_MAIN
-#include <boost/test/test_tools.hpp>
-
-int test_main(int, char*[])
+int main()
 {
     boost::lexical_cast<char*>("Hello");
-    BOOST_CHECK(false); // suppressing warning about 'boost::unit_test::{anonymous}::unit_test_log' defined but not used
-    return 0;
+    return 1;
 }
 
