@@ -1,50 +1,47 @@
 var group__date__time =
 [
-    [ "period", "namespaceboost_1_1locale_1_1period.html", null ],
-    [ "time_zone", "namespaceboost_1_1locale_1_1time__zone.html", null ],
-    [ "date_time_error", "classboost_1_1locale_1_1date__time__error.html", [
+    [ "boost::locale::period", "namespaceboost_1_1locale_1_1period.html", null ],
+    [ "boost::locale::time_zone", "namespaceboost_1_1locale_1_1time__zone.html", null ],
+    [ "boost::locale::date_time_error", "classboost_1_1locale_1_1date__time__error.html", [
       [ "date_time_error", "classboost_1_1locale_1_1date__time__error.html#a25580392651d96c752a67f01ea853542", null ]
     ] ],
-    [ "date_time_period", "structboost_1_1locale_1_1date__time__period.html", [
+    [ "boost::locale::date_time_period", "structboost_1_1locale_1_1date__time__period.html", [
       [ "date_time_period", "structboost_1_1locale_1_1date__time__period.html#a61b11b2243098412dddd804ca7e104af", null ],
       [ "operator+", "structboost_1_1locale_1_1date__time__period.html#a4db4cc5a2c415dc54ab5d67185881900", null ],
       [ "operator-", "structboost_1_1locale_1_1date__time__period.html#a42337ef4ab1008fc5deeb548c01905ca", null ],
       [ "type", "structboost_1_1locale_1_1date__time__period.html#aa6511600eb5264c8597f700668e9c628", null ],
       [ "value", "structboost_1_1locale_1_1date__time__period.html#aec776b16ed46a22833308a4112886ca4", null ]
     ] ],
-    [ "date_time_period_set", "classboost_1_1locale_1_1date__time__period__set.html", [
-      [ "date_time_period_set", "classboost_1_1locale_1_1date__time__period__set.html#a635b8d91c4c8da99857810e42a0aff65", null ],
+    [ "boost::locale::date_time_period_set", "classboost_1_1locale_1_1date__time__period__set.html", [
+      [ "date_time_period_set", "classboost_1_1locale_1_1date__time__period__set.html#a0d14216cd4a4dae3645900c78fb77070", null ],
       [ "date_time_period_set", "classboost_1_1locale_1_1date__time__period__set.html#a0966962f5da78fc06121d1455efcbbae", null ],
       [ "date_time_period_set", "classboost_1_1locale_1_1date__time__period__set.html#a5867088d009104d8d3725d52ad0ac2bd", null ],
       [ "add", "classboost_1_1locale_1_1date__time__period__set.html#a0e70247c1738dbf6869e6d8c04461893", null ],
-      [ "operator[]", "classboost_1_1locale_1_1date__time__period__set.html#a47b0a2759cbacd296d91929ddd453dcb", null ],
+      [ "operator[]", "classboost_1_1locale_1_1date__time__period__set.html#acc79f97dbd47a6e94329b45f93dcfa00", null ],
       [ "size", "classboost_1_1locale_1_1date__time__period__set.html#a14b5c2e199b3458d5faee0dc572b2f28", null ]
     ] ],
-    [ "calendar", "classboost_1_1locale_1_1calendar.html", [
+    [ "boost::locale::calendar", "classboost_1_1locale_1_1calendar.html", [
       [ "calendar", "classboost_1_1locale_1_1calendar.html#a889746f73b03bb21f5c8459cbe9b293d", null ],
       [ "calendar", "classboost_1_1locale_1_1calendar.html#adee95b95c8635f7a3515e6116c6a12a2", null ],
       [ "calendar", "classboost_1_1locale_1_1calendar.html#ac083baf94c478302dde8a28d64a973c4", null ],
       [ "calendar", "classboost_1_1locale_1_1calendar.html#a111b9a81f231b3b4555eb122a02e366d", null ],
       [ "calendar", "classboost_1_1locale_1_1calendar.html#a56c55c24fbbb29fac5a18c44d3a27beb", null ],
-      [ "~calendar", "classboost_1_1locale_1_1calendar.html#a378ecd62f6cc64928ab308b180c98b21", null ],
       [ "calendar", "classboost_1_1locale_1_1calendar.html#ad6a28e60830f466c749c9cbbab3e1360", null ],
       [ "first_day_of_week", "classboost_1_1locale_1_1calendar.html#a7a0f1c79578137bbbb63de3fe8f05383", null ],
-      [ "get_locale", "classboost_1_1locale_1_1calendar.html#a71bf8666365059c21bfba2de2e02d2c9", null ],
-      [ "get_time_zone", "classboost_1_1locale_1_1calendar.html#ae9b32820cc9c8aa9962d339d833f9960", null ],
+      [ "get_locale", "classboost_1_1locale_1_1calendar.html#aec861ac1985d0ceaf332ed1944f115c8", null ],
+      [ "get_time_zone", "classboost_1_1locale_1_1calendar.html#a0ad69716969c51a46d12e567cf9dd2fd", null ],
       [ "greatest_minimum", "classboost_1_1locale_1_1calendar.html#a175df8244754dec5c748cc2bd031a60c", null ],
       [ "is_gregorian", "classboost_1_1locale_1_1calendar.html#a42684e8e81a48309c3917735b1810506", null ],
       [ "least_maximum", "classboost_1_1locale_1_1calendar.html#a52d6099c1b4a38110bd3ed595075d4c0", null ],
       [ "maximum", "classboost_1_1locale_1_1calendar.html#a1f201a7c283ea00d75601b0d804b0878", null ],
       [ "minimum", "classboost_1_1locale_1_1calendar.html#a7d76bef064eedbe9c4d838b7b0a76f1c", null ],
       [ "operator!=", "classboost_1_1locale_1_1calendar.html#adc1dad63217b601527c253af34406cab", null ],
-      [ "operator=", "classboost_1_1locale_1_1calendar.html#aeae9cae78ff85587e32f630ca71963a7", null ],
-      [ "operator==", "classboost_1_1locale_1_1calendar.html#a5a510078e9bd0ba311cfbc612a662280", null ],
-      [ "date_time", "classboost_1_1locale_1_1calendar.html#a7c627d823bfb1186af76ed36016cbb31", null ]
+      [ "operator=", "classboost_1_1locale_1_1calendar.html#a1fd80b8d57ca0921c71bd16fe40c9660", null ],
+      [ "operator==", "classboost_1_1locale_1_1calendar.html#a5a510078e9bd0ba311cfbc612a662280", null ]
     ] ],
-    [ "date_time", "classboost_1_1locale_1_1date__time.html", [
+    [ "boost::locale::date_time", "classboost_1_1locale_1_1date__time.html", [
       [ "date_time", "classboost_1_1locale_1_1date__time.html#ae7a3b74e7512ddc4d618eb1f51c3d2b0", null ],
       [ "date_time", "classboost_1_1locale_1_1date__time.html#a7144d1e240a2d7433039dba9984ea618", null ],
-      [ "date_time", "classboost_1_1locale_1_1date__time.html#a2e8589e260604cf2cd7c43380392d0d2", null ],
       [ "date_time", "classboost_1_1locale_1_1date__time.html#ad09863ad4367277fa34a742368e20db1", null ],
       [ "date_time", "classboost_1_1locale_1_1date__time.html#addfee06ea6efa5fdca252191176b5756", null ],
       [ "date_time", "classboost_1_1locale_1_1date__time.html#aabf5d22c8afafe330158bcff00adc95d", null ],
@@ -57,54 +54,54 @@ var group__date__time =
       [ "maximum", "classboost_1_1locale_1_1date__time.html#ad8d3812b5dc9a028e8bf4360adcaddd4", null ],
       [ "minimum", "classboost_1_1locale_1_1date__time.html#ace9bfc278a8417fd1e1f607da35e89cb", null ],
       [ "operator!=", "classboost_1_1locale_1_1date__time.html#a9f7017adc0938b2d78c6b66e01e86104", null ],
-      [ "operator+", "classboost_1_1locale_1_1date__time.html#a3d66a4e6adfcc369c03626c8cd7429b7", null ],
       [ "operator+", "classboost_1_1locale_1_1date__time.html#a856249fbb0eba7ad35e41c66fdae0b70", null ],
       [ "operator+", "classboost_1_1locale_1_1date__time.html#a8ecbdd5e711dd68469079f9bca945caa", null ],
-      [ "operator+=", "classboost_1_1locale_1_1date__time.html#a4af6593b60bf965b9138a564644ab66a", null ],
-      [ "operator+=", "classboost_1_1locale_1_1date__time.html#a4d37df1beea1f9cf12188561e9c96d25", null ],
-      [ "operator+=", "classboost_1_1locale_1_1date__time.html#ab7c06308f15f75974cfb893a52ef862c", null ],
-      [ "operator-", "classboost_1_1locale_1_1date__time.html#aefda6042554834d3455e680de596d577", null ],
+      [ "operator+", "classboost_1_1locale_1_1date__time.html#a3d66a4e6adfcc369c03626c8cd7429b7", null ],
+      [ "operator+=", "classboost_1_1locale_1_1date__time.html#acfd92db3a0c39fca48682e69fd00da80", null ],
+      [ "operator+=", "classboost_1_1locale_1_1date__time.html#a3b12ee3749eb679e2340a8223c158d9f", null ],
+      [ "operator+=", "classboost_1_1locale_1_1date__time.html#ae0453961d54b7a7a4f1b590a4c796bb1", null ],
       [ "operator-", "classboost_1_1locale_1_1date__time.html#a239887b91bd0b05c4b531732892a29b8", null ],
       [ "operator-", "classboost_1_1locale_1_1date__time.html#af1fc0e58c89e31a3f649fe53456ddd11", null ],
-      [ "operator-=", "classboost_1_1locale_1_1date__time.html#a04f0b2a8b8444e8b603ebbf58ef3a4e3", null ],
-      [ "operator-=", "classboost_1_1locale_1_1date__time.html#a6c1ccd31f9bdfe330c9e033e6ca9b89f", null ],
-      [ "operator-=", "classboost_1_1locale_1_1date__time.html#a3d76679ba297d3ea4aba541cbf2ca8de", null ],
+      [ "operator-", "classboost_1_1locale_1_1date__time.html#aefda6042554834d3455e680de596d577", null ],
+      [ "operator-=", "classboost_1_1locale_1_1date__time.html#a3a56d61697e5a9d96819e02e4cf431df", null ],
+      [ "operator-=", "classboost_1_1locale_1_1date__time.html#a3723a7eef51480dc0848a12b621b04af", null ],
+      [ "operator-=", "classboost_1_1locale_1_1date__time.html#ab77905ae83ee3416af09a85cf6ba8757", null ],
       [ "operator/", "classboost_1_1locale_1_1date__time.html#a57fc9acb86b8e89bc20278d510f096f5", null ],
       [ "operator<", "classboost_1_1locale_1_1date__time.html#a8a775930b0896e64ac9dbfd9bc95bde9", null ],
-      [ "operator<<", "classboost_1_1locale_1_1date__time.html#ac538193b90000b90b20792b87a42ab72", null ],
       [ "operator<<", "classboost_1_1locale_1_1date__time.html#afefcdd6cbfd467d1fd62fb57d72aa35e", null ],
       [ "operator<<", "classboost_1_1locale_1_1date__time.html#aa53b462192f4fd5fdbcbb65311985cab", null ],
-      [ "operator<<=", "classboost_1_1locale_1_1date__time.html#ab249f9229b2de6fc9d1afc818bb1d0dc", null ],
-      [ "operator<<=", "classboost_1_1locale_1_1date__time.html#a93361595f49e14c088f07bd2959b1854", null ],
-      [ "operator<<=", "classboost_1_1locale_1_1date__time.html#a2f49f4a353e47291452ef34719e4b98e", null ],
+      [ "operator<<", "classboost_1_1locale_1_1date__time.html#ac538193b90000b90b20792b87a42ab72", null ],
+      [ "operator<<=", "classboost_1_1locale_1_1date__time.html#a8f39070557438ddd3355876deb28d431", null ],
+      [ "operator<<=", "classboost_1_1locale_1_1date__time.html#af26e21c1d4052cdaa033d3f65b4cb833", null ],
+      [ "operator<<=", "classboost_1_1locale_1_1date__time.html#ae201600ed60871feee1268af1fec9b53", null ],
       [ "operator<=", "classboost_1_1locale_1_1date__time.html#a5d8e43dee85f185a9c9c88904afaa48f", null ],
-      [ "operator=", "classboost_1_1locale_1_1date__time.html#a836e219334e99986387b89451ee1ed05", null ],
-      [ "operator=", "classboost_1_1locale_1_1date__time.html#a634994b8f7e1d57addb036885d17a72e", null ],
-      [ "operator=", "classboost_1_1locale_1_1date__time.html#a42accf841e2f19505ab56a2dc407aa70", null ],
+      [ "operator=", "classboost_1_1locale_1_1date__time.html#a14f243f67a6841aa3de43a5fcccdec83", null ],
+      [ "operator=", "classboost_1_1locale_1_1date__time.html#a584967d235c9871744cf3d8573d445f5", null ],
       [ "operator==", "classboost_1_1locale_1_1date__time.html#addb8de90adbebcc15634dddbe47b81ac", null ],
       [ "operator>", "classboost_1_1locale_1_1date__time.html#a2f4de2667cc55719042a9c703a8c8af7", null ],
       [ "operator>=", "classboost_1_1locale_1_1date__time.html#ac1b1418c91fa3fe77a53fd588bab17b0", null ],
-      [ "operator>>", "classboost_1_1locale_1_1date__time.html#a8865698029284b6c7729ea393ad2ebfb", null ],
       [ "operator>>", "classboost_1_1locale_1_1date__time.html#aa3576f907dfce8fe6700c18d87bcdd9c", null ],
       [ "operator>>", "classboost_1_1locale_1_1date__time.html#a5335f4514df285c3cf0549eb1062c8ea", null ],
-      [ "operator>>=", "classboost_1_1locale_1_1date__time.html#abb1fb403d1571d7973186916cc76686e", null ],
-      [ "operator>>=", "classboost_1_1locale_1_1date__time.html#a0a017a76447591fc1851ca5bb3516352", null ],
-      [ "operator>>=", "classboost_1_1locale_1_1date__time.html#aec5644eeb393f3f542c01a36a15b12cc", null ],
+      [ "operator>>", "classboost_1_1locale_1_1date__time.html#a8865698029284b6c7729ea393ad2ebfb", null ],
+      [ "operator>>=", "classboost_1_1locale_1_1date__time.html#a4ceea3c55b475bbc1970eb8b45b8d58d", null ],
+      [ "operator>>=", "classboost_1_1locale_1_1date__time.html#adc69a0bb7079634f229234d468f02616", null ],
+      [ "operator>>=", "classboost_1_1locale_1_1date__time.html#ae7c205f61a2a8b74074a086c110a2260", null ],
       [ "set", "classboost_1_1locale_1_1date__time.html#a4c0ed3be4d5d3bb44014a2ea12927ff8", null ],
-      [ "swap", "classboost_1_1locale_1_1date__time.html#a704626c84b012080f5e0b73db3d080fb", null ],
+      [ "swap", "classboost_1_1locale_1_1date__time.html#aee1d8a3ad9ab9d8507051d4450bcf5d0", null ],
       [ "time", "classboost_1_1locale_1_1date__time.html#a3bd340d8382b034ac1c90c9447ca7713", null ],
-      [ "time", "classboost_1_1locale_1_1date__time.html#a71bc51cd2ef635dfb0da6c0b740dcb5f", null ]
+      [ "time", "classboost_1_1locale_1_1date__time.html#a71bc51cd2ef635dfb0da6c0b740dcb5f", null ],
+      [ "timezone", "classboost_1_1locale_1_1date__time.html#a78b89dd478ea0131b209a0d0b9facad0", null ]
     ] ],
-    [ "date_time_duration", "classboost_1_1locale_1_1date__time__duration.html", [
+    [ "boost::locale::date_time_duration", "classboost_1_1locale_1_1date__time__duration.html", [
       [ "date_time_duration", "classboost_1_1locale_1_1date__time__duration.html#a4556447fc56ce359e2e207da2bbd25bf", null ],
-      [ "end", "classboost_1_1locale_1_1date__time__duration.html#a77e0946de974eeeb60d8aa3f6d174c93", null ],
+      [ "end", "classboost_1_1locale_1_1date__time__duration.html#a97034fcf223609c128ac6b446425d571", null ],
       [ "get", "classboost_1_1locale_1_1date__time__duration.html#af18b87186d2a9343069b1186fd062e2f", null ],
       [ "operator/", "classboost_1_1locale_1_1date__time__duration.html#aac2e7c14858dcde54baca11d26d2dd54", null ],
-      [ "start", "classboost_1_1locale_1_1date__time__duration.html#a8570e450ad9c900a4dd39235b8e61909", null ]
+      [ "start", "classboost_1_1locale_1_1date__time__duration.html#a14db126f4003dbcf81fc157d75f10beb", null ]
     ] ],
-    [ "operator+", "group__date__time.html#ga5fb5bf4b94dcd67f45564e8015b57c20", null ],
-    [ "operator-", "group__date__time.html#ga0079bd8236eee75c4b5baa8497959b78", null ],
-    [ "operator-", "group__date__time.html#ga04d9cf366abf96ba0a208f618fc9fb06", null ],
-    [ "operator<<", "group__date__time.html#gadac52301b5dbc9383cc35610417802a3", null ],
-    [ "operator>>", "group__date__time.html#gaf6e30351fc67e887e37853723c228484", null ]
+    [ "boost::locale::operator+", "group__date__time.html#ga5fb5bf4b94dcd67f45564e8015b57c20", null ],
+    [ "boost::locale::operator-", "group__date__time.html#ga04d9cf366abf96ba0a208f618fc9fb06", null ],
+    [ "boost::locale::operator-", "group__date__time.html#ga0079bd8236eee75c4b5baa8497959b78", null ],
+    [ "boost::locale::operator<<", "group__date__time.html#ga8379172845a1ccf331e0daecdf006e14", null ],
+    [ "boost::locale::operator>>", "group__date__time.html#gad1f02913587706cadbd718c74274194d", null ]
 ];
\ No newline at end of file
