@@ -1,12 +1,10 @@
 var NAVTREEINDEX0 =
 {
-".html":[10,0,0],
-".html":[11,0,0],
 "annotated.html":[11,0],
 "appendix.html":[7],
 "appendix.html#appendix_toc":[7,0],
 "boundary_8cpp-example.html":[13,0],
-"boundary_8hpp_source.html":[12,0,0,0,2],
+"boundary_8hpp_source.html":[12,0,0,0,3],
 "boundary__point_8hpp_source.html":[12,0,0,0,0,0],
 "boundary_analysys.html":[3,6],
 "boundary_analysys.html#boundary_analysys_basics":[3,6,0],
@@ -26,7 +24,7 @@ var NAVTREEINDEX0 =
 "building_boost_locale.html#bb_platform_opts":[6,0,1],
 "building_boost_locale.html#binary_compatibility":[6,3],
 "building_boost_locale.html#building_boost_locale_bb":[6,0],
-"calendar_8cpp-example.html":[13,1],
+"calendar_8cpp-example.html":[13,5],
 "changelog.html":[8],
 "charset_handling.html":[3,5],
 "charset_handling.html#codecvt":[3,5,0],
@@ -34,27 +32,26 @@ var NAVTREEINDEX0 =
 "charset_handling.html#codecvt_iostreams_integration":[3,5,2],
 "charset_handling.html#codecvt_limitations":[3,5,3],
 "classboost_1_1locale_1_1abstract__calendar.html":[11,0,0,0,6],
-"classboost_1_1locale_1_1abstract__calendar.html#a0c034dd6f135b7d9b6faad08d49715a8":[11,0,0,0,6,7],
-"classboost_1_1locale_1_1abstract__calendar.html#a13d068ea5b491898ee1a64fa1d551972":[11,0,0,0,6,17],
-"classboost_1_1locale_1_1abstract__calendar.html#a1fa3963b78eecfe4d0f22f655bedb9c2":[11,0,0,0,6,3],
-"classboost_1_1locale_1_1abstract__calendar.html#a2f7ba0401405c8793d746988a5bad506":[11,0,0,0,6,13],
-"classboost_1_1locale_1_1abstract__calendar.html#a4770b99780933148b737e911595c0b85":[11,0,0,0,6,6],
-"classboost_1_1locale_1_1abstract__calendar.html#a51f4b91d0dc2f9afa3920a771307d92f":[11,0,0,0,6,10],
+"classboost_1_1locale_1_1abstract__calendar.html#a0c034dd6f135b7d9b6faad08d49715a8":[11,0,0,0,6,6],
+"classboost_1_1locale_1_1abstract__calendar.html#a13d068ea5b491898ee1a64fa1d551972":[11,0,0,0,6,16],
+"classboost_1_1locale_1_1abstract__calendar.html#a21258ba655bbd5fbc9f39351f2601433":[11,0,0,0,6,4],
+"classboost_1_1locale_1_1abstract__calendar.html#a2f7ba0401405c8793d746988a5bad506":[11,0,0,0,6,12],
+"classboost_1_1locale_1_1abstract__calendar.html#a4770b99780933148b737e911595c0b85":[11,0,0,0,6,5],
+"classboost_1_1locale_1_1abstract__calendar.html#a51f4b91d0dc2f9afa3920a771307d92f":[11,0,0,0,6,9],
 "classboost_1_1locale_1_1abstract__calendar.html#a5f1927f4c71fafa4712265e6b68958b5":[11,0,0,0,6,0],
 "classboost_1_1locale_1_1abstract__calendar.html#a5f1927f4c71fafa4712265e6b68958b5a69f0c20e321e3b914883869466122c61":[11,0,0,0,6,0,1],
 "classboost_1_1locale_1_1abstract__calendar.html#a5f1927f4c71fafa4712265e6b68958b5add910815d1ad0e97275b781223e869a9":[11,0,0,0,6,0,0],
-"classboost_1_1locale_1_1abstract__calendar.html#a73bc2d023be4c6ac6a6f441f74ded2f9":[11,0,0,0,6,5],
-"classboost_1_1locale_1_1abstract__calendar.html#a7a3f0e3392cee1f8623ecc4eafe6ee41":[11,0,0,0,6,16],
-"classboost_1_1locale_1_1abstract__calendar.html#a8900097c0b687393b053bc0420070815":[11,0,0,0,6,8],
-"classboost_1_1locale_1_1abstract__calendar.html#a9265206013005d9ac30cf723a7ffe032":[11,0,0,0,6,14],
+"classboost_1_1locale_1_1abstract__calendar.html#a7a3f0e3392cee1f8623ecc4eafe6ee41":[11,0,0,0,6,15],
+"classboost_1_1locale_1_1abstract__calendar.html#a8900097c0b687393b053bc0420070815":[11,0,0,0,6,7],
+"classboost_1_1locale_1_1abstract__calendar.html#a9265206013005d9ac30cf723a7ffe032":[11,0,0,0,6,13],
 "classboost_1_1locale_1_1abstract__calendar.html#a92cf9485b91d60b70ef00e183bdf4e95":[11,0,0,0,6,1],
 "classboost_1_1locale_1_1abstract__calendar.html#a92cf9485b91d60b70ef00e183bdf4e95a704e0e917603c2a88de22f3426a3e20b":[11,0,0,0,6,1,1],
 "classboost_1_1locale_1_1abstract__calendar.html#a92cf9485b91d60b70ef00e183bdf4e95aac5f9cb6e12a121b47b51434a3655c81":[11,0,0,0,6,1,0],
-"classboost_1_1locale_1_1abstract__calendar.html#aa06fef77acaa6104e3cd2bc80ccc76d9":[11,0,0,0,6,12],
-"classboost_1_1locale_1_1abstract__calendar.html#aab88e44a19162f45c2d5cbe6849e6de3":[11,0,0,0,6,11],
-"classboost_1_1locale_1_1abstract__calendar.html#acc0e2e3edb7e774c35e0a01964d10c02":[11,0,0,0,6,4],
-"classboost_1_1locale_1_1abstract__calendar.html#ae95fea3dee649c3432844dcf7b400a0e":[11,0,0,0,6,15],
-"classboost_1_1locale_1_1abstract__calendar.html#aee7627ecf4f78c7cc68508533c606f2a":[11,0,0,0,6,9],
+"classboost_1_1locale_1_1abstract__calendar.html#aa06fef77acaa6104e3cd2bc80ccc76d9":[11,0,0,0,6,11],
+"classboost_1_1locale_1_1abstract__calendar.html#aab88e44a19162f45c2d5cbe6849e6de3":[11,0,0,0,6,10],
+"classboost_1_1locale_1_1abstract__calendar.html#acc0e2e3edb7e774c35e0a01964d10c02":[11,0,0,0,6,3],
+"classboost_1_1locale_1_1abstract__calendar.html#ae95fea3dee649c3432844dcf7b400a0e":[11,0,0,0,6,14],
+"classboost_1_1locale_1_1abstract__calendar.html#aee7627ecf4f78c7cc68508533c606f2a":[11,0,0,0,6,8],
 "classboost_1_1locale_1_1abstract__calendar.html#af786b3e65294d70769f2826ef95c7bd5":[11,0,0,0,6,2],
 "classboost_1_1locale_1_1abstract__calendar.html#af786b3e65294d70769f2826ef95c7bd5a28694319e58f559df9ca41b22f03427e":[11,0,0,0,6,2,0],
 "classboost_1_1locale_1_1abstract__calendar.html#af786b3e65294d70769f2826ef95c7bd5a388661725182373d2f92b709034f85c9":[11,0,0,0,6,2,4],
@@ -65,48 +62,45 @@ var NAVTREEINDEX0 =
 "classboost_1_1locale_1_1abstract__calendar.html#af786b3e65294d70769f2826ef95c7bd5ab5d1af0b2698fee942a1486dfcc6552b":[11,0,0,0,6,2,6],
 "classboost_1_1locale_1_1basic__format.html":[9,5,0],
 "classboost_1_1locale_1_1basic__format.html#a0e1263d23f67aa38b4d857031fccf973":[9,5,0,3],
-"classboost_1_1locale_1_1basic__format.html#a2c3b195f13391f689932804df974f431":[9,5,0,9],
 "classboost_1_1locale_1_1basic__format.html#a45c16f2e69842b8d223d240bbd6e210a":[9,5,0,0],
 "classboost_1_1locale_1_1basic__format.html#a6aba7e54f0065f2697d13ff8a859309a":[9,5,0,2],
 "classboost_1_1locale_1_1basic__format.html#a75213e5cc9d113f6b25e72542a4841f5":[9,5,0,1],
-"classboost_1_1locale_1_1basic__format.html#a7e86989f062f99a246833e086462e345":[9,5,0,8],
-"classboost_1_1locale_1_1basic__format.html#a8085d426d16d30e870cb816664b863ff":[9,5,0,11],
+"classboost_1_1locale_1_1basic__format.html#a8085d426d16d30e870cb816664b863ff":[9,5,0,9],
 "classboost_1_1locale_1_1basic__format.html#a9967b94f6a02d511089a7b82a8e02256":[9,5,0,4],
 "classboost_1_1locale_1_1basic__format.html#a9df35fd08f72160624133f0af8e83655":[9,5,0,6],
-"classboost_1_1locale_1_1basic__format.html#aac5b3eeb481d6a4411e53c3d3d833e39":[9,5,0,10],
-"classboost_1_1locale_1_1basic__format.html#aaefca2f7ba9d12348ee2528bc9f99979":[9,5,0,12],
+"classboost_1_1locale_1_1basic__format.html#aa95399d8e0dc11cacbc093815231628f":[9,5,0,8],
+"classboost_1_1locale_1_1basic__format.html#aaefca2f7ba9d12348ee2528bc9f99979":[9,5,0,10],
 "classboost_1_1locale_1_1basic__format.html#ab1f9a5410362c9719b461179ebd30071":[9,5,0,7],
 "classboost_1_1locale_1_1basic__format.html#abcc68ea3efb6cfa3c1cef75cfcb84602":[9,5,0,5],
 "classboost_1_1locale_1_1basic__message.html":[9,6,4],
 "classboost_1_1locale_1_1boundary_1_1boundary__indexing.html":[9,0,2],
 "classboost_1_1locale_1_1boundary_1_1boundary__indexing.html#a251d097b8498d6dade6110b0829c8cf5":[9,0,2,0],
 "classboost_1_1locale_1_1boundary_1_1boundary__indexing.html#a32ef96e6ecaa0cb04bec0e91b3a9fd62":[9,0,2,1],
-"classboost_1_1locale_1_1boundary_1_1boundary__indexing.html#a6ec435e58e34f70046f62ac0314c1a58":[9,0,2,2],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html":[9,0,0],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html#a2e0ee743f9593183b7442e4be734ac55":[9,0,0,7],
-"classboost_1_1locale_1_1boundary_1_1boundary__point.html#a5ea18137618a1a84ff0b75c3b166c495":[9,0,0,3],
-"classboost_1_1locale_1_1boundary_1_1boundary__point.html#a61a1ba94fed8a2cc4adef2f888ebc244":[9,0,0,11],
+"classboost_1_1locale_1_1boundary_1_1boundary__point.html#a5ea18137618a1a84ff0b75c3b166c495":[9,0,0,4],
+"classboost_1_1locale_1_1boundary_1_1boundary__point.html#a61a1ba94fed8a2cc4adef2f888ebc244":[9,0,0,10],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html#a653a1c0d7480006ff647a656c74521df":[9,0,0,2],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html#a6fdab000fc55661da0bdfeba1c15dec5":[9,0,0,5],
-"classboost_1_1locale_1_1boundary_1_1boundary__point.html#a757b28e11c66f9871d3f51fe93a51bdb":[9,0,0,10],
+"classboost_1_1locale_1_1boundary_1_1boundary__point.html#a757b28e11c66f9871d3f51fe93a51bdb":[9,0,0,11],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html#a975790f175523980751689102c534c3f":[9,0,0,6],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html#a98f56abd956141788f5ea022088aeb0e":[9,0,0,9],
-"classboost_1_1locale_1_1boundary_1_1boundary__point.html#aab347a172f56f5139e07eb11235e7f32":[9,0,0,4],
+"classboost_1_1locale_1_1boundary_1_1boundary__point.html#aab347a172f56f5139e07eb11235e7f32":[9,0,0,3],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html#aabbbee60c2c97ffd95210206a86c9298":[9,0,0,1],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html#af3c3a74a9a79690ff44f38d267b3b694":[9,0,0,0],
 "classboost_1_1locale_1_1boundary_1_1boundary__point.html#af461681cc48e35c36b11f863c5f51da1":[9,0,0,8],
 "classboost_1_1locale_1_1boundary_1_1boundary__point__index.html":[9,0,4],
 "classboost_1_1locale_1_1boundary_1_1segment.html":[9,0,5],
-"classboost_1_1locale_1_1boundary_1_1segment.html#a17550339abde23807c75fba819f9af6d":[9,0,5,9],
+"classboost_1_1locale_1_1boundary_1_1segment.html#a17550339abde23807c75fba819f9af6d":[9,0,5,8],
 "classboost_1_1locale_1_1boundary_1_1segment.html#a31960fd7b416715d012b686bc1f2c205":[9,0,5,3],
-"classboost_1_1locale_1_1boundary_1_1segment.html#a3dc6f4315df3c637e4e0e16ff45177bd":[9,0,5,8],
+"classboost_1_1locale_1_1boundary_1_1segment.html#a3dc6f4315df3c637e4e0e16ff45177bd":[9,0,5,9],
 "classboost_1_1locale_1_1boundary_1_1segment.html#a3fe57aac1fc110e474aa5bdea6c03210":[9,0,5,15],
 "classboost_1_1locale_1_1boundary_1_1segment.html#a4704be68c05541b4349502989def8cda":[9,0,5,13],
-"classboost_1_1locale_1_1boundary_1_1segment.html#a49d80037c24f2efb09209d03517c6c8f":[9,0,5,11],
+"classboost_1_1locale_1_1boundary_1_1segment.html#a49d80037c24f2efb09209d03517c6c8f":[9,0,5,12],
 "classboost_1_1locale_1_1boundary_1_1segment.html#a4e785bc97dba9e8e25f18b43957723e5":[9,0,5,6],
 "classboost_1_1locale_1_1boundary_1_1segment.html#a795d3328ac4d1692294f172c8480da47":[9,0,5,4],
 "classboost_1_1locale_1_1boundary_1_1segment.html#a79ee4d48248ffbc23f84a33355ca3b62":[9,0,5,2],
-"classboost_1_1locale_1_1boundary_1_1segment.html#a9079852b3d034e6012d0793c4fec060b":[9,0,5,12],
+"classboost_1_1locale_1_1boundary_1_1segment.html#a9079852b3d034e6012d0793c4fec060b":[9,0,5,11],
 "classboost_1_1locale_1_1boundary_1_1segment.html#a962c26b7e2024767ad25f2be080fd53a":[9,0,5,18],
 "classboost_1_1locale_1_1boundary_1_1segment.html#aa24dcd83aefe4925bfc11b0285e2517a":[9,0,5,1],
 "classboost_1_1locale_1_1boundary_1_1segment.html#ab7ba55015262b4fb85bb531882a32ead":[9,0,5,5],
@@ -119,54 +113,63 @@ var NAVTREEINDEX0 =
 "classboost_1_1locale_1_1boundary_1_1segment.html#afa7f5f8cf0c99d97797416f49efcac7c":[9,0,5,19],
 "classboost_1_1locale_1_1boundary_1_1segment__index.html":[9,0,3],
 "classboost_1_1locale_1_1calendar.html":[9,3,5],
+"classboost_1_1locale_1_1calendar.html#a0ad69716969c51a46d12e567cf9dd2fd":[9,3,5,8],
 "classboost_1_1locale_1_1calendar.html#a111b9a81f231b3b4555eb122a02e366d":[9,3,5,3],
-"classboost_1_1locale_1_1calendar.html#a175df8244754dec5c748cc2bd031a60c":[9,3,5,10],
-"classboost_1_1locale_1_1calendar.html#a1f201a7c283ea00d75601b0d804b0878":[9,3,5,13],
-"classboost_1_1locale_1_1calendar.html#a378ecd62f6cc64928ab308b180c98b21":[9,3,5,5],
-"classboost_1_1locale_1_1calendar.html#a42684e8e81a48309c3917735b1810506":[9,3,5,11],
-"classboost_1_1locale_1_1calendar.html#a52d6099c1b4a38110bd3ed595075d4c0":[9,3,5,12],
+"classboost_1_1locale_1_1calendar.html#a175df8244754dec5c748cc2bd031a60c":[9,3,5,9],
+"classboost_1_1locale_1_1calendar.html#a1f201a7c283ea00d75601b0d804b0878":[9,3,5,12],
+"classboost_1_1locale_1_1calendar.html#a1fd80b8d57ca0921c71bd16fe40c9660":[9,3,5,15],
+"classboost_1_1locale_1_1calendar.html#a42684e8e81a48309c3917735b1810506":[9,3,5,10],
+"classboost_1_1locale_1_1calendar.html#a52d6099c1b4a38110bd3ed595075d4c0":[9,3,5,11],
 "classboost_1_1locale_1_1calendar.html#a56c55c24fbbb29fac5a18c44d3a27beb":[9,3,5,4],
-"classboost_1_1locale_1_1calendar.html#a5a510078e9bd0ba311cfbc612a662280":[9,3,5,17],
-"classboost_1_1locale_1_1calendar.html#a71bf8666365059c21bfba2de2e02d2c9":[9,3,5,8],
-"classboost_1_1locale_1_1calendar.html#a7a0f1c79578137bbbb63de3fe8f05383":[9,3,5,7],
-"classboost_1_1locale_1_1calendar.html#a7c627d823bfb1186af76ed36016cbb31":[9,3,5,18],
-"classboost_1_1locale_1_1calendar.html#a7d76bef064eedbe9c4d838b7b0a76f1c":[9,3,5,14],
+"classboost_1_1locale_1_1calendar.html#a5a510078e9bd0ba311cfbc612a662280":[9,3,5,16],
+"classboost_1_1locale_1_1calendar.html#a7a0f1c79578137bbbb63de3fe8f05383":[9,3,5,6],
+"classboost_1_1locale_1_1calendar.html#a7d76bef064eedbe9c4d838b7b0a76f1c":[9,3,5,13],
 "classboost_1_1locale_1_1calendar.html#a889746f73b03bb21f5c8459cbe9b293d":[9,3,5,0],
 "classboost_1_1locale_1_1calendar.html#ac083baf94c478302dde8a28d64a973c4":[9,3,5,2],
-"classboost_1_1locale_1_1calendar.html#ad6a28e60830f466c749c9cbbab3e1360":[9,3,5,6],
-"classboost_1_1locale_1_1calendar.html#adc1dad63217b601527c253af34406cab":[9,3,5,15],
+"classboost_1_1locale_1_1calendar.html#ad6a28e60830f466c749c9cbbab3e1360":[9,3,5,5],
+"classboost_1_1locale_1_1calendar.html#adc1dad63217b601527c253af34406cab":[9,3,5,14],
 "classboost_1_1locale_1_1calendar.html#adee95b95c8635f7a3515e6116c6a12a2":[9,3,5,1],
-"classboost_1_1locale_1_1calendar.html#ae9b32820cc9c8aa9962d339d833f9960":[9,3,5,9],
-"classboost_1_1locale_1_1calendar.html#aeae9cae78ff85587e32f630ca71963a7":[9,3,5,16],
+"classboost_1_1locale_1_1calendar.html#aec861ac1985d0ceaf332ed1944f115c8":[9,3,5,7],
 "classboost_1_1locale_1_1calendar__facet.html":[11,0,0,0,10],
 "classboost_1_1locale_1_1calendar__facet.html#a04e5d7baa3bb0f362b0c2faac0c5d376":[11,0,0,0,10,0],
-"classboost_1_1locale_1_1calendar__facet.html#a6db1915db3ad99ea65334dddaa7dcc28":[11,0,0,0,10,2],
-"classboost_1_1locale_1_1calendar__facet.html#a88dc563112346949302fd95df833089c":[11,0,0,0,10,3],
-"classboost_1_1locale_1_1calendar__facet.html#acce7e72f184362c991ad7d729b0ebcff":[11,0,0,0,10,1],
+"classboost_1_1locale_1_1calendar__facet.html#a28ad3228f77cf7e39a3e196e25de30a5":[11,0,0,0,10,1],
 "classboost_1_1locale_1_1collator.html":[9,1,0],
 "classboost_1_1locale_1_1collator.html#a0b5964844b2eeb135ab88c4fe63881b8":[9,1,0,12],
 "classboost_1_1locale_1_1collator.html#a106a3fe9e068530013c428661758733d":[9,1,0,1],
 "classboost_1_1locale_1_1collator.html#a246dba22f585e5d155b22a58837dbea0":[9,1,0,3],
 "classboost_1_1locale_1_1collator.html#a25a8b21a756756e850a7488a54610053":[9,1,0,2],
 "classboost_1_1locale_1_1collator.html#a2b74a0b9a613a4a4337632bf34644c6f":[9,1,0,0],
-"classboost_1_1locale_1_1collator.html#a3a9e81e87b63ef8329e13f9ff2b8a60d":[9,1,0,6],
-"classboost_1_1locale_1_1collator.html#a4c22ec1ddd00f15fd85f5d25f5fae2a1":[9,1,0,5],
-"classboost_1_1locale_1_1collator.html#a6a740b1d50087042cf6d29a817be40cd":[9,1,0,8],
-"classboost_1_1locale_1_1collator.html#a85f94d10caca8ec211e9de6651dcce20":[9,1,0,9],
-"classboost_1_1locale_1_1collator.html#a99579f1d4dd09d6cf4ef53f3589ff375":[9,1,0,7],
+"classboost_1_1locale_1_1collator.html#a3a9e81e87b63ef8329e13f9ff2b8a60d":[9,1,0,5],
+"classboost_1_1locale_1_1collator.html#a4c22ec1ddd00f15fd85f5d25f5fae2a1":[9,1,0,6],
+"classboost_1_1locale_1_1collator.html#a6a740b1d50087042cf6d29a817be40cd":[9,1,0,7],
+"classboost_1_1locale_1_1collator.html#a85f94d10caca8ec211e9de6651dcce20":[9,1,0,10],
+"classboost_1_1locale_1_1collator.html#a99579f1d4dd09d6cf4ef53f3589ff375":[9,1,0,8],
 "classboost_1_1locale_1_1collator.html#aaa2f92a8991a45ef86c4c60f6dc2b5c4":[9,1,0,11],
 "classboost_1_1locale_1_1collator.html#abafa4c86ac5f93b03112368b2c4c1f2d":[9,1,0,4],
-"classboost_1_1locale_1_1collator.html#ac670afc3cbe29d722b7762e2a72679b5":[9,1,0,10],
+"classboost_1_1locale_1_1collator.html#ac670afc3cbe29d722b7762e2a72679b5":[9,1,0,9],
 "classboost_1_1locale_1_1collator.html#aec2f6e262baf753a6ba4e0cae56e1312":[9,1,0,13],
 "classboost_1_1locale_1_1collator.html#afd9ac717586002d9e5a1030716604450":[9,1,0,14],
-"classboost_1_1locale_1_1conv_1_1conversion__error.html":[9,4,0],
-"classboost_1_1locale_1_1conv_1_1conversion__error.html#aba6b713c35f3538d9e130d3c6cd32d49":[9,4,0,0],
-"classboost_1_1locale_1_1conv_1_1invalid__charset__error.html":[9,4,1],
-"classboost_1_1locale_1_1conv_1_1invalid__charset__error.html#ac40c259adef82950a1b7049f37bd3ca1":[9,4,1,0],
+"classboost_1_1locale_1_1conv_1_1conversion__error.html":[9,7,0],
+"classboost_1_1locale_1_1conv_1_1invalid__charset__error.html":[9,7,1],
+"classboost_1_1locale_1_1conv_1_1invalid__charset__error.html#ac40c259adef82950a1b7049f37bd3ca1":[9,7,1,0],
+"classboost_1_1locale_1_1conv_1_1narrow__converter.html":[11,0,0,0,1,2],
+"classboost_1_1locale_1_1conv_1_1narrow__converter.html#a47a2bb677414241c832013da40d5191a":[11,0,0,0,1,2,1],
+"classboost_1_1locale_1_1conv_1_1narrow__converter.html#aa1a34078162cb1f849022f3d890a98b4":[11,0,0,0,1,2,0],
+"classboost_1_1locale_1_1conv_1_1narrow__converter.html#ab0e5105dae8f348036a6efe0f827feec":[11,0,0,0,1,2,2],
+"classboost_1_1locale_1_1conv_1_1narrow__converter.html#ad1cd453f6290027157ea9acab3fa1f2a":[11,0,0,0,1,2,3],
+"classboost_1_1locale_1_1conv_1_1utf__decoder.html":[11,0,0,0,1,3],
+"classboost_1_1locale_1_1conv_1_1utf__decoder.html#a53c783320e5b0113e86387a61bb1ebdc":[11,0,0,0,1,3,0],
+"classboost_1_1locale_1_1conv_1_1utf__decoder.html#a899c880e6c171e61be35ff5a76f5b835":[11,0,0,0,1,3,1],
+"classboost_1_1locale_1_1conv_1_1utf__decoder.html#ab63ab01715724e571099c180a8398481":[11,0,0,0,1,3,3],
+"classboost_1_1locale_1_1conv_1_1utf__decoder.html#ae32e2409526f1e34edddc4edacb0663b":[11,0,0,0,1,3,2],
+"classboost_1_1locale_1_1conv_1_1utf__encoder.html":[11,0,0,0,1,4],
+"classboost_1_1locale_1_1conv_1_1utf__encoder.html#a2ecd1d7952f4afbd86e2048889e2ce56":[11,0,0,0,1,4,2],
+"classboost_1_1locale_1_1conv_1_1utf__encoder.html#a361402d07a595ac10c4e28425299593b":[11,0,0,0,1,4,0],
+"classboost_1_1locale_1_1conv_1_1utf__encoder.html#a909294a63f8e27e29537efaef5ae3171":[11,0,0,0,1,4,3],
+"classboost_1_1locale_1_1conv_1_1utf__encoder.html#ae185ce8b2db4360e236437e812e30de4":[11,0,0,0,1,4,1],
 "classboost_1_1locale_1_1converter.html":[9,2,1],
-"classboost_1_1locale_1_1converter.html#a0ab17b265161bb2c5d7a233710d2740b":[9,2,1,2],
+"classboost_1_1locale_1_1converter.html#a8f58495523b04b54390f4d2d33b69943":[9,2,1,1],
 "classboost_1_1locale_1_1converter.html#aba25fd4a18937543823cd61bef72c628":[9,2,1,0],
-"classboost_1_1locale_1_1converter.html#aeef785ffa5ec1a232cd0ae4ee52d6731":[9,2,1,1],
 "classboost_1_1locale_1_1converter__base.html":[9,2,0],
 "classboost_1_1locale_1_1converter__base.html#a726bc2bbcbb6f1e550cca14163fb669b":[9,2,0,0],
 "classboost_1_1locale_1_1converter__base.html#a726bc2bbcbb6f1e550cca14163fb669ba0fee54e09732910ab30856d0e34c8ad2":[9,2,0,0,1],
@@ -175,79 +178,76 @@ var NAVTREEINDEX0 =
 "classboost_1_1locale_1_1converter__base.html#a726bc2bbcbb6f1e550cca14163fb669bac136b257286085de7bd7eb4a7876dfa7":[9,2,0,0,4],
 "classboost_1_1locale_1_1converter__base.html#a726bc2bbcbb6f1e550cca14163fb669bae20bf7eface68062a0b9f2396833354a":[9,2,0,0,0],
 "classboost_1_1locale_1_1date__time.html":[9,3,6],
-"classboost_1_1locale_1_1date__time.html#a04f0b2a8b8444e8b603ebbf58ef3a4e3":[9,3,6,24],
-"classboost_1_1locale_1_1date__time.html#a0a017a76447591fc1851ca5bb3516352":[9,3,6,46],
-"classboost_1_1locale_1_1date__time.html#a239887b91bd0b05c4b531732892a29b8":[9,3,6,22],
-"classboost_1_1locale_1_1date__time.html#a2e8589e260604cf2cd7c43380392d0d2":[9,3,6,2],
-"classboost_1_1locale_1_1date__time.html#a2f49f4a353e47291452ef34719e4b98e":[9,3,6,34],
-"classboost_1_1locale_1_1date__time.html#a2f4de2667cc55719042a9c703a8c8af7":[9,3,6,40],
-"classboost_1_1locale_1_1date__time.html#a3bd340d8382b034ac1c90c9447ca7713":[9,3,6,50],
-"classboost_1_1locale_1_1date__time.html#a3d66a4e6adfcc369c03626c8cd7429b7":[9,3,6,15],
-"classboost_1_1locale_1_1date__time.html#a3d76679ba297d3ea4aba541cbf2ca8de":[9,3,6,26],
-"classboost_1_1locale_1_1date__time.html#a42accf841e2f19505ab56a2dc407aa70":[9,3,6,38],
-"classboost_1_1locale_1_1date__time.html#a4af6593b60bf965b9138a564644ab66a":[9,3,6,18],
-"classboost_1_1locale_1_1date__time.html#a4c0ed3be4d5d3bb44014a2ea12927ff8":[9,3,6,48],
-"classboost_1_1locale_1_1date__time.html#a4d37df1beea1f9cf12188561e9c96d25":[9,3,6,19],
-"classboost_1_1locale_1_1date__time.html#a5335f4514df285c3cf0549eb1062c8ea":[9,3,6,44],
-"classboost_1_1locale_1_1date__time.html#a57fc9acb86b8e89bc20278d510f096f5":[9,3,6,27],
-"classboost_1_1locale_1_1date__time.html#a5d8e43dee85f185a9c9c88904afaa48f":[9,3,6,35],
-"classboost_1_1locale_1_1date__time.html#a634994b8f7e1d57addb036885d17a72e":[9,3,6,37],
-"classboost_1_1locale_1_1date__time.html#a6c1ccd31f9bdfe330c9e033e6ca9b89f":[9,3,6,25],
-"classboost_1_1locale_1_1date__time.html#a704626c84b012080f5e0b73db3d080fb":[9,3,6,49],
+"classboost_1_1locale_1_1date__time.html#a14f243f67a6841aa3de43a5fcccdec83":[9,3,6,35],
+"classboost_1_1locale_1_1date__time.html#a239887b91bd0b05c4b531732892a29b8":[9,3,6,20],
+"classboost_1_1locale_1_1date__time.html#a2f4de2667cc55719042a9c703a8c8af7":[9,3,6,38],
+"classboost_1_1locale_1_1date__time.html#a3723a7eef51480dc0848a12b621b04af":[9,3,6,24],
+"classboost_1_1locale_1_1date__time.html#a3a56d61697e5a9d96819e02e4cf431df":[9,3,6,23],
+"classboost_1_1locale_1_1date__time.html#a3b12ee3749eb679e2340a8223c158d9f":[9,3,6,18],
+"classboost_1_1locale_1_1date__time.html#a3bd340d8382b034ac1c90c9447ca7713":[9,3,6,48],
+"classboost_1_1locale_1_1date__time.html#a3d66a4e6adfcc369c03626c8cd7429b7":[9,3,6,16],
+"classboost_1_1locale_1_1date__time.html#a4c0ed3be4d5d3bb44014a2ea12927ff8":[9,3,6,46],
+"classboost_1_1locale_1_1date__time.html#a4ceea3c55b475bbc1970eb8b45b8d58d":[9,3,6,43],
+"classboost_1_1locale_1_1date__time.html#a5335f4514df285c3cf0549eb1062c8ea":[9,3,6,41],
+"classboost_1_1locale_1_1date__time.html#a57fc9acb86b8e89bc20278d510f096f5":[9,3,6,26],
+"classboost_1_1locale_1_1date__time.html#a584967d235c9871744cf3d8573d445f5":[9,3,6,36],
+"classboost_1_1locale_1_1date__time.html#a5d8e43dee85f185a9c9c88904afaa48f":[9,3,6,34],
 "classboost_1_1locale_1_1date__time.html#a7144d1e240a2d7433039dba9984ea618":[9,3,6,1],
-"classboost_1_1locale_1_1date__time.html#a71bc51cd2ef635dfb0da6c0b740dcb5f":[9,3,6,51],
-"classboost_1_1locale_1_1date__time.html#a7248cbe75240f34250d9acbd534ee18b":[9,3,6,6],
-"classboost_1_1locale_1_1date__time.html#a7a1b0da437e819cccc10a48b007fdd6e":[9,3,6,11],
-"classboost_1_1locale_1_1date__time.html#a7a472cf5c99f91d6167c1990d4ee42f4":[9,3,6,8],
-"classboost_1_1locale_1_1date__time.html#a836e219334e99986387b89451ee1ed05":[9,3,6,36],
-"classboost_1_1locale_1_1date__time.html#a856249fbb0eba7ad35e41c66fdae0b70":[9,3,6,16],
+"classboost_1_1locale_1_1date__time.html#a71bc51cd2ef635dfb0da6c0b740dcb5f":[9,3,6,49],
+"classboost_1_1locale_1_1date__time.html#a7248cbe75240f34250d9acbd534ee18b":[9,3,6,5],
+"classboost_1_1locale_1_1date__time.html#a78b89dd478ea0131b209a0d0b9facad0":[9,3,6,50],
+"classboost_1_1locale_1_1date__time.html#a7a1b0da437e819cccc10a48b007fdd6e":[9,3,6,10],
+"classboost_1_1locale_1_1date__time.html#a7a472cf5c99f91d6167c1990d4ee42f4":[9,3,6,7],
+"classboost_1_1locale_1_1date__time.html#a856249fbb0eba7ad35e41c66fdae0b70":[9,3,6,14],
 "classboost_1_1locale_1_1date__time.html#a8865698029284b6c7729ea393ad2ebfb":[9,3,6,42],
-"classboost_1_1locale_1_1date__time.html#a8a775930b0896e64ac9dbfd9bc95bde9":[9,3,6,28],
-"classboost_1_1locale_1_1date__time.html#a8d00584d1f1b2dc0f9b44ef53e2a15e9":[9,3,6,9],
-"classboost_1_1locale_1_1date__time.html#a8ecbdd5e711dd68469079f9bca945caa":[9,3,6,17],
-"classboost_1_1locale_1_1date__time.html#a93361595f49e14c088f07bd2959b1854":[9,3,6,33],
-"classboost_1_1locale_1_1date__time.html#a9f7017adc0938b2d78c6b66e01e86104":[9,3,6,14],
-"classboost_1_1locale_1_1date__time.html#aa3576f907dfce8fe6700c18d87bcdd9c":[9,3,6,43],
-"classboost_1_1locale_1_1date__time.html#aa53b462192f4fd5fdbcbb65311985cab":[9,3,6,31],
-"classboost_1_1locale_1_1date__time.html#aabf5d22c8afafe330158bcff00adc95d":[9,3,6,5],
-"classboost_1_1locale_1_1date__time.html#ab249f9229b2de6fc9d1afc818bb1d0dc":[9,3,6,32],
-"classboost_1_1locale_1_1date__time.html#ab7c06308f15f75974cfb893a52ef862c":[9,3,6,20],
-"classboost_1_1locale_1_1date__time.html#ab906696b8fae6a83a2aebdabc8a7129e":[9,3,6,7],
-"classboost_1_1locale_1_1date__time.html#abb1fb403d1571d7973186916cc76686e":[9,3,6,45],
-"classboost_1_1locale_1_1date__time.html#abc5b3fccdb3b2d2c673b48380a2434bb":[9,3,6,10],
-"classboost_1_1locale_1_1date__time.html#ac1b1418c91fa3fe77a53fd588bab17b0":[9,3,6,41],
-"classboost_1_1locale_1_1date__time.html#ac538193b90000b90b20792b87a42ab72":[9,3,6,29],
-"classboost_1_1locale_1_1date__time.html#ace9bfc278a8417fd1e1f607da35e89cb":[9,3,6,13],
-"classboost_1_1locale_1_1date__time.html#ad09863ad4367277fa34a742368e20db1":[9,3,6,3],
-"classboost_1_1locale_1_1date__time.html#ad8d3812b5dc9a028e8bf4360adcaddd4":[9,3,6,12],
-"classboost_1_1locale_1_1date__time.html#addb8de90adbebcc15634dddbe47b81ac":[9,3,6,39],
-"classboost_1_1locale_1_1date__time.html#addfee06ea6efa5fdca252191176b5756":[9,3,6,4],
+"classboost_1_1locale_1_1date__time.html#a8a775930b0896e64ac9dbfd9bc95bde9":[9,3,6,27],
+"classboost_1_1locale_1_1date__time.html#a8d00584d1f1b2dc0f9b44ef53e2a15e9":[9,3,6,8],
+"classboost_1_1locale_1_1date__time.html#a8ecbdd5e711dd68469079f9bca945caa":[9,3,6,15],
+"classboost_1_1locale_1_1date__time.html#a8f39070557438ddd3355876deb28d431":[9,3,6,31],
+"classboost_1_1locale_1_1date__time.html#a9f7017adc0938b2d78c6b66e01e86104":[9,3,6,13],
+"classboost_1_1locale_1_1date__time.html#aa3576f907dfce8fe6700c18d87bcdd9c":[9,3,6,40],
+"classboost_1_1locale_1_1date__time.html#aa53b462192f4fd5fdbcbb65311985cab":[9,3,6,29],
+"classboost_1_1locale_1_1date__time.html#aabf5d22c8afafe330158bcff00adc95d":[9,3,6,4],
+"classboost_1_1locale_1_1date__time.html#ab77905ae83ee3416af09a85cf6ba8757":[9,3,6,25],
+"classboost_1_1locale_1_1date__time.html#ab906696b8fae6a83a2aebdabc8a7129e":[9,3,6,6],
+"classboost_1_1locale_1_1date__time.html#abc5b3fccdb3b2d2c673b48380a2434bb":[9,3,6,9],
+"classboost_1_1locale_1_1date__time.html#ac1b1418c91fa3fe77a53fd588bab17b0":[9,3,6,39],
+"classboost_1_1locale_1_1date__time.html#ac538193b90000b90b20792b87a42ab72":[9,3,6,30],
+"classboost_1_1locale_1_1date__time.html#ace9bfc278a8417fd1e1f607da35e89cb":[9,3,6,12],
+"classboost_1_1locale_1_1date__time.html#acfd92db3a0c39fca48682e69fd00da80":[9,3,6,17],
+"classboost_1_1locale_1_1date__time.html#ad09863ad4367277fa34a742368e20db1":[9,3,6,2],
+"classboost_1_1locale_1_1date__time.html#ad8d3812b5dc9a028e8bf4360adcaddd4":[9,3,6,11],
+"classboost_1_1locale_1_1date__time.html#adc69a0bb7079634f229234d468f02616":[9,3,6,44],
+"classboost_1_1locale_1_1date__time.html#addb8de90adbebcc15634dddbe47b81ac":[9,3,6,37],
+"classboost_1_1locale_1_1date__time.html#addfee06ea6efa5fdca252191176b5756":[9,3,6,3],
+"classboost_1_1locale_1_1date__time.html#ae0453961d54b7a7a4f1b590a4c796bb1":[9,3,6,19],
+"classboost_1_1locale_1_1date__time.html#ae201600ed60871feee1268af1fec9b53":[9,3,6,33],
 "classboost_1_1locale_1_1date__time.html#ae7a3b74e7512ddc4d618eb1f51c3d2b0":[9,3,6,0],
-"classboost_1_1locale_1_1date__time.html#aec5644eeb393f3f542c01a36a15b12cc":[9,3,6,47],
-"classboost_1_1locale_1_1date__time.html#aefda6042554834d3455e680de596d577":[9,3,6,21],
-"classboost_1_1locale_1_1date__time.html#af1fc0e58c89e31a3f649fe53456ddd11":[9,3,6,23],
-"classboost_1_1locale_1_1date__time.html#afefcdd6cbfd467d1fd62fb57d72aa35e":[9,3,6,30],
+"classboost_1_1locale_1_1date__time.html#ae7c205f61a2a8b74074a086c110a2260":[9,3,6,45],
+"classboost_1_1locale_1_1date__time.html#aee1d8a3ad9ab9d8507051d4450bcf5d0":[9,3,6,47],
+"classboost_1_1locale_1_1date__time.html#aefda6042554834d3455e680de596d577":[9,3,6,22],
+"classboost_1_1locale_1_1date__time.html#af1fc0e58c89e31a3f649fe53456ddd11":[9,3,6,21],
+"classboost_1_1locale_1_1date__time.html#af26e21c1d4052cdaa033d3f65b4cb833":[9,3,6,32],
+"classboost_1_1locale_1_1date__time.html#afefcdd6cbfd467d1fd62fb57d72aa35e":[9,3,6,28],
 "classboost_1_1locale_1_1date__time__duration.html":[9,3,7],
+"classboost_1_1locale_1_1date__time__duration.html#a14db126f4003dbcf81fc157d75f10beb":[9,3,7,4],
 "classboost_1_1locale_1_1date__time__duration.html#a4556447fc56ce359e2e207da2bbd25bf":[9,3,7,0],
-"classboost_1_1locale_1_1date__time__duration.html#a77e0946de974eeeb60d8aa3f6d174c93":[9,3,7,1],
-"classboost_1_1locale_1_1date__time__duration.html#a8570e450ad9c900a4dd39235b8e61909":[9,3,7,4],
+"classboost_1_1locale_1_1date__time__duration.html#a97034fcf223609c128ac6b446425d571":[9,3,7,1],
 "classboost_1_1locale_1_1date__time__duration.html#aac2e7c14858dcde54baca11d26d2dd54":[9,3,7,3],
 "classboost_1_1locale_1_1date__time__duration.html#af18b87186d2a9343069b1186fd062e2f":[9,3,7,2],
 "classboost_1_1locale_1_1date__time__error.html":[9,3,2],
 "classboost_1_1locale_1_1date__time__error.html#a25580392651d96c752a67f01ea853542":[9,3,2,0],
 "classboost_1_1locale_1_1date__time__period__set.html":[9,3,4],
 "classboost_1_1locale_1_1date__time__period__set.html#a0966962f5da78fc06121d1455efcbbae":[9,3,4,1],
+"classboost_1_1locale_1_1date__time__period__set.html#a0d14216cd4a4dae3645900c78fb77070":[9,3,4,0],
 "classboost_1_1locale_1_1date__time__period__set.html#a0e70247c1738dbf6869e6d8c04461893":[9,3,4,3],
 "classboost_1_1locale_1_1date__time__period__set.html#a14b5c2e199b3458d5faee0dc572b2f28":[9,3,4,5],
-"classboost_1_1locale_1_1date__time__period__set.html#a47b0a2759cbacd296d91929ddd453dcb":[9,3,4,4],
 "classboost_1_1locale_1_1date__time__period__set.html#a5867088d009104d8d3725d52ad0ac2bd":[9,3,4,2],
-"classboost_1_1locale_1_1date__time__period__set.html#a635b8d91c4c8da99857810e42a0aff65":[9,3,4,0],
+"classboost_1_1locale_1_1date__time__period__set.html#acc79f97dbd47a6e94329b45f93dcfa00":[9,3,4,4],
 "classboost_1_1locale_1_1generator.html":[11,0,0,0,20],
 "classboost_1_1locale_1_1generator.html#a0596082db49151e68d5143c827b61951":[11,0,0,0,20,1],
-"classboost_1_1locale_1_1generator.html#a06d729d1343302c1e522fae272b74156":[11,0,0,0,20,8],
-"classboost_1_1locale_1_1generator.html#a14df17122870020b1e3ab4d88188cb43":[11,0,0,0,20,14],
-"classboost_1_1locale_1_1generator.html#a1804390c65562fa66327152e9dd04c60":[11,0,0,0,20,11],
+"classboost_1_1locale_1_1generator.html#a06d729d1343302c1e522fae272b74156":[11,0,0,0,20,6],
+"classboost_1_1locale_1_1generator.html#a14df17122870020b1e3ab4d88188cb43":[11,0,0,0,20,11],
 "classboost_1_1locale_1_1generator.html#a25f1d8fbbab6558213991c99630e851c":[11,0,0,0,20,0],
-"classboost_1_1locale_1_1generator.html#a7ad16257142e13377a163d1fe75526dc":[11,0,0,0,20,4],
-"classboost_1_1locale_1_1generator.html#a7b4458ef36df82bc9e359735c55203e8":[11,0,0,0,20,9]
+"classboost_1_1locale_1_1generator.html#a7ad16257142e13377a163d1fe75526dc":[11,0,0,0,20,3]
 };
