@@ -13,12 +13,13 @@
  *         at http://www.boost.org/doc/libs/release/libs/log/doc/html/index.html.
  */
 
+#include <boost/log/detail/config.hpp>
 #include <map>
 #include <string>
 #include <boost/limits.hpp>
 #include <boost/type_index.hpp>
+#include <boost/core/snprintf.hpp>
 #include <boost/log/exceptions.hpp>
-#include <boost/log/detail/snprintf.hpp>
 #include <boost/log/detail/singleton.hpp>
 #include <boost/log/sources/global_logger_storage.hpp>
 #if !defined(BOOST_LOG_NO_THREADS)
@@ -82,18 +83,27 @@ BOOST_LOG_API BOOST_LOG_NORETURN void throw_odr_violation(
     typeindex::type_index logger_type,
     logger_holder_base const& registered)
 {
+    std::string str("Could not initialize global logger with tag \"");
+    str.append(tag_type.pretty_name());
+    str.append("\" and type \"");
+    str.append(logger_type.pretty_name());
+    str.append("\". A logger of type \"");
+    str.append(registered.m_LoggerType.pretty_name());
+    str.append("\" with the same tag has already been registered at ");
+    str.append(registered.m_RegistrationFile);
+
     char buf[std::numeric_limits< unsigned int >::digits10 + 3];
-    if (log::aux::snprintf(buf, sizeof(buf), "%u", registered.m_RegistrationLine) < 0)
-        buf[0] = '\0';
-    std::string str =
-        std::string("Could not initialize global logger with tag \"") +
-        tag_type.pretty_name() +
-        "\" and type \"" +
-        logger_type.pretty_name() +
-        "\". A logger of type \"" +
-        registered.m_LoggerType.pretty_name() +
-        "\" with the same tag has already been registered at " +
-        registered.m_RegistrationFile + ":" + buf + ".";
+    int res = boost::core::snprintf(buf, sizeof(buf), "%u", registered.m_RegistrationLine);
+    if (BOOST_LIKELY(res > 0))
+    {
+        if (BOOST_UNLIKELY(static_cast< unsigned int >(res) >= sizeof(buf)))
+            res = sizeof(buf) - 1u;
+
+        str.push_back(':');
+        str.append(buf, res);
+    }
+
+    str.push_back('.');
 
     BOOST_LOG_THROW_DESCR(odr_violation, str);
 }
