@@ -7,21 +7,31 @@
 //
 // See http://www.boost.org/libs/mpl for documentation.
 
-// $Id: transform_view.cpp 49268 2008-10-11 06:26:17Z agurtovoy $
-// $Date: 2008-10-10 23:26:17 -0700 (Fri, 10 Oct 2008) $
-// $Revision: 49268 $
+// $Id$
+// $Date$
+// $Revision$
 
 #include <boost/mpl/transform_view.hpp>
 
 #include <boost/mpl/max_element.hpp>
 #include <boost/mpl/list.hpp>
 #include <boost/mpl/sizeof.hpp>
+#include <boost/mpl/equal.hpp>
 #include <boost/mpl/aux_/test.hpp>
 
-
 MPL_TEST_CASE()
 {
     typedef list<int,long,char,char[50],double> types;
+    typedef list<
+        sizeof_<int>::type,
+        sizeof_<long>::type,
+        sizeof_<char>::type,
+        sizeof_<char[50]>::type,
+        sizeof_<double>::type
+    > sizes;
+
+    MPL_ASSERT(( equal< transform_view< types, sizeof_<_> >::type,sizes > ));
+
     typedef max_element<
           transform_view< types, sizeof_<_> >
         >::type iter;
