@@ -14,9 +14,9 @@
 // test ratio_add
 
 #include <boost/ratio/ratio.hpp>
-#if !defined(BOOST_NO_STATIC_ASSERT)
-#define NOTHING ""
-#endif
+#include <cstdint>
+
+#define STATIC_ASSERT(...) static_assert(__VA_ARGS__, #__VA_ARGS__)
 
 void test()
 {
@@ -24,66 +24,66 @@ void test()
   typedef boost::ratio<0> R1;
   typedef boost::ratio<0> R2;
   typedef boost::ratio_add<R1, R2> R;
-  BOOST_RATIO_STATIC_ASSERT(R::num == 0 && R::den == 1, NOTHING, ());
+  STATIC_ASSERT(R::num == 0 && R::den == 1);
   }
     {
     typedef boost::ratio<1, 1> R1;
     typedef boost::ratio<1, 1> R2;
     typedef boost::ratio_add<R1, R2> R;
-    BOOST_RATIO_STATIC_ASSERT(R::num == 2 && R::den == 1, NOTHING, ());
+    STATIC_ASSERT(R::num == 2 && R::den == 1);
     typedef boost::ratio_add<R, R2> RR;
-    BOOST_RATIO_STATIC_ASSERT(RR::num == 3 && RR::den == 1, NOTHING, ());
+    STATIC_ASSERT(RR::num == 3 && RR::den == 1);
     }
     {
     typedef boost::ratio<1, 2> R1;
     typedef boost::ratio<1, 1> R2;
     typedef boost::ratio_add<R1, R2> R;
-    BOOST_RATIO_STATIC_ASSERT(R::num == 3 && R::den == 2, NOTHING, ());
+    STATIC_ASSERT(R::num == 3 && R::den == 2);
     }
     {
     typedef boost::ratio<-1, 2> R1;
     typedef boost::ratio<1, 1> R2;
     typedef boost::ratio_add<R1, R2> R;
-    BOOST_RATIO_STATIC_ASSERT(R::num == 1 && R::den == 2, NOTHING, ());
+    STATIC_ASSERT(R::num == 1 && R::den == 2);
     }
     {
     typedef boost::ratio<1, -2> R1;
     typedef boost::ratio<1, 1> R2;
     typedef boost::ratio_add<R1, R2> R;
-    BOOST_RATIO_STATIC_ASSERT(R::num == 1 && R::den == 2, NOTHING, ());
+    STATIC_ASSERT(R::num == 1 && R::den == 2);
     }
     {
     typedef boost::ratio<1, 2> R1;
     typedef boost::ratio<-1, 1> R2;
     typedef boost::ratio_add<R1, R2> R;
-    BOOST_RATIO_STATIC_ASSERT(R::num == -1 && R::den == 2, NOTHING, ());
+    STATIC_ASSERT(R::num == -1 && R::den == 2);
     }
     {
     typedef boost::ratio<1, 2> R1;
     typedef boost::ratio<1, -1> R2;
     typedef boost::ratio_add<R1, R2> R;
-    BOOST_RATIO_STATIC_ASSERT(R::num == -1 && R::den == 2, NOTHING, ());
+    STATIC_ASSERT(R::num == -1 && R::den == 2);
     }
     {
     typedef boost::ratio<56987354, 467584654> R1;
     typedef boost::ratio<544668, 22145> R2;
     typedef boost::ratio_add<R1, R2> R;
-    BOOST_RATIO_STATIC_ASSERT(R::num == 127970191639601LL && R::den == 5177331081415LL, NOTHING, ());
+    STATIC_ASSERT(R::num == 127970191639601LL && R::den == 5177331081415LL);
     }
     {
-    typedef boost::ratio<BOOST_RATIO_INTMAX_T_MAX, 1> R1;
+    typedef boost::ratio<INTMAX_MAX, 1> R1;
     typedef boost::ratio<-1, 1> R2;
     typedef boost::ratio_add<R1, R2>::type RT;
     }
 
 }
 
-boost::intmax_t func(boost::ratio<5,6> s) {
+std::intmax_t func(boost::ratio<5,6> s) {
     return s.num;
 }
 
 
-boost::intmax_t test_conversion() {
+std::intmax_t test_conversion() {
     return func(
             boost::ratio_add<
                 boost::ratio<1,2>,
@@ -92,4 +92,3 @@ boost::intmax_t test_conversion() {
             ()
             );
 }
-
