@@ -31,30 +31,30 @@
 
 boost::timed_mutex m;
 
-typedef boost::chrono::steady_clock Clock;
+typedef boost::chrono::high_resolution_clock Clock;
 typedef Clock::time_point time_point;
 typedef Clock::duration duration;
 typedef boost::chrono::milliseconds ms;
 typedef boost::chrono::nanoseconds ns;
+time_point t0;
+time_point t1;
 
 const ms max_diff(BOOST_THREAD_TEST_TIME_MS);
 
 void f1()
 {
-  time_point t0 = Clock::now();
+  t0 = Clock::now();
   boost::unique_lock<boost::timed_mutex> lk(m, Clock::now() + ms(750));
   BOOST_TEST(lk.owns_lock() == true);
-  time_point t1 = Clock::now();
-  ns d = t1 - t0 - ms(250);
-  BOOST_THREAD_TEST_IT(d, ns(max_diff));
+  t1 = Clock::now();
 }
 
 void f2()
 {
-  time_point t0 = Clock::now();
+  t0 = Clock::now();
   boost::unique_lock<boost::timed_mutex> lk(m, Clock::now() + ms(250));
   BOOST_TEST(lk.owns_lock() == false);
-  time_point t1 = Clock::now();
+  t1 = Clock::now();
   ns d = t1 - t0 - ms(250);
   BOOST_TEST(d < max_diff);
 }
@@ -64,9 +64,18 @@ int main()
   {
     m.lock();
     boost::thread t(f1);
+    time_point t2 = Clock::now();
     boost::this_thread::sleep_for(ms(250));
+    time_point t3 = Clock::now();
     m.unlock();
     t.join();
+
+    ns sleep_time = t3 - t2;
+    ns d_ns = t1 - t0 - sleep_time;
+    ms d_ms = boost::chrono::duration_cast<boost::chrono::milliseconds>(d_ns);
+    // BOOST_TEST_GE(d_ms.count(), 0);
+    BOOST_THREAD_TEST_IT(d_ms, max_diff);
+    BOOST_THREAD_TEST_IT(d_ns, ns(max_diff));
   }
   {
     m.lock();
