@@ -41,7 +41,7 @@ struct check_quiet_NaN<true> {
     static void apply() {
         quantity<unit_type, T> q((std::numeric_limits<quantity<unit_type, T> >::quiet_NaN)());
         bool test = isnan BOOST_PREVENT_MACRO_SUBSTITUTION (q);
-        BOOST_CHECK(test);
+        BOOST_TEST(test);
     }
 };
 
@@ -60,7 +60,7 @@ struct check_signaling_NaN<true> {
     static void apply() {
         quantity<unit_type, T> q((std::numeric_limits<quantity<unit_type, T> >::signaling_NaN)());
         bool test = isnan BOOST_PREVENT_MACRO_SUBSTITUTION (q);
-        BOOST_CHECK(test);
+        BOOST_TEST(test);
     }
 };
 
@@ -72,18 +72,24 @@ struct check_signaling_NaN<false> {
 
 template<class T>
 void do_check() {
-    #define CHECK_FUNCTION(name) BOOST_CHECK(((std::numeric_limits<T>::name)() == (std::numeric_limits<quantity<unit_type, T> >::name)().value()))
-    #define CHECK_CONSTANT(name) BOOST_CHECK((std::numeric_limits<T>::name == std::numeric_limits<quantity<unit_type, T> >::name))
+    #define CHECK_FUNCTION(name) BOOST_TEST(((std::numeric_limits<T>::name)() == (std::numeric_limits<quantity<unit_type, T> >::name)().value()))
+    #define CHECK_CONSTANT(name) BOOST_TEST((std::numeric_limits<T>::name == std::numeric_limits<quantity<unit_type, T> >::name))
     CHECK_FUNCTION(min);
     CHECK_FUNCTION(max);
     CHECK_FUNCTION(epsilon);
     CHECK_FUNCTION(round_error);
     CHECK_FUNCTION(infinity);
     CHECK_FUNCTION(denorm_min);
+    #ifndef BOOST_NO_CXX11_NUMERIC_LIMITS
+    CHECK_FUNCTION(lowest);
+    #endif
 
     CHECK_CONSTANT(is_specialized);
     CHECK_CONSTANT(digits);
     CHECK_CONSTANT(digits10);
+    #ifndef BOOST_NO_CXX11_NUMERIC_LIMITS
+    CHECK_CONSTANT(max_digits10);
+    #endif
     CHECK_CONSTANT(is_signed);
     CHECK_CONSTANT(is_integer);
     CHECK_CONSTANT(is_exact);
@@ -108,7 +114,7 @@ void do_check() {
     check_signaling_NaN<std::numeric_limits<quantity<unit_type, T> >::has_signaling_NaN>::template apply<T>();
 }
 
-int test_main(int,char *[])
+int main()
 {
     do_check<float>();
     do_check<double>();
@@ -117,5 +123,5 @@ int test_main(int,char *[])
     do_check<unsigned>();
     do_check<std::complex<double> >();
 
-    return(0);
+    return boost::report_errors();
 }
