@@ -1,15 +1,12 @@
 
 // Copyright 2013 Daniel James.
+// Copyright 2022-2023 Christian Mazakas.
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
-// clang-format off
-#include "../helpers/prefix.hpp"
-#include <boost/unordered_set.hpp>
-#include <boost/unordered_map.hpp>
-#include "../helpers/postfix.hpp"
-// clang-format on
+#include "../helpers/unordered.hpp"
 
+#include "../helpers/fwd.hpp"
 #include "../helpers/test.hpp"
 
 #if defined(BOOST_MSVC)
@@ -60,13 +57,10 @@ namespace noexcept_tests {
     bool nothrow_swap>
   class hash_nothrow : boost::hash<int>
   {
-    BOOST_COPYABLE_AND_MOVABLE(hash_nothrow)
-
     typedef boost::hash<int> base;
 
   public:
-    hash_nothrow(BOOST_RV_REF(hash_nothrow))
-      BOOST_NOEXCEPT_IF(nothrow_move_construct)
+    hash_nothrow(hash_nothrow&&) noexcept(nothrow_move_construct)
     {
       if (!nothrow_move_construct) {
         test_throw("Move Constructor");
@@ -75,13 +69,13 @@ namespace noexcept_tests {
 
     hash_nothrow() { test_throw("Constructor"); }
     hash_nothrow(hash_nothrow const&) { test_throw("Copy"); }
-    hash_nothrow& operator=(BOOST_COPY_ASSIGN_REF(hash_nothrow))
+    hash_nothrow& operator=(hash_nothrow const&)
     {
       test_throw("Assign");
       return *this;
     }
-    hash_nothrow& operator=(BOOST_RV_REF(hash_nothrow))
-      BOOST_NOEXCEPT_IF(nothrow_move_assign)
+    hash_nothrow& operator=(hash_nothrow&&)
+      noexcept(nothrow_move_assign)
     {
       if (!nothrow_move_assign) {
         test_throw("Move Assign");
@@ -93,8 +87,7 @@ namespace noexcept_tests {
       test_throw("Operator");
       return static_cast<base const&>(*this)(x);
     }
-    friend void swap(hash_nothrow&, hash_nothrow&)
-      BOOST_NOEXCEPT_IF(nothrow_swap)
+    friend void swap(hash_nothrow&, hash_nothrow&) noexcept(nothrow_swap)
     {
       if (!nothrow_swap) {
         test_throw("Swap");
@@ -110,13 +103,11 @@ namespace noexcept_tests {
     bool nothrow_swap>
   class equal_to_nothrow
   {
-    BOOST_COPYABLE_AND_MOVABLE(equal_to_nothrow)
-
     typedef boost::hash<int> base;
 
   public:
-    equal_to_nothrow(BOOST_RV_REF(equal_to_nothrow))
-      BOOST_NOEXCEPT_IF(nothrow_move_construct)
+    equal_to_nothrow(equal_to_nothrow&&)
+      noexcept(nothrow_move_construct)
     {
       if (!nothrow_move_construct) {
         test_throw("Move Constructor");
@@ -125,13 +116,13 @@ namespace noexcept_tests {
 
     equal_to_nothrow() { test_throw("Constructor"); }
     equal_to_nothrow(equal_to_nothrow const&) { test_throw("Copy"); }
-    equal_to_nothrow& operator=(BOOST_COPY_ASSIGN_REF(equal_to_nothrow))
+    equal_to_nothrow& operator=(equal_to_nothrow const&)
     {
       test_throw("Assign");
       return *this;
     }
-    equal_to_nothrow& operator=(BOOST_RV_REF(equal_to_nothrow))
-      BOOST_NOEXCEPT_IF(nothrow_move_assign)
+    equal_to_nothrow& operator=(equal_to_nothrow&&)
+      noexcept(nothrow_move_assign)
     {
       if (!nothrow_move_assign) {
         test_throw("Move Assign");
@@ -144,7 +135,7 @@ namespace noexcept_tests {
       return x == y;
     }
     friend void swap(equal_to_nothrow&, equal_to_nothrow&)
-      BOOST_NOEXCEPT_IF(nothrow_swap)
+      noexcept(nothrow_swap)
     {
       if (!nothrow_swap) {
         test_throw("Swap");
@@ -181,18 +172,9 @@ namespace noexcept_tests {
       boost::is_nothrow_swappable<hash_nothrow_swap>::value;
 
 // Check that the traits work when expected.
-#if !defined(BOOST_NO_CXX11_NOEXCEPT) && !defined(BOOST_NO_SFINAE_EXPR) &&     \
-  !BOOST_WORKAROUND(BOOST_GCC_VERSION, < 40800)
     BOOST_TEST(have_is_nothrow_move);
     BOOST_TEST(have_is_nothrow_move_assign);
-#endif
-
-#if !defined(BOOST_NO_SFINAE_EXPR) && !defined(BOOST_NO_CXX11_NOEXCEPT) &&     \
-  !defined(BOOST_NO_CXX11_DECLTYPE) &&                                         \
-  !defined(BOOST_NO_CXX11_FUNCTION_TEMPLATE_DEFAULT_ARGS) &&                   \
-  !BOOST_WORKAROUND(BOOST_GCC_VERSION, < 40700)
     BOOST_TEST(have_is_nothrow_swap);
-#endif
 
     BOOST_LIGHTWEIGHT_TEST_OSTREAM
       << "have_is_nothrow_move: " << have_is_nothrow_move << std::endl
@@ -201,6 +183,16 @@ namespace noexcept_tests {
 
   UNORDERED_AUTO_TEST (test_noexcept) {
     if (have_is_nothrow_move) {
+#ifdef BOOST_UNORDERED_FOA_TESTS
+      BOOST_TEST((boost::is_nothrow_move_constructible<
+        boost::unordered_flat_set<int> >::value));
+      BOOST_TEST((boost::is_nothrow_move_constructible<
+        boost::unordered_flat_map<int, int> >::value));
+      BOOST_TEST((boost::is_nothrow_move_constructible<
+        boost::unordered_node_set<int> >::value));
+      BOOST_TEST((boost::is_nothrow_move_constructible<
+        boost::unordered_node_map<int, int> >::value));
+#else
       BOOST_TEST((boost::is_nothrow_move_constructible<
         boost::unordered_set<int> >::value));
       BOOST_TEST((boost::is_nothrow_move_constructible<
@@ -209,34 +201,48 @@ namespace noexcept_tests {
         boost::unordered_map<int, int> >::value));
       BOOST_TEST((boost::is_nothrow_move_constructible<
         boost::unordered_multimap<int, int> >::value));
+#endif
     }
 
+#ifdef BOOST_UNORDERED_FOA_TESTS
+    BOOST_TEST(
+      (!boost::is_nothrow_move_constructible<
+        boost::unordered_flat_set<int, hash_possible_exception> >::value));
+    BOOST_TEST(
+      (!boost::is_nothrow_move_constructible<boost::unordered_flat_set<int,
+          boost::hash<int>, equal_to_possible_exception> >::value));
+
+    BOOST_TEST(
+      (!boost::is_nothrow_move_constructible<
+        boost::unordered_node_set<int, hash_possible_exception> >::value));
+    BOOST_TEST(
+      (!boost::is_nothrow_move_constructible<boost::unordered_node_set<int,
+          boost::hash<int>, equal_to_possible_exception> >::value));
+#else
     BOOST_TEST((!boost::is_nothrow_move_constructible<
                 boost::unordered_set<int, hash_possible_exception> >::value));
     BOOST_TEST(
       (!boost::is_nothrow_move_constructible<boost::unordered_multiset<int,
           boost::hash<int>, equal_to_possible_exception> >::value));
+#endif
   }
 
-  UNORDERED_AUTO_TEST (test_nothrow_move_when_noexcept) {
-    typedef boost::unordered_set<int, hash_nothrow_move_construct,
-      equal_to_nothrow_move_construct>
-      throwing_set;
-
+  template <class X> static void test_nothrow_move_when_noexcept(X*)
+  {
     if (have_is_nothrow_move) {
-      BOOST_TEST(boost::is_nothrow_move_constructible<throwing_set>::value);
+      BOOST_TEST(boost::is_nothrow_move_constructible<X>::value);
     }
 
     throwing_test_exception = false;
 
-    throwing_set x1;
+    X x1;
     x1.insert(10);
     x1.insert(50);
 
     try {
       throwing_test_exception = true;
 
-      throwing_set x2 = boost::move(x1);
+      X x2 = std::move(x1);
       BOOST_TEST(x2.size() == 2);
       BOOST_TEST(*x2.begin() == 10 || *x2.begin() == 50);
       BOOST_TEST(have_is_nothrow_move);
@@ -247,51 +253,77 @@ namespace noexcept_tests {
     throwing_test_exception = false;
   }
 
-  UNORDERED_AUTO_TEST (test_nothrow_move_assign_when_noexcept) {
-    typedef boost::unordered_set<int, hash_nothrow_move_assign,
-      equal_to_nothrow_move_assign>
-      throwing_set;
+  template <class T>
+  void test_nothrow_move_assign_when_noexcept(T*, test::random_generator const&)
+  {
+    {
+      if (have_is_nothrow_move_assign) {
+        BOOST_TEST(boost::is_nothrow_move_assignable<T>::value);
+      }
 
-    if (have_is_nothrow_move_assign) {
-      BOOST_TEST(boost::is_nothrow_move_assignable<throwing_set>::value);
+      throwing_test_exception = false;
+
+      T x1;
+      T x2;
+      x1.insert(10);
+      x1.insert(50);
+      for (int i = 0; i < 100; ++i) {
+        x2.insert(i);
+      }
+
+      try {
+        throwing_test_exception = true;
+
+        x2 = std::move(x1);
+        BOOST_TEST(x2.size() == 2);
+        BOOST_TEST(*x2.begin() == 10 || *x2.begin() == 50);
+        BOOST_TEST(have_is_nothrow_move_assign);
+      } catch (test_exception) {
+        BOOST_TEST(!have_is_nothrow_move_assign);
+      }
+
+      throwing_test_exception = false;
     }
 
-    throwing_test_exception = false;
+    {
+      if (have_is_nothrow_move_assign) {
+        BOOST_TEST(boost::is_nothrow_move_assignable<T>::value);
+      }
 
-    throwing_set x1;
-    throwing_set x2;
-    x1.insert(10);
-    x1.insert(50);
-    for (int i = 0; i < 100; ++i) {
-      x2.insert(i);
+      throwing_test_exception = false;
+
+      T x1;
+      T x2;
+      x1.insert(10);
+      x1.insert(50);
+      for (int i = 0; i < 100; ++i) {
+        x2.insert(i);
+      }
+
+      try {
+        throwing_test_exception = true;
+
+        x1 = std::move(x2);
+        BOOST_TEST(x1.size() == 100);
+        BOOST_TEST(have_is_nothrow_move_assign);
+      } catch (test_exception) {
+        BOOST_TEST(!have_is_nothrow_move_assign);
+      }
+
+      throwing_test_exception = false;
     }
-
-    try {
-      throwing_test_exception = true;
-
-      x2 = boost::move(x1);
-      BOOST_TEST(x2.size() == 2);
-      BOOST_TEST(*x2.begin() == 10 || *x2.begin() == 50);
-      BOOST_TEST(have_is_nothrow_move_assign);
-    } catch (test_exception) {
-      BOOST_TEST(!have_is_nothrow_move_assign);
-    }
-
-    throwing_test_exception = false;
   }
 
-  UNORDERED_AUTO_TEST (test_nothrow_swap_when_noexcept) {
-    typedef boost::unordered_set<int, hash_nothrow_swap, equal_to_nothrow_swap>
-      throwing_set;
-
+  template <class X> static void test_nothrow_swap_when_noexcept(X*)
+  {
     if (have_is_nothrow_swap) {
-      BOOST_TEST(boost::is_nothrow_swappable<throwing_set>::value);
+      BOOST_TEST(boost::is_nothrow_swappable<X>::value);
     }
 
     throwing_test_exception = false;
 
-    throwing_set x1;
-    throwing_set x2;
+    X x1;
+    X x2;
     x1.insert(10);
     x1.insert(50);
     for (int i = 0; i < 100; ++i) {
@@ -312,10 +344,130 @@ namespace noexcept_tests {
 
     throwing_test_exception = false;
   }
-}
+} // namespace noexcept_tests
 
 #if defined(BOOST_MSVC)
 #pragma warning(pop)
 #endif
 
+template <class T> class allocator1
+{
+  allocator1 operator=(allocator1 const&);
+  allocator1 operator=(allocator1&&);
+
+public:
+  typedef T value_type;
+
+  allocator1() {}
+  allocator1(allocator1 const&) {}
+
+  template <class U> allocator1(allocator1<U> const&) {}
+
+  T* allocate(std::size_t n)
+  {
+    noexcept_tests::test_throw("Allocate");
+    return static_cast<T*>(::operator new(n * sizeof(T)));
+  }
+
+  void deallocate(T* p, std::size_t) { ::operator delete(p); }
+
+  friend bool operator==(allocator1 const&, allocator1 const&) { return true; }
+  friend bool operator!=(allocator1 const&, allocator1 const&) { return false; }
+};
+
+template <class T> class allocator2
+{
+  allocator2 operator=(allocator2 const&);
+
+public:
+  typedef T value_type;
+  typedef boost::true_type propagate_on_container_move_assignment;
+
+  allocator2() {}
+  allocator2(allocator2 const&) {}
+
+  template <class U> allocator2(allocator2<U> const&) {}
+
+  allocator2& operator=(allocator2&&) { return *this; }
+
+  T* allocate(std::size_t n)
+  {
+    noexcept_tests::test_throw("Allocate");
+    return static_cast<T*>(::operator new(n * sizeof(T)));
+  }
+
+  void deallocate(T* p, std::size_t) { ::operator delete(p); }
+
+  friend bool operator==(allocator2 const&, allocator2 const&) { return true; }
+  friend bool operator!=(allocator2 const&, allocator2 const&) { return false; }
+};
+
+UNORDERED_AUTO_TEST (prelim_allocator_checks) {
+  BOOST_TEST(boost::allocator_is_always_equal<allocator1<int> >::type::value);
+  BOOST_TEST(!boost::allocator_propagate_on_container_move_assignment<
+             allocator1<int> >::type::value);
+
+  BOOST_TEST(boost::allocator_is_always_equal<allocator2<int> >::type::value);
+  BOOST_TEST(boost::allocator_propagate_on_container_move_assignment<
+    allocator2<int> >::type::value);
+}
+
+using test::default_generator;
+
+#ifdef BOOST_UNORDERED_FOA_TESTS
+boost::unordered_flat_set<int, noexcept_tests::hash_nothrow_move_construct,
+  noexcept_tests::equal_to_nothrow_move_construct>* throwing_set;
+boost::unordered_flat_set<int, noexcept_tests::hash_nothrow_swap,
+  noexcept_tests::equal_to_nothrow_swap>* throwing_set2;
+
+boost::unordered_flat_set<int, noexcept_tests::hash_nothrow_swap,
+  noexcept_tests::equal_to_nothrow_swap, allocator1<int> >* throwing_set_alloc1;
+
+boost::unordered_flat_set<int, noexcept_tests::hash_nothrow_swap,
+  noexcept_tests::equal_to_nothrow_swap, allocator2<int> >* throwing_set_alloc2;
+
+boost::unordered_node_set<int, noexcept_tests::hash_nothrow_move_construct,
+  noexcept_tests::equal_to_nothrow_move_construct>* throwing_node_set;
+boost::unordered_node_set<int, noexcept_tests::hash_nothrow_swap,
+  noexcept_tests::equal_to_nothrow_swap>* throwing_node_set2;
+
+boost::unordered_node_set<int, noexcept_tests::hash_nothrow_swap,
+  noexcept_tests::equal_to_nothrow_swap, allocator1<int> >*
+  throwing_node_set_alloc1;
+
+boost::unordered_node_set<int, noexcept_tests::hash_nothrow_swap,
+  noexcept_tests::equal_to_nothrow_swap, allocator2<int> >*
+  throwing_node_set_alloc2;
+
+// clang-format off
+UNORDERED_TEST(
+  test_nothrow_move_when_noexcept, ((throwing_set)(throwing_node_set)))
+UNORDERED_TEST(
+  test_nothrow_swap_when_noexcept, ((throwing_set2)(throwing_node_set2)))
+UNORDERED_TEST(test_nothrow_move_assign_when_noexcept,
+  ((throwing_set_alloc1)(throwing_set_alloc2)
+   (throwing_node_set_alloc1)(throwing_node_set_alloc2))(
+    (default_generator)))
+// clang-format on
+#else
+boost::unordered_set<int, noexcept_tests::hash_nothrow_move_construct,
+  noexcept_tests::equal_to_nothrow_move_construct>* throwing_set;
+
+boost::unordered_set<int, noexcept_tests::hash_nothrow_swap,
+  noexcept_tests::equal_to_nothrow_swap>* throwing_set2;
+
+boost::unordered_set<int, noexcept_tests::hash_nothrow_move_assign,
+  noexcept_tests::equal_to_nothrow_move_assign, allocator1<int> >*
+  throwing_set_alloc1;
+
+boost::unordered_set<int, noexcept_tests::hash_nothrow_move_assign,
+  noexcept_tests::equal_to_nothrow_move_assign, allocator2<int> >*
+  throwing_set_alloc2;
+
+UNORDERED_TEST(test_nothrow_move_when_noexcept, ((throwing_set)))
+UNORDERED_TEST(test_nothrow_swap_when_noexcept, ((throwing_set2)))
+UNORDERED_TEST(test_nothrow_move_assign_when_noexcept,
+  ((throwing_set_alloc1)(throwing_set_alloc2))((default_generator)))
+#endif
+
 RUN_TESTS()
