@@ -3,7 +3,7 @@
 // See http://www.boost.org for updates, documentation, and revision history.
 //-----------------------------------------------------------------------------
 //
-// Copyright (c) 2014-2021 Antony Polukhin
+// Copyright (c) 2014-2023 Antony Polukhin
 //
 // Distributed under the Boost Software License, Version 1.0. (See
 // accompanying file LICENSE_1_0.txt or copy at
@@ -188,12 +188,6 @@ struct lex_streamer2 {
     }
 };
 
-#ifndef BOOST_VARIANT_DO_NOT_USE_VARIADIC_TEMPLATES
-#   define BOOST_TEST_IF_HAS_VARIADIC(x) BOOST_TEST(x)
-#else
-#   define BOOST_TEST_IF_HAS_VARIADIC(x) /**/
-#endif
-
 void run()
 {
     typedef boost::variant<int, std::string, double> variant_type;
@@ -201,9 +195,9 @@ void run()
     lex_streamer lex_streamer_visitor;
 
     BOOST_TEST(boost::apply_visitor(lex_streamer(), v1) == "1");
-    BOOST_TEST_IF_HAS_VARIADIC(boost::apply_visitor(lex_streamer_visitor)(v1) == "1");
+    BOOST_TEST(boost::apply_visitor(lex_streamer_visitor)(v1) == "1");
     BOOST_TEST(boost::apply_visitor(lex_streamer(), v2) == "10");
-    BOOST_TEST_IF_HAS_VARIADIC(boost::apply_visitor(lex_streamer_visitor)(v2) == "10");
+    BOOST_TEST(boost::apply_visitor(lex_streamer_visitor)(v2) == "10");
 
     #ifndef BOOST_NO_CXX14_GENERIC_LAMBDAS
         BOOST_TEST(boost::apply_visitor([](auto v) { return boost::lexical_cast<std::string>(v); }, v1) == "1");
@@ -220,16 +214,16 @@ void run()
     lex_streamer2 visitor_ref;
     BOOST_TEST(boost::apply_visitor(visitor_ref, v1) == "1");
     BOOST_TEST(boost::apply_visitor(visitor_ref, v2) == "10");
-#ifndef BOOST_VARIANT_DO_NOT_USE_VARIADIC_TEMPLATES
+
     std::string& ref_to_string = boost::apply_visitor(visitor_ref, v1);
     BOOST_TEST(ref_to_string == "1");
-#endif
+
     lex_streamer_void lex_streamer_void_visitor;
     boost::apply_visitor(lex_streamer_void(), v1);
     boost::apply_visitor(lex_streamer_void(), v2);
-#ifndef BOOST_VARIANT_DO_NOT_USE_VARIADIC_TEMPLATES
+
     boost::apply_visitor(lex_streamer_void_visitor)(v2);
-#endif
+
 
     boost::ignore_unused(lex_streamer_visitor, visitor_ref, lex_streamer_void_visitor);
 }
@@ -258,7 +252,7 @@ void run2()
 
     BOOST_TEST(boost::apply_visitor(lex_combine(), v1, v2) == "1+10");
     BOOST_TEST(boost::apply_visitor(lex_combine(), v2, v1) == "10+1");
-    BOOST_TEST_IF_HAS_VARIADIC(boost::apply_visitor(lex_combine_visitor)(v2, v1) == "10+1");
+    BOOST_TEST(boost::apply_visitor(lex_combine_visitor)(v2, v1) == "10+1");
 
 
     #ifndef BOOST_NO_CXX14_GENERIC_LAMBDAS
@@ -291,10 +285,9 @@ void run2()
     lex_streamer2 visitor_ref;
     BOOST_TEST(boost::apply_visitor(visitor_ref, v1, v2) == "1+10");
     BOOST_TEST(boost::apply_visitor(visitor_ref, v2, v1) == "10+1");
-#ifndef BOOST_VARIANT_DO_NOT_USE_VARIADIC_TEMPLATES
+
     std::string& ref_to_string = boost::apply_visitor(visitor_ref)(v1, v2);
     BOOST_TEST(ref_to_string == "1+10");
-#endif
 
     boost::apply_visitor(lex_streamer_void(), v1, v2);
     boost::apply_visitor(lex_streamer_void(), v2, v1);
@@ -302,11 +295,8 @@ void run2()
     boost::ignore_unused(lex_combine_visitor, visitor_ref);
 }
 
-#undef BOOST_TEST_IF_HAS_VARIADIC
-
 void run3()
 {
-#if !defined(BOOST_VARIANT_DO_NOT_USE_VARIADIC_TEMPLATES) && !defined(BOOST_NO_CXX11_HDR_TUPLE)
     typedef boost::variant<int, std::string, double> variant_type;
     variant_type v1(1), v2("10"), v3(100);
     lex_combine lex_combine_visitor;
@@ -363,7 +353,7 @@ void run3()
     boost::apply_visitor(lex_streamer_void(), v1, v2, v1);
     boost::apply_visitor(lex_streamer_void(), v2, v1, v1);
     boost::apply_visitor(lex_streamer_void_visitor)(v2, v1, v1);
-#endif // !defined(BOOST_VARIANT_DO_NOT_USE_VARIADIC_TEMPLATES) && !defined(BOOST_NO_CXX11_HDR_TUPLE)
+
 }
 #endif
 
