@@ -7,13 +7,10 @@
     LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 =============================================================================*/
 
-// Test error reporting for non-unique parameter names
+// Test error reporting during redefinition of 'defined'
 
-//E t_1_026.cpp(13): error: duplicate macro parameter name: x
-#define MACRO(x, x) x
-           // ^  ^ this is illegal
+//E t_9_008.cpp(13): warning: #undef may not be used on this predefined name: defined
+#undef defined 
 
-MACRO(1, 2)
-
-//H 10: t_1_026.cpp(13): #define
-//H 18: boost::wave::macro_handling_exception
+//H 10: t_9_008.cpp(13): #undef
+//H 18: boost::wave::preprocess_exception
